<?php
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) )
	exit;

/**
 *  class
 */
class Listeo_Core_Paid_Properties {
	
	/**
	 * Returns static instance of class.
	 *
	 * @return self
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}


	/**
	 * Constructor
	 */
	public function __construct() {

		/* Hooks */
		add_action( 'woocommerce_product_options_general_product_data', array( $this,  'listeo_core_add_custom_settings' ) );
		add_action( 'woocommerce_process_product_meta_listing_package', array( $this, 'save_package_data' ) );
		
		/* Includes */
		include_once( 'class-listeo-core-paid-listings-orders.php' );
		include_once( 'class-listeo-core-paid-listings-package.php' );
		include_once( 'class-listeo-core-paid-listings-cart.php' );

	}


	function listeo_core_add_custom_settings() {
	    global $woocommerce, $post;
	    echo '<div class="options_group show_if_listing_package">';

	    // Create a number field, for example for UPC
	     woocommerce_wp_text_input( array(
			'id' 				=> '_listing_limit',
			'label' 			=> __( 'Listing limit', 'listeo_core' ),
			'description' 		=> __( 'The number of listings a user can post with this package.', 'listeo_core' ),
			'value' 			=> ( $limit = get_post_meta( $post->ID, '_listing_limit', true ) ) ? $limit : '',
			'placeholder' 		=> __( 'Unlimited', 'listeo_core' ),
			'type' 				=> 'number',
			'desc_tip' 			=> true,
			'custom_attributes' => array(
			'min'   			=> '',
			'step' 				=> '1',
			),
		) ); 

	    woocommerce_wp_text_input( array(
			'id' 				=> '_listing_duration',
			'label' 			=> __( 'Listing duration', 'listeo_core' ),
			'description' 		=> __( 'The number of days that the listing will be active.', 'listeo_core' ),
			'value' 			=> get_post_meta(  $post->ID, '_listing_duration', true ),
			'placeholder' 		=> get_option( 'job_manager_submission_duration' ),
			'desc_tip' 			=> true,
			'type' 				=> 'number',
			'custom_attributes' => array(
			'min'  				=> '',
			'step' 				=> '1',
			),
		) );

		 woocommerce_wp_checkbox( array(
			'id' => '_listing_featured',
			'label' => __( 'Feature Listing?', 'listeo_core' ),
			'description' => __( 'Feature this listing - it will have a badge and sticky status.', 'listeo_core' ),
			'value' => get_post_meta(  $post->ID, '_listing_featured', true ),
		) ); 
	    echo '</div>';
	    ?>
	    <script type="text/javascript">
		jQuery(function(){
			jQuery('#product-type').change( function() {
				jQuery('#woocommerce-product-data').removeClass(function(i, classNames) {
					var classNames = classNames.match(/is\_[a-zA-Z\_]+/g);
					if ( ! classNames ) {
						return '';
					}
					return classNames.join(' ');
				});
				jQuery('#woocommerce-product-data').addClass( 'is_' + jQuery(this).val() );
			} );
			jQuery('.pricing').addClass( 'show_if_listing_package' );
			jQuery('._tax_status_field').closest('div').addClass( 'show_if_listing_package' );
			
			
			jQuery('#product-type').change();
			
		});
	</script>
	<?php
	}

	/**
	 * Save Job Package data for the product
	 *
	 * @param  int $post_id
	 */
	public function save_package_data( $post_id ) {
		global $wpdb;

		// Save meta
		$meta_to_save = array(
			'_listing_duration'             => '',
			'_listing_limit'                => 'int',
			'_listing_featured'             => 'yesno',
		);

		foreach ( $meta_to_save as $meta_key => $sanitize ) {
			$value = ! empty( $_POST[ $meta_key ] ) ? $_POST[ $meta_key ] : '';
			switch ( $sanitize ) {
				case 'int' :
					$value = absint( $value );
					break;
				case 'float' :
					$value = floatval( $value );
					break;
				case 'yesno' :
					$value = $value == 'yes' ? 'yes' : 'no';
					break;
				default :
					$value = sanitize_text_field( $value );
			}
			update_post_meta( $post_id, $meta_key, $value );
		}

	}

}

new Listeo_Core_Paid_Properties();



