<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

class Listeo_Submit_Editor {
/**
     * Stores static instance of class.
     *
     * @access protected
     * @var Listeo_Submit The single instance of the class
     */
    protected static $_instance = null;

    /**
     * Returns static instance of class.
     *
     * @return self
     */
    public static function instance() {
        if ( is_null( self::$_instance ) ) {
            self::$_instance = new self();
        }
        return self::$_instance;
    }

    public function __construct($version = '1.0.0') {
  
       	add_action( 'admin_menu', array( $this, 'add_options_page' ) ); //create tab pages
      	add_filter('submit_property_form_fields', array( $this,'add_listeo_submit_property_form_fields_form_editor')); 
       
    }

    function add_listeo_submit_property_form_fields_form_editor($r){
        $fields =  get_option('listeo_submit_form_fields');
        if(!empty($fields)) { $r['property'] = $fields; }
        return $r;
      }

     /**
     * Add menu options page
     * @since 0.1.0
     */
    public function add_options_page() {        
         add_submenu_page( 'listeo-fields-and-form', 'Submit Form', 'Submit Form', 'manage_options', 'listeo-submit-builder', array( $this, 'output' )); 
    }


    public function output(){

    	 $predefined_options = apply_filters( 'listeo_predefined_options', array(
                'listeo_get_property_types'     => __( 'Property Types list', 'wp-job-manager-applications' ),
                'listeo_get_offer_types_flat'        => __( 'Offer Types list', 'wp-job-manager-applications' ),
                'listeo_get_rental_period'         => __( 'Rental Period list', 'wp-job-manager-applications' ),
            ) );

    	
    	$defaults = array(
			'basic_info' => array(
				'title' 	=> __('Basic Information','listeo_core'),
				'class' 	=> '',
				'icon' 		=> 'sl sl-icon-doc',
				'fields' 	=> array(
						'listing_title' => array(
							'label'       => __( 'Listing Title', 'listeo_core' ),
							'type'        => 'text',
							'name'       => 'listing_title',
							'tooltip'	  => __( 'Type title that will also contains an unique feature of your listing (e.g. renovated, air contidioned)', 'listeo_core' ),
							'required'    => true,
							'placeholder' => '',
							'class'		  => '',
							'priority'    => 1,
							
						),
						'listing_category' => array(
							'label'       => __( 'Category', 'listeo_core' ),
							'type'        => 'term-select',
							'placeholder' => '',
							'name'        => 'listing_category',
							'taxonomy'	  => 'listing_category',
							'tooltip'	  => __( 'This is main listings category', 'listeo_core' ),
							'priority'    => 10,
							'before_row'  => '<div class="row with-forms">',
							'after_row'   => '',
							'default'	  => '',
							'render_row_col' => '4',
							'required'    => false,
						),
						// 'event_category' => array(
						// 	'label'       => __( 'Event Category', 'listeo_core' ),
						// 	'type'        => 'term-select',
						// 	'placeholder' => '',
						// 	'name'        => 'event_category',
						// 	'taxonomy'	  => 'event_category',
						// 	'tooltip'	  => __( 'Those are categories related to your listing type', 'listeo_core' ),
						// 	'priority'    => 10,
						// 	'before_row'  => '',
						// 	'after_row'   => '',
						// 	'default'	  => '',
						// 	'render_row_col' => '4',
						// 	'required'    => false,
						// ),
						// 'service_category' => array(
						// 	'label'       => __( 'Service Category', 'listeo_core' ),
						// 	'type'        => 'term-select',
						// 	'placeholder' => '',
						// 	'name'        => 'service_category',
						// 	'taxonomy'	  => 'service_category',
						// 	'priority'    => 10,
						// 	'before_row'  => '',
						// 	'after_row'   => '',
						// 	'default'	  => '',
						// 	'render_row_col' => '4',
						// 	'required'    => false,
						// ),
						// 'rental_category' => array(
						// 	'label'       => __( 'Rental Category', 'listeo_core' ),
						// 	'type'        => 'term-select',
						// 	'placeholder' => '',
						// 	'name'        => 'rental_category',
						// 	'taxonomy'	  => 'rental_category',
						// 	'priority'    => 10,
						// 	'before_row'  => '',
						// 	'after_row'   => '',
						// 	'default'	  => '',
						// 	'render_row_col' => '4',
						// 	'required'    => false,
						// ),
						'keywords' => array(
							'label'       => __( 'Keywords', 'listeo_core' ),
							'type'        => 'text',
							'tooltip'	  => __( 'Maximum of 15 keywords related with your business, separated by coma' , 'listeo_core' ),
							'placeholder' => '',
							'name'        => 'keywords',
							'after_row'   => '</div>',
							'priority'    => 10,
							'before_row'  => '',
							'default'	  => '',
							'render_row_col' => '4',
							'required'    => false,
						),
						'product_id' => array(
							'name'        => 'product_id',
							'type'        => 'hidden',							
							'required'    => false,
						),
						'listing_feature' => array(
							'label'       	=> __( 'Other Features', 'listeo_core' ),
							'type'        	=> 'term-checkboxes',
							'taxonomy'		=> 'listing_feature',
							'name'			=> 'listing_feature',
							'class'		  	 => 'chosen-select-no-single',
							'default'    	 => '',
							'priority'    	 => 2,
							'required'    => false,
						),
						
				),
			),
			'location' =>  array(
				'title' 	=> __('Location','listeo_core'),
				'class' 	=> 'margin-top-40',
				'icon' 		=> 'sl sl-icon-location',
				'fields' 	=> array(
					
					'_address' => array(
						'label'       => __( 'Address', 'listeo_core' ),
						'type'        => 'text',
						'required'    => false,
						'name'        => '_address',
						'placeholder' => '',
						'class'		  => '',
						'before_row' 	 => '<div class="row with-forms">',
						'priority'    => 7,
						'render_row_col' => '6'
					),				
					'_friendly_address' => array(
						'label'       => __( 'Friendly Address', 'listeo_core' ),
						'type'        => 'text',
						'required'    => false,
						'name'        => '_friendly_address',
						'placeholder' => '',
						'tooltip'	  => __('Human readable address, if not set, the Google address will be used', 'listeo_core'),
						'class'		  => '',
						'after_row' 	 => '</div>',
						'priority'    => 8,
						'render_row_col' => '6'
					),	
					'region' => array(
						'label'       => __( 'Region', 'listeo_core' ),
						'type'        => 'term-select',
						'required'    => false,
						'name'        => 'region',
						'taxonomy'        => 'region',
						'placeholder' => '',
						'class'		  => '',
						'before_row'  => '<div class="row with-forms">',
						'priority'    => 8,
						'render_row_col' => '6'
					),				
					'_geolocation_long' => array(
						'label'       => __( 'Longitude', 'listeo_core' ),
						'type'        => 'text',
						'required'    => false,
						'placeholder' => '',
						'name'        => '_geolocation_long',
						'class'		  => '',
						'before_row' 	 => '',
						'priority'    => 9,
						'render_row_col' => '3'
					),				
					'_geolocation_lat' => array(
						'label'       => __( 'Latitude', 'listeo_core' ),
						'type'        => 'text',
						'required'    => false,
						'placeholder' => '',
						'name'        => '_geolocation_lat',
						'class'		  => '',
						'priority'    => 10,
						'after_row' 	 => '</div>',
						'render_row_col' => '3'
					),
				),
			),
			'gallery' => array(
				'title' 	=> __('Gallery','listeo_core'),
				'class' 	=> 'margin-top-40',
				'icon' 		=> 'sl sl-icon-picture',
				'fields' 	=> array(
						'_gallery' => array(
							'label'       => __( 'Gallery', 'listeo_core' ),
							'name'       => '_gallery',
							'type'        => 'files',
							'description' => __( 'By selecting (clicking on a photo) one of the uploaded photos you will set it as Featured Image for this listing (marked by icon with star). Drag and drop thumbnails to re-order images in gallery.', 'listeo_core' ),
							'placeholder' => 'Upload images',
							'class'		  => '',
							'priority'    => 1,
							'required'    => false,
						),				
						'_thumbnail_id' => array(
							'label'       => __( 'Thumbnail ID', 'listeo_core' ),
							'type'        => 'hidden',
							'name'        => '_thumbnail_id',
							'class'		  => '',
							'priority'    => 1,
							'required'    => false,
						),
				),
			),
			'details' => array(
				'title' 	=> __('Details','listeo_core'),
				'class' 	=> 'margin-top-40',
				'icon' 		=> 'sl sl-icon-docs',
				'fields' 	=> array(
						'listing_description' => array(
							'label'       => __( 'Description', 'listeo_core' ),
							'name'       => 'listing_description',
							'type'        => 'wp-editor',
							'description' => __( 'By selecting (clicking on a photo) one of the uploaded photos you will set it as Featured Image for this listing (marked by icon with star). Drag and drop thumbnails to re-order images in gallery.', 'listeo_core' ),
							'placeholder' => 'Upload images',
							'class'		  => '',
							'priority'    => 1,
							'required'    => true,
						),				
						'_video' => array(
							'label'       => __( 'Video', 'listeo_core' ),
							'type'        => 'text',
							'name'        => '_video',
							'required'    => false,
							'placeholder' => __( 'URL to oEmbed supported service', 'listeo_core' ),
							'class'		  => '',
							'priority'    => 5,
						),

						'_phone' => array(
							'label'       => __( 'Phone', 'listeo_core' ),
							'type'        => 'text',
							'required'    => false,
							'placeholder' => '',
							'name'        => '_phone',
							'class'		  => '',
							'before_row' 	 => '<div class="row with-forms">',
							'priority'    => 9,
							'render_row_col' => '3'
						),		
						'_website' => array(
							'label'       => __( 'Website', 'listeo_core' ),
							'type'        => 'text',
							'required'    => false,
							'placeholder' => '',
							'name'        => '_website',
							'class'		  => '',
							
							'priority'    => 9,
							'render_row_col' => '3'
						),
						'_email' => array(
							'label'       => __( 'E-mail', 'listeo_core' ),
							'type'        => 'text',
							'required'    => false,
							'placeholder' => '',
							'name'        => '_email',
							
							'class'		  => '',
							'priority'    => 10,
							'render_row_col' => '3'
						),
						'_email_contact_widget' => array(
							'label'       => __( 'Enable Contact Widget', 'listeo_core' ),
							'type'        => 'checkbox',
							'tooltip'	  => __('With this option enabled listing will display Contact Form Widget that will send emails to this address', 'listeo_core'),
							'required'    => false,
							
							'placeholder' => '',
							'name'        => '_email_contact_widget',
							'class'		  => '',
							'priority'    => 10,
							'after_row' 	 => '</div>',
							'priority'    => 9,
							'render_row_col' => '3'
						),				
						
						'_facebook' => array(
							'label'       => __( '<i class="fa fa-facebook-square"></i> Facebook', 'listeo_core' ),
							'type'        => 'text',
							'required'    => false,
							'placeholder' => '',
							'name'        => '_facebook',
							'class'		  => 'fb-input',
							'before_row' 	 => '<div class="row with-forms">',
							'priority'    => 9,
							'render_row_col' => '4'
						),	
						'_twitter' => array(
							'label'       => __( '<i class="fa fa-twitter-square"></i> Twitter', 'listeo_core' ),
							'type'        => 'text',
							'required'    => false,
							'placeholder' => '',
							'name'        => '_twitter',
							'class'		  => 'twitter-input',
							'before_row' 	 => '',
							'priority'    => 9,
							'render_row_col' => '4'
						),
						'_youtube' => array(
							'label'       => __( '<i class="fa fa-youtube-square"></i> YouTube', 'listeo_core' ),
							'type'        => 'text',
							'required'    => false,
							'placeholder' => '',
							'name'        => '_youtube',
							'class'		  => 'youtube-input',
							'after_row' 	 => '</div>',
							'priority'    => 9,
							'render_row_col' => '4'
						),				
						'_instagram' => array(
							'label'       => __( '<i class="fa fa-instagram"></i> Instagram', 'listeo_core' ),
							'type'        => 'text',
							'required'    => false,
							'placeholder' => '',
							'name'        => '_instagram',
							'class'		  => 'instagram-input',
							'priority'    => 10,
							'before_row' 	 => '<div class="row with-forms">',
							'render_row_col' => '4'
						),
						'_whatsapp' => array(
							'label'       => __( '<i class="fa fa-whatsapp"></i> WhatsApp', 'listeo_core' ),
							'type'        => 'text',
							'required'    => false,
							'placeholder' => '',
							'name'        => '_whatsapp',
							'class'		  => 'whatsapp-input',
							'priority'    => 10,
							'before_row' 	 => '',
							'after_row' 	 => '',
							'render_row_col' => '4'
						),
						'_skype' => array(
							'label'       => __( '<i class="fa fa-skype"></i> Skype', 'listeo_core' ),
							'type'        => 'text',
							'required'    => false,
							'placeholder' => '',
							'name'        => '_skype',
							'class'		  => 'skype-input',
							'priority'    => 10,
							'before_row' 	 => '',
							'after_row' 	 => '',
							'render_row_col' => '4'
						),
						
						'_price_min' => array(
							'label'       => __( 'Minimum Price Range', 'listeo_core' ),
							'type'        => 'number',
							'required'    => false,
							'placeholder' => '',
							'name'        => '_price_min',
							'tooltip'	  => __('Set only minimum price to show "Prices starts from " instead of range', 'listeo_core'),
							'class'		  => '',
							'before_row' 	 => '',
							'priority'    => 9,
							'render_row_col' => '6',
							'atts' => array(
								'step' => 0.1,
								'min'  => 0,
							),
						),
						'_price_max' => array(
							'label'       => __( 'Maximum Price Range (optional)', 'listeo_core' ),
							'type'        => 'number',
							'required'    => false,
							'placeholder' => '',
							'tooltip'	  => __('Set the maximum price for your service, used on filters in search form', 'listeo_core'),
							'name'        => '_price_max',
							'class'		  => '',
							'after_row' 	 => '</div>',
							'priority'    => 9,
							'render_row_col' => '6',
							'atts' => array(
								'step' => 0.1,
								'min'  => 0,
							),
						),

				),
			),
			
			'opening_hours' => array(
				'title' 	=> __('Opening Hours','listeo_core'),
				'class' 	=> 'margin-top-40',
				'onoff'		=> true,
				'icon' 		=> 'sl sl-icon-clock',
				'fields' 	=> array(
						'_opening_hours_status' => array(
								'label'       => __( 'Opening Hours status', 'listeo_core' ),
								'type'        => 'skipped',
								'required'    => false,
								'name'        => '_opening_hours_status',
						),
						'_opening_hours' => array(
							'label'       => __( 'Opening Hours', 'listeo_core' ),
							'name'       => '_opening_hours',
							'type'        => 'hours',
							'placeholder' => '',
							'class'		  => '',
							'priority'    => 1,
							'required'    => false,
						),	
						'_monday_opening_hour' => array(
							'label'       => __( 'Monday Opening Hour', 'listeo_core' ),
							'type'        => 'skipped',
							'required'    => false,
							'name'        => '_monday_opening_hour',
							'before_row' 	 => '',
							'priority'    => 9,
							'render_row_col' => '4'
						),
						'_monday_closing_hour' => array(
							'label'       => __( 'Monday Opening Hour', 'listeo_core' ),
							'type'        => 'skipped',
							'required'    => false,
							'name'        => '_monday_closing_hour',
							'before_row' 	 => '',
							'priority'    => 9,
							'render_row_col' => '4'
						),	
						'_tuesday_opening_hour' => array(
							'label'       => __( 'Tuesday Opening Hour', 'listeo_core' ),
							'type'        => 'skipped',
							'required'    => false,
							'name'        => '_tuesday_opening_hour',
							'before_row' 	 => '',
							'priority'    => 9,
							'render_row_col' => '4'
						),
						'_tuesday_closing_hour' => array(
							'label'       => __( 'Monday Opening Hour', 'listeo_core' ),
							'type'        => 'skipped',
							'required'    => false,
							'name'        => '_tuesday_closing_hour',
							'before_row' 	 => '',
							'priority'    => 9,
							'render_row_col' => '4'
						),
	
						'_wednesday_opening_hour' => array(
							'label'       => __( 'Wednesday Opening Hour', 'listeo_core' ),
							'type'        => 'skipped',
							'required'    => false,
							'name'        => '_wednesday_opening_hour',
							'before_row' 	 => '',
							'priority'    => 9,
							'render_row_col' => '4'
						),
						'_wednesday_closing_hour' => array(
							'label'       => __( 'Wednesday Opening Hour', 'listeo_core' ),
							'type'        => 'skipped',
							'required'    => false,
							'name'        => '_wednesday_closing_hour',
							'before_row' 	 => '',
							'priority'    => 9,
							'render_row_col' => '4'
						),		
						'_thursday_opening_hour' => array(
							'label'       => __( 'Thursday Opening Hour', 'listeo_core' ),
							'type'        => 'skipped',
							'required'    => false,
							'name'        => '_thursday_opening_hour',
							'before_row' 	 => '',
							'priority'    => 9,
							'render_row_col' => '4'
						),
						'_thursday_closing_hour' => array(
							'label'       => __( 'Thursday Opening Hour', 'listeo_core' ),
							'type'        => 'skipped',
							'required'    => false,
							'name'        => '_thursday_closing_hour',
							'before_row' 	 => '',
							'priority'    => 9,
							'render_row_col' => '4'
						),						
						'_friday_opening_hour' => array(
							'label'       => __( 'Friday Opening Hour', 'listeo_core' ),
							'type'        => 'skipped',
							'required'    => false,
							'name'        => '_friday_opening_hour',
							'before_row' 	 => '',
							'priority'    => 9,
							'render_row_col' => '4'
						),
						'_friday_closing_hour' => array(
							'label'       => __( 'Friday Opening Hour', 'listeo_core' ),
							'type'        => 'skipped',
							'required'    => false,
							'name'        => '_friday_closing_hour',
							'before_row' 	 => '',
							'priority'    => 9,
							'render_row_col' => '4'
						),												
						'_saturday_opening_hour' => array(
							'label'       => __( 'saturday Opening Hour', 'listeo_core' ),
							'type'        => 'skipped',
							'required'    => false,
							'name'        => '_saturday_opening_hour',
							'before_row' 	 => '',
							'priority'    => 9,
							'render_row_col' => '4'
						),
						'_saturday_closing_hour' => array(
							'label'       => __( 'saturday Opening Hour', 'listeo_core' ),
							'type'        => 'skipped',
							'required'    => false,
							'name'        => '_saturday_closing_hour',
							'before_row' 	 => '',
							'priority'    => 9,
							'render_row_col' => '4'
						),														
						'_sunday_opening_hour' => array(
							'label'       => __( 'sunday Opening Hour', 'listeo_core' ),
							'type'        => 'skipped',
							'required'    => false,
							'name'        => '_sunday_opening_hour',
							'before_row' 	 => '',
							'priority'    => 9,
							'render_row_col' => '4'
						),
						'_sunday_closing_hour' => array(
							'label'       => __( 'sunday Opening Hour', 'listeo_core' ),
							'type'        => 'skipped',
							'required'    => false,
							'name'        => '_sunday_closing_hour',
							'before_row' 	 => '',
							'priority'    => 9,
							'render_row_col' => '4'
						),				
						
				),
			),
			'event' => array(
				'title'		=> __( 'Event Date', 'listeo_core' ),
				'class'		=> 'margin-top-40',
				'icon'		=> 'fa fa-money',
				'fields'	=> array(
					'_event_date' => array(
						'label'       => __( 'Event Date', 'listeo_core' ),
						'tooltip'	  => __('Select date when even will start', 'listeo_core'),
						'type'        => 'text',
						'before_row'  => '<div class="row with-forms">',
						'after_row'  => '',
						'required'    => false,
						'name'        => '_event_date',
						'class'		  => 'input-datetime',
						'placeholder' => '',
						'priority'    => 9,
						'render_row_col' => '6'
					),
					'_event_date_end' => array(
						'label'       => __( 'Event Date End', 'listeo_core' ),
						'tooltip'	  => __('Select date when even will end', 'listeo_core'),
						'type'        => 'text',
						'before_row'  => '',
						'after_row'  => '</div>',
						'required'    => false,
						'name'        => '_event_date_end',
						'class'		  => 'input-datetime',
						'placeholder' => '',
						'priority'    => 9,
						'render_row_col' => '6'
					),
					
				)
			),
			'menu' => array(
				'title' 	=> __('Pricing & Bookable Services','listeo_core'),
				'class' 	=> 'margin-top-40',
				'onoff'		=> true,
				'icon' 		=> 'sl sl-icon-book-open',
				'fields' 	=> array(
						'_menu_status' => array(
								'label'       => __( 'Menu status', 'listeo_core' ),
								'type'        => 'skipped',
								'required'    => false,
								'name'        => '_menu_status',
						),
						'_menu' => array(
							'label'       => __( 'Pricing', 'listeo_core' ),
							'name'       => '_menu',
							'type'        => 'pricing',
							'placeholder' => '',
							'class'		  => '',
							'priority'    => 1,
							'required'    => false,
						),	
						'_hide_pricing_if_bookable' => array(
								
								'type'        => 'checkboxes',
								'required'    => false,
								'placeholder' => '',
								'name'        => '_hide_pricing_if_bookable',
								'label'       => '',
								'placeholder' => '',
								'class'		  => '',
								'options'	=> array(
									'hide' => __('Hide pricing table on listing page but show bookable services in booking widget', 'listeo_core' )
								),

							
							
						),	
							
						
				),
			),
			'booking' => array(
				'title' 	=> __('Booking','listeo_core'),
				'class' 	=> 'margin-top-40 booking-enable',
				'onoff'		=> true,
				//'onoff_state' => 'on',
				'icon' 		=> 'fa fa-calendar-check-o',
				'fields' 	=> array(
					'_booking_status' => array(
							'label'       => __( 'Booking status', 'listeo_core' ),
							'type'        => 'skipped',
							'required'    => false,
							'name'        => '_booking_status',
							
					),
				)
			),
			'slots' => array(
				'title' 	=> __('Availability','listeo_core'),
				'class' 	=> 'margin-top-40',
				'onoff'		=> true,
				'icon' 		=> 'fa fa-calendar-check-o',
				'fields' 	=> array(
						'_slots_status' => array(
								'label'       => __( 'Booking status', 'listeo_core' ),
								'type'        => 'skipped',
								'required'    => false,
								'name'        => '_slots_status',
						),
						'_slots' => array(
							'label'       => __( 'Availability Calendar', 'listeo_core' ),
							'name'       => '_slots',
							'type'        => 'slots',
							'placeholder' => '',
							'class'		  => '',
							'priority'    => 1,
							'required'    => false,
						),				
						
				),
			),
			

			'basic_prices' => array(
				'title'		=> __('Booking prices and settings','listeo_core'),
				'class'		=> 'margin-top-40',
				'icon'		=> 'fa fa-money',
				'fields'	=> array(
					
					'_event_tickets' => array(
						'label'       => __( 'Available Tickets', 'listeo_core' ),
						'tooltip'	  => __('How many ticekts you have to offer', 'listeo_core'),
						'type'        => 'number',
						'before_row'  => '<div class="row with-forms">',
						'required'    => false,
						'name'        => '_event_tickets',
						'class'		  => '',
						'placeholder' => '',
						'priority'    => 9,
						'render_row_col' => '6'
					),

					'_normal_price' => array(
						'label'       => __( 'Regular Price', 'listeo_core' ),
						'type'        => 'number',
						'tooltip'	  => __('Default price for booking on Monday - Friday', 'listeo_core'),
						'required'    => false,
						'default'           => '0',
						'placeholder' => '',
						'unit'		  => $currency,
						'name'        => '_normal_price',
						'before_row'  => '<div class="row with-forms">',
						'class'		  => '',
						'priority'    => 10,
						'priority'    => 9,
						'render_row_col' => '6'
						
					),	

					'_weekday_price' => array(
						'label'       => __( 'Weekend Price', 'listeo_core' ),
						'type'        => 'number',
						'required'    => false,
						'tooltip'	  => __('Default price for booking on weekend', 'listeo_core'),
						'placeholder' => '',
						'name'        => '_weekday_price',
						'unit'		  => $currency,
						'class'		  => '',
						'priority'    => 10,
						'priority'    => 9,
						'render_row_col' => '6'
					),	
					'_reservation_price' => array(
						'label'       => __( 'Reservation Fee', 'listeo_core' ),
						'type'        => 'number',
						'required'    => false,
						'name'        => '_reservation_price',
						'tooltip'	  => __('One time fee for booking', 'listeo_core'),
						'placeholder' => '',
						'unit'		  => $currency,
						'default'           => '0',
						'class'		  => '',
						'priority'    => 10,
						'priority'    => 9,
						'render_row_col' => '6'
						
					),				
					'_expired_after' => array(
						'label'       => __( 'Reservation expires after', 'listeo_core' ),
						'tooltip'	  => __('How many hours you can wait for clients payment', 'listeo_core'),
						'type'        => 'number',
						'default'     => '48',
						'required'    => false,
						'name'        => '_expired_after',
						'placeholder' => '',
						'after_row'   => '',
						'class'		  => '',
						'unit'		  => 'hours',
						'priority'    => 10,
						'priority'    => 9,
						'render_row_col' => '6'
					),
						
					'_instant_booking' => array(
						'label'       => __( 'Enable Instant Booking', 'listeo_core' ),
						'type'        => 'checkbox',
						'tooltip'	  => __('With this option enabled booking request will be immediately approved ', 'listeo_core'),
						'required'    => false,
						
						'placeholder' => '',
						'name'        => '_instant_booking',
						'before_row'  => '',
						'after_row'   => '',
						'class'		  => '',
						'priority'    => 10,
						'priority'    => 9,
						'render_row_col' => '6'
					),
					'_max_guests' => array(
						'label'       => __( 'Maximum number of guests', 'listeo_core' ),
						'type'        => 'number',
						'tooltip'	  => __('Set maximum number of guests per reservation', 'listeo_core'),
						'required'    => false,
						'placeholder' => '',
						'name'        => '_max_guests',
						'before_row'  => '',
						'after_row'  => '',
						'class'		  => '',
						'priority'    => 10,
						'priority'    => 9,
						'render_row_col' => '3'
					),	
					'_count_per_guest' => array(
						'label'       => __( 'Enable Price per Guest', 'listeo_core' ),
						'type'        => 'checkbox',
						'tooltip'	  => __('With this option enabled regular price and weekend price will be multiplied by number of guests to estimate total cost', 'listeo_core'),
						'required'    => false,
						
						'placeholder' => '',
						'name'        => '_count_per_guest',
						'before_row'  => '',
						'after_row'   => '</div>',
						'class'		  => '',
						'priority'    => 10,
						'priority'    => 9,
						'render_row_col' => '3'
					),	
						
				),
			),

			'availability_calendar' => array(
				'title' 	=> __('Availability Calendar','listeo_core'),
				'class' 	=> 'margin-top-40',
				//'onoff'		=> true,
				'icon' 		=> 'fa fa-calendar-check-o',
				'fields' 	=> array(
						'_availability' => array(
							'label'       => __( 'Click day in calendar to mark it as unavailable', 'listeo_core' ),
						
							'name'       => '_availability_calendar',
							'type'        => 'calendar',
							'placeholder' => '',
							'class'		  => '',
							'priority'    => 1,
							'required'    => false,
						),				
						
				),
			),

		);
	 		if ( ! empty( $_GET['reset-fields'] ) && ! empty( $_GET['_wpnonce'] ) && wp_verify_nonce( $_GET['_wpnonce'], 'reset' ) ) {
                delete_option("listeo_submit_form_fields");
                echo '<div class="updated"><p>' . __( 'The fields were successfully reset.', 'listeo' ) . '</p></div>';
            }
      


            if ( ! empty( $_POST )) { /* add nonce tu*/
              
                echo $this->form_editor_save(); 
            }
            
	    	$options = get_option("listeo_submit_form_fields");
	        $search_fields = (!empty($options)) ? get_option("listeo_submit_form_fields") : $defaults;

       
         ?>
			<h2>Listeo Submit Form editor</h2>
			<div class="wrap listeo-forms-builder clearfix">
                               
                <form method="post" id="mainform" action="admin.php?page=listeo-submit-builder">
               
                <div class="listeo-forms-builder-left">
                    <div class="form-editor-container" id="listeo-fafe-forms-editor"> 
                        <?php
                        $index = 0;
                        foreach ( $search_fields as $field_key => $field ) {

                            $index++;
                            if(is_array($field)){ ?>
                                <div class="form_item form_item_<?php echo $field_key; ?> form_item_<?php echo $field['type']; ?>" data-priority="<?php echo  $index; ?>">
                                    <span class="handle dashicons dashicons-editor-justify"></span>
                                    <div class="element_title"><?php echo  esc_attr( $field['label'] );  ?>  
                                        <div class="element_title_edit"><span class="dashicons dashicons-edit"></span> Edit</div>
                                    </div>
                                    <?php include( plugin_dir_path( __DIR__  ) .  'views/form-edit-submit.php' ); ?>

                                    <?php if( 
                                    	isset($field['name']) && 
                                    	!in_array( $field['name'], array('property_title','thumbnail','property_description') ) ) { ?>
                                        <div class="remove_item"> Remove </div>
                                    <?php } ?>

                                </div>
                            <?php }
                        }  ?>
                        <div class="droppable-helper"></div>
                    </div>
                  
                    <input type="submit" class="save-fields button-primary" value="<?php _e( 'Save Changes', 'listeo' ); ?>" />
           
                    <a href="<?php echo wp_nonce_url( add_query_arg( 'reset-fields', 1 ), 'reset' ); ?>" class="reset button-secondary"><?php _e( 'Reset to defaults', 'listeo' ); ?></a>
                </div>
                <?php wp_nonce_field( 'save-fields' ); ?>
                <?php wp_nonce_field( 'save'); ?>
        </form>
<div class="listeo-forms-builder-right">
                    <h3>Available Submit Form Elements</h3>
                    
                    <div class="form-editor-available-elements-container">
                        <h4>Visual fields:</h4>
                        <?php 
                        $visual_fields = array(
								'header' => array(
									'name' => __( 'Header', 'listeo' ),
									'id'   => '_header',
									'type' => 'header',
									'desc' => __( '', 'listeo' ),
								),
								'map' => array(
									'name' => __( 'Map', 'listeo' ),
									'id'   => '_map',
									'type' => 'map',
									'desc' => __( '', 'listeo' ),
								),
								'_floorplans' => array(
									'label'       => __( 'Floorplans', 'listeo' ),
									'name'       => __( 'Floorplans', 'listeo' ),
									'id'       => '_floorplans',
									'type'        => 'floorplans',
									'placeholder' => 'Upload floorplans',
								),
								'_gallery' => array(
									'label'       	=> __( 'Gallery', 'listeo' ),
									'name'       	=> __( 'Gallery', 'listeo' ),
									'id'       		=> '_gallery',
									'type'        	=> 'files',
									'description' 	=> __( 'By selecting (clicking on a photo) one of the uploaded photos you will set it as Featured Image for this property (marked by icon with star). Drag and drop thumbnails to re-order images in gallery.', 'listeo' ),
									'placeholder' => 'Upload images',
								),	
						);
                        foreach ($visual_fields as $key => $field) { 
                             $index++;
                        ?>
                        <div class="form_item form_item_<?php echo $key; ?>" data-priority="0">
                            <span class="handle dashicons dashicons-editor-justify"></span>
                             <div class="element_title"><?php echo  esc_attr( $field['name'] );  ?> <div class="element_title_edit"><span class="dashicons dashicons-edit"></span> Edit</div></div>
                            <?php include( plugin_dir_path( __DIR__  ) .  'views/form-edit-submit-ready-regular.php' ); ?>
                            <div class="remove_item"> Remove </div>
                        </div>
                        <?php } 
                        ?>

                        <h4>Taxonomies:</h4>
                        <?php 
                        $taxonomy_objects = get_object_taxonomies( 'property', 'objects' );
                        foreach ($taxonomy_objects as $tax) {
                             $index++;
                        ?>
                        <div class="form_item" data-priority="0">
                            <span class="handle dashicons dashicons-editor-justify"></span>
                            <div class="element_title"><?php echo  esc_attr( $tax->label );  ?> <div class="element_title_edit"><span class="dashicons dashicons-edit"></span> Edit</div></div>
                            <?php include( plugin_dir_path( __DIR__  ) .  'views/form-edit-submit-ready-tax.php' ); ?>
                            <div class="remove_item"> Remove </div>
                        </div>
                        <?php } 
                        ?>
                    
                   
                    <h4>Custom Field</h4>
                    <?php  
                    $price_fields = Listeo_Meta_Boxes::meta_boxes_price();
                    foreach ($price_fields['fields'] as $key => $field) {  $index++;?>
                        <div class="form_item" data-priority="0">
                            <span class="handle dashicons dashicons-editor-justify"></span>
                            <div class="element_title"><?php echo  esc_attr( $field['name'] );  ?> <div class="element_title_edit"><span class="dashicons dashicons-edit"></span> Edit</div></div>
                            <?php  include( plugin_dir_path( __DIR__  ) .  'views/form-edit-submit-ready-field.php' ); ?>
                            <div class="remove_item"> Remove </div>
                        </div>
                        <?php } 
                    ?>               
                    <?php  
                    $main_details = Listeo_Meta_Boxes::meta_boxes_main_details();
                    foreach ($main_details['fields'] as $key => $field) {  $index++;?>
                        <div class="form_item" data-priority="0">
                            <span class="handle dashicons dashicons-editor-justify"></span>
                            <div class="element_title"><?php echo  esc_attr( $field['name'] );  ?> <div class="element_title_edit"><span class="dashicons dashicons-edit"></span> Edit</div></div>
                            <?php  include( plugin_dir_path( __DIR__  ) .  'views/form-edit-submit-ready-field.php' ); ?>
                            <div class="remove_item"> Remove </div>
                        </div>
                        <?php } 
                    ?>                    
                    <?php  
                    $details = Listeo_Meta_Boxes::meta_boxes_details();
                    foreach ($details['fields'] as $key => $field) {  $index++;?>
                        <div class="form_item" data-priority="0">
                            <span class="handle dashicons dashicons-editor-justify"></span>
                            <div class="element_title"><?php echo  esc_attr( $field['name'] );  ?> <div class="element_title_edit"><span class="dashicons dashicons-edit"></span> Edit</div></div>
                            <?php include( plugin_dir_path( __DIR__  ) .  'views/form-edit-submit-ready-field.php' ); ?>
                            <div class="remove_item"> Remove </div>
                        </div>
                        <?php } 
                    ?>                    
                    <?php  
                    $location = Listeo_Meta_Boxes::meta_boxes_location();
                    foreach ($location['fields'] as $key => $field) {  $index++;?>
                        <div class="form_item" data-priority="0">
                            <span class="handle dashicons dashicons-editor-justify"></span>
                            <div class="element_title"><?php echo  esc_attr( $field['name'] );  ?> <div class="element_title_edit"><span class="dashicons dashicons-edit"></span> Edit</div></div>
                            <?php include( plugin_dir_path( __DIR__  ) .  'views/form-edit-submit-ready-field.php' ); ?>
                            <div class="remove_item"> Remove </div>
                        </div>
                        <?php } 
                    ?>
                    </div>

                  
                </div>
                </div>
        <?php
    }

     /**
     * Save the form fields
     */
    private function form_editor_save() {

        $field_type             = ! empty( $_POST['type'] ) ? array_map( 'sanitize_text_field', $_POST['type'] )                    : array();
        $field_name             = ! empty( $_POST['name'] ) ? array_map( 'sanitize_text_field', $_POST['name'] )                    : array();
        $field_label            = ! empty( $_POST['label'] ) ? array_map( 'sanitize_text_field', $_POST['label'] )                  : array();
        $field_multi            = ! empty( $_POST['multi'] ) ? array_map( 'sanitize_text_field', $_POST['multi'] )                  : array();
        $field_placeholder      = ! empty( $_POST['placeholder'] ) ? array_map( 'sanitize_text_field', $_POST['placeholder'] )      : array();
        $field_tooltip      	= ! empty( $_POST['tooltip'] ) ? array_map( 'sanitize_text_field', $_POST['tooltip'] )      : array();
        $field_description      = ! empty( $_POST['description'] ) ? array_map( 'sanitize_text_field', $_POST['description'] )      : array();

        $field_required         = ! empty( $_POST['required'] ) ? array_map( 'sanitize_text_field', $_POST['required'] ) : array();

        $field_render_row_col  = ! empty( $_POST['render_row_col'] ) ? array_map( 'sanitize_text_field', $_POST['render_row_col'] )                  : array();

        $field_class            = ! empty( $_POST['class'] ) ? array_map( 'sanitize_text_field', $_POST['class'] )                  : array();
    
        $field_before_row         = ! empty( $_POST['before_row'] ) ? array_map( 'sanitize_text_field', $_POST['before_row'] )            : array();
        $field_after_row        = ! empty( $_POST['after_row'] ) ? array_map( 'sanitize_text_field', $_POST['after_row'] )          : array();
        
        $field_unit            = ! empty( $_POST['unit'] ) ? array_map( 'sanitize_text_field', $_POST['unit'] )                  : array();

        $field_priority         = ! empty( $_POST['priority'] ) ? array_map( 'sanitize_text_field', $_POST['priority'] )            : array();
       
        $field_taxonomy         = ! empty( $_POST['field_taxonomy'] ) ? array_map( 'sanitize_text_field', $_POST['field_taxonomy'] ): array();
        $field_default         = ! empty( $_POST['default'] ) ? array_map( 'sanitize_text_field', $_POST['default'] ): array();
        
        $field_options_cb       = ! empty( $_POST['options_cb'] ) ? array_map( 'sanitize_text_field', $_POST['options_cb'] )        : array();
        $field_options_source   = ! empty( $_POST['options_source'] ) ? array_map( 'sanitize_text_field', $_POST['options_source'] ): array();
        $field_options          = ! empty( $_POST['options'] ) ? $this->sanitize_array( $_POST['options'] )                         : array();
        $new_fields             = array();
        $index                  = 0;

       foreach ( $field_label as $key => $field ) {
          
      
            $name                = sanitize_title( $field_name[ $key ] );
            $options             = array();
            if(! empty( $field_options[ $key ] )){
                foreach ($field_options[ $key ] as $op_key => $op_value) {
                    $options[$op_value['name']] = $op_value['value'];
                } 
            }
            $new_field                       = array();
            $new_field['type']               = $field_type[ $key ];
            $new_field['name']               = $field_name[ $key ];
            $new_field['multi']              = isset($field_multi[ $key ]) ? $field_multi[ $key ] : false;
            $new_field['label']              = $field_label[ $key ];
            $new_field['placeholder']        = $field_placeholder[ $key ];
            $new_field['tooltip']            = $field_tooltip[ $key ];
            $new_field['description']        = $field_description[ $key ];
            $new_field['class']              = $field_class[ $key ];
            $new_field['render_row_col']     = $field_render_row_col[ $key ];
            $new_field['required']           = isset($field_required[ $key ]) ? $field_required[ $key ] : false;

            $new_field['before_row']         = isset($field_before_row[ $key ]) ? '<div class="row with-forms">' : false;
            $new_field['after_row']          = isset($field_after_row[ $key ]) ? '</div>' : false;
            $new_field['unit']               = $field_unit[ $key ];
            $new_field['taxonomy']           = $field_taxonomy[ $key ];
            $new_field['default']            = $field_default[ $key ];
            $new_field['options_source']     = $field_options_source[ $key ];
            $new_field['options_cb']         = $field_options_cb[ $key ];
            if(!empty($field_options_cb[ $key ])) {
                $new_field['options']           = array();
            } else {
                $new_field['options']           = $options;
            }
            $new_field['priority']           = $index ++;
            
            $new_fields[ $name ]            = $new_field;
            
        }

        $result = update_option( "listeo_submit_form_fields", $new_fields);
        

        if ( true === $result ) {
            echo '<div class="updated"><p>' . __( 'The fields were successfully saved.', 'wp-job-manager-applications' ) . '</p></div>';
        }
      
    }

    /**
     * Sanitize a 2d array
     * @param  array $array
     * @return array
     */
    private function sanitize_array( $input ) {
        if ( is_array( $input ) ) {
            foreach ( $input as $k => $v ) {
                $input[ $k ] = $this->sanitize_array( $v );
            }
            return $input;
        } else {
            return sanitize_text_field( $input );
        }
    }
}