<?php
/**
 * Custom functions that act independently of the theme templates
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package listeo
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function listeo_body_classes( $classes ) {
	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

  $submit_page = get_option('listeo_submit_page');
  if(is_page($submit_page)){
      $classes[] = 'add-listing-dashboard-template';   
  }

  if(!is_user_logged_in()){
      $classes[] = 'user_not_logged_in';
  }
  if( ( is_page_template('template-home-search.php') || is_page_template('template-home-search-splash.php') )  && (get_option('listeo_home_transparent_header') == 'enable')){
      $classes[] = 'transparent-header';   
  } else {
      $classes[] = 'solid-header';   
  }
  if(is_page_template('template-home-search.php')  && (get_option('listeo_home_solid_background') == 'enable')){
      $classes[] = 'solid-bg-home-banner';   
  }

  
  if(is_post_type_archive('listing') && get_option('pp_listings_top_layout') == 'half'){
        $classes[] = 'page-template-template-split-map';   
  }
  if(get_option('listeo_fw_header') || is_page_template('template-home-search-splash.php')){
    $classes[] = 'full-width-header';
  }
  if(get_option('listeo_marker_no_icon') == 'no_icon'){
    $classes[] = 'no-map-marker-icon ';
  }
	return $classes;
}
add_filter( 'body_class', 'listeo_body_classes' );


add_action('pre_user_query', 'my_custom_users_search');
function my_custom_users_search( $args ) {
    if( isset( $args->query_vars['and2or'] ) )
        $args->query_where = str_replace(') AND (', ') OR (', $args->query_where);
}
/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function listeo_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'listeo_pingback_header' );



function workscout_get_rating_class($average) {
     if(!$average) {
               $class="no-stars";
     } else {
          switch ($average) {
               
               case $average >= 1 && $average < 1.5:
                    $class="one-stars";
                    break;
               case $average >= 1.5 && $average < 2:
                    $class="one-and-half-stars";
                    break;
               case $average >= 2 && $average < 2.5:
                    $class="two-stars";
                    break;
               case $average >= 2.5 && $average < 3:
                    $class="two-and-half-stars";
                    break;
               case $average >= 3 && $average < 3.5:
                    $class="three-stars";
                    break;
               case $average >= 3.5 && $average < 4:
                    $class="three-and-half-stars";
                    break;
               case $average >= 4 && $average < 4.5:
                    $class="four-stars";
                    break;
               case $average >= 4.5 && $average < 5:
                    $class="four-and-half-stars";
                    break;
               case $average >= 5:
                    $class="five-stars";
                    break;

               default:
                    $class="no-stars";
                    break;
          }
     }
     return $class;
     }


function wsl_findeo_use_fontawesome_icons( $provider_id, $provider_name, $authenticate_url )
{
   ?>
   <a 
      rel           = "nofollow"
      href          = "<?php echo $authenticate_url; ?>"
      data-provider = "<?php echo $provider_id ?>"
      class         = "wp-social-login-provider wp-social-login-provider-<?php echo strtolower( $provider_id ); ?>" 
    >
      <span>
         <i class="fa fa-<?php echo strtolower( $provider_id ); ?>"></i><?php echo $provider_name; ?>
      </span>
   </a>
<?php
}
 
add_filter( 'wsl_render_auth_widget_alter_provider_icon_markup', 'wsl_findeo_use_fontawesome_icons', 10, 3 );
/**
 * Customize the PageNavi HTML before it is output
 */
add_filter( 'wp_pagenavi', 'listeo_pagination', 10, 2 );
function listeo_pagination($html) {
    $out = '';
    //wrap a's and span's in li's
    
    $out = str_replace("<a","<li><a",$html);
    $out = str_replace("</a>","</a></li>",$out);
    $out = str_replace("<span","<li><span",$out);
    $out = str_replace("</span>","</span></li>",$out);
    $out = str_replace("<div class='wp-pagenavi' role='navigation'>","",$out);
    $out = str_replace("</div>","",$out);
    return '<div class="pagination"><ul>'.$out.'</ul></div>';
}

function listeo_disable_sticky_footer($sticky){
	if(is_404()){
		$sticky = false;
	}
	return $sticky;
}
add_action('listeo_sticky_footer_filter','listeo_disable_sticky_footer');


function get_listeo_icons_dropdown($sel=''){
   // $icons = vc_iconpicker_type_iconsmind(array());
    $output = '<option value="">'.esc_html__('no icon','listeo').'</option>';

    $sl_icons = purethemes_get_simple_line_icons();

    foreach ($sl_icons as $icon) {
       $output .= '<option value="' . esc_attr( $icon ) . '" ' . ( strcmp( $icon, $sel ) === 0 ? 'selected' : '' ) . '>' . esc_html( $icon  ) . '(Simple Line)</option>' . "\n";
    }
  

    return $output;
}


/**
 * FontAwesome icons array
 */
function listeo_fa_icons_list(){
    $icon = array(''=>'empty','500px'=>'500px','adjust'=>'adjust','adn'=>'adn','align-center'=>'align-center','align-justify'=>'align-justify','align-left'=>'align-left','align-right'=>'align-right','amazon'=>'amazon','ambulance'=>'ambulance','american-sign-language-interpreting'=>'american-sign-language-interpreting','anchor'=>'anchor','android'=>'android','angellist'=>'angellist','angle-double-down'=>'angle-double-down','angle-double-left'=>'angle-double-left','angle-double-right'=>'angle-double-right','angle-double-up'=>'angle-double-up','angle-down'=>'angle-down','angle-left'=>'angle-left','angle-right'=>'angle-right','angle-up'=>'angle-up','apple'=>'apple','archive'=>'archive','area-chart'=>'area-chart','arrow-circle-down'=>'arrow-circle-down','arrow-circle-left'=>'arrow-circle-left','arrow-circle-o-down'=>'arrow-circle-o-down','arrow-circle-o-left'=>'arrow-circle-o-left','arrow-circle-o-right'=>'arrow-circle-o-right','arrow-circle-o-up'=>'arrow-circle-o-up','arrow-circle-right'=>'arrow-circle-right','arrow-circle-up'=>'arrow-circle-up','arrow-down'=>'arrow-down','arrow-left'=>'arrow-left','arrow-right'=>'arrow-right','arrow-up'=>'arrow-up','arrows'=>'arrows','arrows-alt'=>'arrows-alt','arrows-h'=>'arrows-h','arrows-v'=>'arrows-v','asl-interpreting'=>'asl-interpreting','assistive-listening-systems'=>'assistive-listening-systems','asterisk'=>'asterisk','at'=>'at','audio-description'=>'audio-description','automobile'=>'automobile','backward'=>'backward','balance-scale'=>'balance-scale','ban'=>'ban','bandcamp'=>'bandcamp','bank'=>'bank','bar-chart'=>'bar-chart','bar-chart-o'=>'bar-chart-o','barcode'=>'barcode','bars'=>'bars','bath'=>'bath','bathtub'=>'bathtub','battery'=>'battery','battery-0'=>'battery-0','battery-1'=>'battery-1','battery-2'=>'battery-2','battery-3'=>'battery-3','battery-4'=>'battery-4','battery-empty'=>'battery-empty','battery-full'=>'battery-full','battery-half'=>'battery-half','battery-quarter'=>'battery-quarter','battery-three-quarters'=>'battery-three-quarters','bed'=>'bed','beer'=>'beer','behance'=>'behance','behance-square'=>'behance-square','bell'=>'bell','bell-o'=>'bell-o','bell-slash'=>'bell-slash','bell-slash-o'=>'bell-slash-o','bicycle'=>'bicycle','binoculars'=>'binoculars','birthday-cake'=>'birthday-cake','bitbucket'=>'bitbucket','bitbucket-square'=>'bitbucket-square','bitcoin'=>'bitcoin','black-tie'=>'black-tie','blind'=>'blind','bluetooth'=>'bluetooth','bluetooth-b'=>'bluetooth-b','bold'=>'bold','bolt'=>'bolt','bomb'=>'bomb','book'=>'book','bookmark'=>'bookmark','bookmark-o'=>'bookmark-o','braille'=>'braille','briefcase'=>'briefcase','btc'=>'btc','bug'=>'bug','building'=>'building','building-o'=>'building-o','bullhorn'=>'bullhorn','bullseye'=>'bullseye','bus'=>'bus','buysellads'=>'buysellads','cab'=>'cab','calculator'=>'calculator','calendar'=>'calendar','calendar-check-o'=>'calendar-check-o','calendar-minus-o'=>'calendar-minus-o','calendar-o'=>'calendar-o','calendar-plus-o'=>'calendar-plus-o','calendar-times-o'=>'calendar-times-o','camera'=>'camera','camera-retro'=>'camera-retro','car'=>'car','caret-down'=>'caret-down','caret-left'=>'caret-left','caret-right'=>'caret-right','caret-square-o-down'=>'caret-square-o-down','caret-square-o-left'=>'caret-square-o-left','caret-square-o-right'=>'caret-square-o-right','caret-square-o-up'=>'caret-square-o-up','caret-up'=>'caret-up','cart-arrow-down'=>'cart-arrow-down','cart-plus'=>'cart-plus','cc'=>'cc','cc-amex'=>'cc-amex','cc-diners-club'=>'cc-diners-club','cc-discover'=>'cc-discover','cc-jcb'=>'cc-jcb','cc-mastercard'=>'cc-mastercard','cc-paypal'=>'cc-paypal','cc-stripe'=>'cc-stripe','cc-visa'=>'cc-visa','certificate'=>'certificate','chain'=>'chain','chain-broken'=>'chain-broken','check'=>'check','check-circle'=>'check-circle','check-circle-o'=>'check-circle-o','check-square'=>'check-square','check-square-o'=>'check-square-o','chevron-circle-down'=>'chevron-circle-down','chevron-circle-left'=>'chevron-circle-left','chevron-circle-right'=>'chevron-circle-right','chevron-circle-up'=>'chevron-circle-up','chevron-down'=>'chevron-down','chevron-left'=>'chevron-left','chevron-right'=>'chevron-right','chevron-up'=>'chevron-up','child'=>'child','chrome'=>'chrome','circle'=>'circle','circle-o'=>'circle-o','circle-o-notch'=>'circle-o-notch','circle-thin'=>'circle-thin','clipboard'=>'clipboard','clock-o'=>'clock-o','clone'=>'clone','close'=>'close','cloud'=>'cloud','cloud-download'=>'cloud-download','cloud-upload'=>'cloud-upload','cny'=>'cny','code'=>'code','code-fork'=>'code-fork','codepen'=>'codepen','codiepie'=>'codiepie','coffee'=>'coffee','cog'=>'cog','cogs'=>'cogs','columns'=>'columns','comment'=>'comment','comment-o'=>'comment-o','commenting'=>'commenting','commenting-o'=>'commenting-o','comments'=>'comments','comments-o'=>'comments-o','compass'=>'compass','compress'=>'compress','connectdevelop'=>'connectdevelop','contao'=>'contao','copy'=>'copy','copyright'=>'copyright','creative-commons'=>'creative-commons','credit-card'=>'credit-card','credit-card-alt'=>'credit-card-alt','crop'=>'crop','crosshairs'=>'crosshairs','css3'=>'css3','cube'=>'cube','cubes'=>'cubes','cut'=>'cut','cutlery'=>'cutlery','dashboard'=>'dashboard','dashcube'=>'dashcube','database'=>'database','deaf'=>'deaf','deafness'=>'deafness','dedent'=>'dedent','delicious'=>'delicious','desktop'=>'desktop','deviantart'=>'deviantart','diamond'=>'diamond','digg'=>'digg','dollar'=>'dollar','dot-circle-o'=>'dot-circle-o','download'=>'download','dribbble'=>'dribbble','drivers-license'=>'drivers-license','drivers-license-o'=>'drivers-license-o','dropbox'=>'dropbox','drupal'=>'drupal','edge'=>'edge','edit'=>'edit','eercast'=>'eercast','eject'=>'eject','ellipsis-h'=>'ellipsis-h','ellipsis-v'=>'ellipsis-v','empire'=>'empire','envelope'=>'envelope','envelope-o'=>'envelope-o','envelope-open'=>'envelope-open','envelope-open-o'=>'envelope-open-o','envelope-square'=>'envelope-square','envira'=>'envira','eraser'=>'eraser','etsy'=>'etsy','eur'=>'eur','euro'=>'euro','exchange'=>'exchange','exclamation'=>'exclamation','exclamation-circle'=>'exclamation-circle','exclamation-triangle'=>'exclamation-triangle','expand'=>'expand','expeditedssl'=>'expeditedssl','external-link'=>'external-link','external-link-square'=>'external-link-square','eye'=>'eye','eye-slash'=>'eye-slash','eyedropper'=>'eyedropper','fa'=>'fa','facebook'=>'facebook','facebook-f'=>'facebook-f','facebook-official'=>'facebook-official','facebook-square'=>'facebook-square','fast-backward'=>'fast-backward','fast-forward'=>'fast-forward','fax'=>'fax','feed'=>'feed','female'=>'female','fighter-jet'=>'fighter-jet','file'=>'file','file-archive-o'=>'file-archive-o','file-audio-o'=>'file-audio-o','file-code-o'=>'file-code-o','file-excel-o'=>'file-excel-o','file-image-o'=>'file-image-o','file-movie-o'=>'file-movie-o','file-o'=>'file-o','file-pdf-o'=>'file-pdf-o','file-photo-o'=>'file-photo-o','file-picture-o'=>'file-picture-o','file-powerpoint-o'=>'file-powerpoint-o','file-sound-o'=>'file-sound-o','file-text'=>'file-text','file-text-o'=>'file-text-o','file-video-o'=>'file-video-o','file-word-o'=>'file-word-o','file-zip-o'=>'file-zip-o','files-o'=>'files-o','film'=>'film','filter'=>'filter','fire'=>'fire','fire-extinguisher'=>'fire-extinguisher','firefox'=>'firefox','first-order'=>'first-order','flag'=>'flag','flag-checkered'=>'flag-checkered','flag-o'=>'flag-o','flash'=>'flash','flask'=>'flask','flickr'=>'flickr','floppy-o'=>'floppy-o','folder'=>'folder','folder-o'=>'folder-o','folder-open'=>'folder-open','folder-open-o'=>'folder-open-o','font'=>'font','font-awesome'=>'font-awesome','fonticons'=>'fonticons','fort-awesome'=>'fort-awesome','forumbee'=>'forumbee','forward'=>'forward','foursquare'=>'foursquare','free-code-camp'=>'free-code-camp','frown-o'=>'frown-o','futbol-o'=>'futbol-o','gamepad'=>'gamepad','gavel'=>'gavel','gbp'=>'gbp','ge'=>'ge','gear'=>'gear','gears'=>'gears','genderless'=>'genderless','get-pocket'=>'get-pocket','gg'=>'gg','gg-circle'=>'gg-circle','gift'=>'gift','git'=>'git','git-square'=>'git-square','github'=>'github','github-alt'=>'github-alt','github-square'=>'github-square','gitlab'=>'gitlab','gittip'=>'gittip','glass'=>'glass','glide'=>'glide','glide-g'=>'glide-g','globe'=>'globe','google'=>'google','google-plus'=>'google-plus','google-plus-circle'=>'google-plus-circle','google-plus-official'=>'google-plus-official','google-plus-square'=>'google-plus-square','google-wallet'=>'google-wallet','graduation-cap'=>'graduation-cap','gratipay'=>'gratipay','grav'=>'grav','group'=>'group','h-square'=>'h-square','hacker-news'=>'hacker-news','hand-grab-o'=>'hand-grab-o','hand-lizard-o'=>'hand-lizard-o','hand-o-down'=>'hand-o-down','hand-o-left'=>'hand-o-left','hand-o-right'=>'hand-o-right','hand-o-up'=>'hand-o-up','hand-paper-o'=>'hand-paper-o','hand-peace-o'=>'hand-peace-o','hand-pointer-o'=>'hand-pointer-o','hand-rock-o'=>'hand-rock-o','hand-scissors-o'=>'hand-scissors-o','hand-spock-o'=>'hand-spock-o','hand-stop-o'=>'hand-stop-o','handshake-o'=>'handshake-o','hard-of-hearing'=>'hard-of-hearing','hashtag'=>'hashtag','hdd-o'=>'hdd-o','header'=>'header','headphones'=>'headphones','heart'=>'heart','heart-o'=>'heart-o','heartbeat'=>'heartbeat','history'=>'history','home'=>'home','hospital-o'=>'hospital-o','hotel'=>'hotel','hourglass'=>'hourglass','hourglass-1'=>'hourglass-1','hourglass-2'=>'hourglass-2','hourglass-3'=>'hourglass-3','hourglass-end'=>'hourglass-end','hourglass-half'=>'hourglass-half','hourglass-o'=>'hourglass-o','hourglass-start'=>'hourglass-start','houzz'=>'houzz','html5'=>'html5','i-cursor'=>'i-cursor','id-badge'=>'id-badge','id-card'=>'id-card','id-card-o'=>'id-card-o','ils'=>'ils','image'=>'image','imdb'=>'imdb','inbox'=>'inbox','indent'=>'indent','industry'=>'industry','info'=>'info','info-circle'=>'info-circle','inr'=>'inr','instagram'=>'instagram','institution'=>'institution','internet-explorer'=>'internet-explorer','intersex'=>'intersex','ioxhost'=>'ioxhost','italic'=>'italic','joomla'=>'joomla','jpy'=>'jpy','jsfiddle'=>'jsfiddle','key'=>'key','keyboard-o'=>'keyboard-o','krw'=>'krw','language'=>'language','laptop'=>'laptop','lastfm'=>'lastfm','lastfm-square'=>'lastfm-square','leaf'=>'leaf','leanpub'=>'leanpub','legal'=>'legal','lemon-o'=>'lemon-o','level-down'=>'level-down','level-up'=>'level-up','life-bouy'=>'life-bouy','life-buoy'=>'life-buoy','life-ring'=>'life-ring','life-saver'=>'life-saver','lightbulb-o'=>'lightbulb-o','line-chart'=>'line-chart','link'=>'link','linkedin'=>'linkedin','linkedin-square'=>'linkedin-square','linode'=>'linode','linux'=>'linux','list'=>'list','list-alt'=>'list-alt','list-ol'=>'list-ol','list-ul'=>'list-ul','location-arrow'=>'location-arrow','lock'=>'lock','long-arrow-down'=>'long-arrow-down','long-arrow-left'=>'long-arrow-left','long-arrow-right'=>'long-arrow-right','long-arrow-up'=>'long-arrow-up','low-vision'=>'low-vision','magic'=>'magic','magnet'=>'magnet','mail-forward'=>'mail-forward','mail-reply'=>'mail-reply','mail-reply-all'=>'mail-reply-all','male'=>'male','map'=>'map','map-marker'=>'map-marker','map-o'=>'map-o','map-pin'=>'map-pin','map-signs'=>'map-signs','mars'=>'mars','mars-double'=>'mars-double','mars-stroke'=>'mars-stroke','mars-stroke-h'=>'mars-stroke-h','mars-stroke-v'=>'mars-stroke-v','maxcdn'=>'maxcdn','meanpath'=>'meanpath','medium'=>'medium','medkit'=>'medkit','meetup'=>'meetup','meh-o'=>'meh-o','mercury'=>'mercury','microchip'=>'microchip','microphone'=>'microphone','microphone-slash'=>'microphone-slash','minus'=>'minus','minus-circle'=>'minus-circle','minus-square'=>'minus-square','minus-square-o'=>'minus-square-o','mixcloud'=>'mixcloud','mobile'=>'mobile','mobile-phone'=>'mobile-phone','modx'=>'modx','money'=>'money','moon-o'=>'moon-o','mortar-board'=>'mortar-board','motorcycle'=>'motorcycle','mouse-pointer'=>'mouse-pointer','music'=>'music','navicon'=>'navicon','neuter'=>'neuter','newspaper-o'=>'newspaper-o','object-group'=>'object-group','object-ungroup'=>'object-ungroup','odnoklassniki'=>'odnoklassniki','odnoklassniki-square'=>'odnoklassniki-square','opencart'=>'opencart','openid'=>'openid','opera'=>'opera','optin-monster'=>'optin-monster','outdent'=>'outdent','pagelines'=>'pagelines','paint-brush'=>'paint-brush','paper-plane'=>'paper-plane','paper-plane-o'=>'paper-plane-o','paperclip'=>'paperclip','paragraph'=>'paragraph','paste'=>'paste','pause'=>'pause','pause-circle'=>'pause-circle','pause-circle-o'=>'pause-circle-o','paw'=>'paw','paypal'=>'paypal','pencil'=>'pencil','pencil-square'=>'pencil-square','pencil-square-o'=>'pencil-square-o','percent'=>'percent','phone'=>'phone','phone-square'=>'phone-square','photo'=>'photo','picture-o'=>'picture-o','pie-chart'=>'pie-chart','pied-piper'=>'pied-piper','pied-piper-alt'=>'pied-piper-alt','pied-piper-pp'=>'pied-piper-pp','pinterest'=>'pinterest','pinterest-p'=>'pinterest-p','pinterest-square'=>'pinterest-square','plane'=>'plane','play'=>'play','play-circle'=>'play-circle','play-circle-o'=>'play-circle-o','plug'=>'plug','plus'=>'plus','plus-circle'=>'plus-circle','plus-square'=>'plus-square','plus-square-o'=>'plus-square-o','podcast'=>'podcast','power-off'=>'power-off','print'=>'print','product-hunt'=>'product-hunt','puzzle-piece'=>'puzzle-piece','qq'=>'qq','qrcode'=>'qrcode','question'=>'question','question-circle'=>'question-circle','question-circle-o'=>'question-circle-o','quora'=>'quora','quote-left'=>'quote-left','quote-right'=>'quote-right','ra'=>'ra','random'=>'random','ravelry'=>'ravelry','rebel'=>'rebel','recycle'=>'recycle','reddit'=>'reddit','reddit-alien'=>'reddit-alien','reddit-square'=>'reddit-square','refresh'=>'refresh','registered'=>'registered','remove'=>'remove','renren'=>'renren','reorder'=>'reorder','repeat'=>'repeat','reply'=>'reply','reply-all'=>'reply-all','resistance'=>'resistance','retweet'=>'retweet','rmb'=>'rmb','road'=>'road','rocket'=>'rocket','rotate-left'=>'rotate-left','rotate-right'=>'rotate-right','rouble'=>'rouble','rss'=>'rss','rss-square'=>'rss-square','rub'=>'rub','ruble'=>'ruble','rupee'=>'rupee','s15'=>'s15','safari'=>'safari','save'=>'save','scissors'=>'scissors','scribd'=>'scribd','search'=>'search','search-minus'=>'search-minus','search-plus'=>'search-plus','sellsy'=>'sellsy','send'=>'send','send-o'=>'send-o','server'=>'server','share'=>'share','share-alt'=>'share-alt','share-alt-square'=>'share-alt-square','share-square'=>'share-square','share-square-o'=>'share-square-o','shekel'=>'shekel','sheqel'=>'sheqel','shield'=>'shield','ship'=>'ship','shirtsinbulk'=>'shirtsinbulk','shopping-bag'=>'shopping-bag','shopping-basket'=>'shopping-basket','shopping-cart'=>'shopping-cart','shower'=>'shower','sign-in'=>'sign-in','sign-language'=>'sign-language','sign-out'=>'sign-out','signal'=>'signal','signing'=>'signing','simplybuilt'=>'simplybuilt','sitemap'=>'sitemap','skyatlas'=>'skyatlas','skype'=>'skype','slack'=>'slack','sliders'=>'sliders','slideshare'=>'slideshare','smile-o'=>'smile-o','snapchat'=>'snapchat','snapchat-ghost'=>'snapchat-ghost','snapchat-square'=>'snapchat-square','snowflake-o'=>'snowflake-o','soccer-ball-o'=>'soccer-ball-o','sort'=>'sort','sort-alpha-asc'=>'sort-alpha-asc','sort-alpha-desc'=>'sort-alpha-desc','sort-amount-asc'=>'sort-amount-asc','sort-amount-desc'=>'sort-amount-desc','sort-asc'=>'sort-asc','sort-desc'=>'sort-desc','sort-down'=>'sort-down','sort-numeric-asc'=>'sort-numeric-asc','sort-numeric-desc'=>'sort-numeric-desc','sort-up'=>'sort-up','soundcloud'=>'soundcloud','space-shuttle'=>'space-shuttle','spinner'=>'spinner','spoon'=>'spoon','spotify'=>'spotify','square'=>'square','square-o'=>'square-o','stack-exchange'=>'stack-exchange','stack-overflow'=>'stack-overflow','star'=>'star','star-half'=>'star-half','star-half-empty'=>'star-half-empty','star-half-full'=>'star-half-full','star-half-o'=>'star-half-o','star-o'=>'star-o','steam'=>'steam','steam-square'=>'steam-square','step-backward'=>'step-backward','step-forward'=>'step-forward','stethoscope'=>'stethoscope','sticky-note'=>'sticky-note','sticky-note-o'=>'sticky-note-o','stop'=>'stop','stop-circle'=>'stop-circle','stop-circle-o'=>'stop-circle-o','street-view'=>'street-view','strikethrough'=>'strikethrough','stumbleupon'=>'stumbleupon','stumbleupon-circle'=>'stumbleupon-circle','subscript'=>'subscript','subway'=>'subway','suitcase'=>'suitcase','sun-o'=>'sun-o','superpowers'=>'superpowers','superscript'=>'superscript','support'=>'support','table'=>'table','tablet'=>'tablet','tachometer'=>'tachometer','tag'=>'tag','tags'=>'tags','tasks'=>'tasks','taxi'=>'taxi','telegram'=>'telegram','television'=>'television','tencent-weibo'=>'tencent-weibo','terminal'=>'terminal','text-height'=>'text-height','text-width'=>'text-width','th'=>'th','th-large'=>'th-large','th-list'=>'th-list','themeisle'=>'themeisle','thermometer'=>'thermometer','thermometer-0'=>'thermometer-0','thermometer-1'=>'thermometer-1','thermometer-2'=>'thermometer-2','thermometer-3'=>'thermometer-3','thermometer-4'=>'thermometer-4','thermometer-empty'=>'thermometer-empty','thermometer-full'=>'thermometer-full','thermometer-half'=>'thermometer-half','thermometer-quarter'=>'thermometer-quarter','thermometer-three-quarters'=>'thermometer-three-quarters','thumb-tack'=>'thumb-tack','thumbs-down'=>'thumbs-down','thumbs-o-down'=>'thumbs-o-down','thumbs-o-up'=>'thumbs-o-up','thumbs-up'=>'thumbs-up','ticket'=>'ticket','times'=>'times','times-circle'=>'times-circle','times-circle-o'=>'times-circle-o','times-rectangle'=>'times-rectangle','times-rectangle-o'=>'times-rectangle-o','tint'=>'tint','toggle-down'=>'toggle-down','toggle-left'=>'toggle-left','toggle-off'=>'toggle-off','toggle-on'=>'toggle-on','toggle-right'=>'toggle-right','toggle-up'=>'toggle-up','trademark'=>'trademark','train'=>'train','transgender'=>'transgender','transgender-alt'=>'transgender-alt','trash'=>'trash','trash-o'=>'trash-o','tree'=>'tree','trello'=>'trello','tripadvisor'=>'tripadvisor','trophy'=>'trophy','truck'=>'truck','try'=>'try','tty'=>'tty','tumblr'=>'tumblr','tumblr-square'=>'tumblr-square','turkish-lira'=>'turkish-lira','tv'=>'tv','twitch'=>'twitch','twitter'=>'twitter','twitter-square'=>'twitter-square','umbrella'=>'umbrella','underline'=>'underline','undo'=>'undo','universal-access'=>'universal-access','university'=>'university','unlink'=>'unlink','unlock'=>'unlock','unlock-alt'=>'unlock-alt','unsorted'=>'unsorted','upload'=>'upload','usb'=>'usb','usd'=>'usd','user'=>'user','user-circle'=>'user-circle','user-circle-o'=>'user-circle-o','user-md'=>'user-md','user-o'=>'user-o','user-plus'=>'user-plus','user-secret'=>'user-secret','user-times'=>'user-times','users'=>'users','vcard'=>'vcard','vcard-o'=>'vcard-o','venus'=>'venus','venus-double'=>'venus-double','venus-mars'=>'venus-mars','viacoin'=>'viacoin','viadeo'=>'viadeo','viadeo-square'=>'viadeo-square','video-camera'=>'video-camera','vimeo'=>'vimeo','vimeo-square'=>'vimeo-square','vine'=>'vine','vk'=>'vk','volume-control-phone'=>'volume-control-phone','volume-down'=>'volume-down','volume-off'=>'volume-off','volume-up'=>'volume-up','warning'=>'warning','wechat'=>'wechat','weibo'=>'weibo','weixin'=>'weixin','whatsapp'=>'whatsapp','wheelchair'=>'wheelchair','wheelchair-alt'=>'wheelchair-alt','wifi'=>'wifi','wikipedia-w'=>'wikipedia-w','window-close'=>'window-close','window-close-o'=>'window-close-o','window-maximize'=>'window-maximize','window-minimize'=>'window-minimize','window-restore'=>'window-restore','windows'=>'windows','won'=>'won','wordpress'=>'wordpress','wpbeginner'=>'wpbeginner','wpexplorer'=>'wpexplorer','wpforms'=>'wpforms','wrench'=>'wrench','xing'=>'xing','xing-square'=>'xing-square','y-combinator'=>'y-combinator','y-combinator-square'=>'y-combinator-square','yahoo'=>'yahoo','yc'=>'yc','yc-square'=>'yc-square','yelp'=>'yelp','yen'=>'yen','yoast'=>'yoast','youtube'=>'youtube','youtube-play'=>'youtube-play','youtube-square'=>'youtube-square');
    return $icon;
}

function purethemes_get_simple_line_icons(){
    return array(
          'user',
          'people',
          'user-female',
          'user-follow',
          'user-following',
          'user-unfollow',
          'login',
          'logout',
          'emotsmile',
          'phone',
          'call-end',
          'call-in',
          'call-out',
          'map',
          'location',
          'direction',
          'directions',
          'compass',
          'layers',
          'menu',
          'list',
          'options-vertical',
          'options',
          'arrow-down',
          'arrow-left',
          'arrow-right',
          'arrow-up',
          'arrow-up-circle',
          'arrow-left-circle',
          'arrow-right-circle',
          'arrow-down-circle',
          'check',
          'clock',
          'plus',
          'minus',
          'close',
          'exclamation',
          'organization',
          'trophy',
          'screen-smartphone',
          'screen-desktop',
          'plane',
          'notebook',
          'mustache',
          'mouse',
          'magnet',
          'energy',
          'disc',
          'cursor',
          'cursor-move',
          'crop',
          'chemistry',
          'speedometer',
          'shield',
          'screen-tablet',
          'magic-wand',
          'hourglass',
          'graduation',
          'ghost',
          'game-controller',
          'fire',
          'eyeglass',
          'envelope-open',
          'envelope-letter',
          'bell',
          'badge',
          'anchor',
          'wallet',
          'vector',
          'speech',
          'puzzle',
          'printer',
          'present',
          'playlist',
          'pin',
          'picture',
          'handbag',
          'globe-alt',
          'globe',
          'folder-alt',
          'folder',
          'film',
          'feed',
          'drop',
          'drawer',
          'docs',
          'doc',
          'diamond',
          'cup',
          'calculator',
          'bubbles',
          'briefcase',
          'book-open',
          'basket-loaded',
          'basket',
          'bag',
          'action-undo',
          'action-redo',
          'wrench',
          'umbrella',
          'trash',
          'tag',
          'support',
          'frame',
          'size-fullscreen',
          'size-actual',
          'shuffle',
          'share-alt',
          'share',
          'rocket',
          'question',
          'pie-chart',
          'pencil',
          'note',
          'loop',
          'home',
          'grid',
          'graph',
          'microphone',
          'music-tone-alt',
          'music-tone',
          'earphones-alt',
          'earphones',
          'equalizer',
          'like',
          'dislike',
          'control-start',
          'control-rewind',
          'control-play',
          'control-pause',
          'control-forward',
          'control-end',
          'volume-1',
          'volume-2',
          'volume-off',
          'calendar',
          'bulb',
          'chart',
          'ban',
          'bubble',
          'camrecorder',
          'camera',
          'cloud-download',
          'cloud-upload',
          'envelope',
          'eye',
          'flag',
          'heart',
          'info',
          'key',
          'link',
          'lock',
          'lock-open',
          'magnifier',
          'magnifier-add',
          'magnifier-remove',
          'paper-clip',
          'paper-plane',
          'power',
          'refresh',
          'reload',
          'settings',
          'star',
          'symbol-female',
          'symbol-male',
          'target',
          'credit-card',
          'paypal',
          'social-tumblr',
          'social-twitter',
          'social-facebook',
          'social-instagram',
          'social-linkedin',
          'social-pinterest',
          'social-github',
          'social-google',
          'social-reddit',
          'social-skype',
          'social-dribbble',
          'social-behance',
          'social-foursqare',
          'social-soundcloud',
          'social-spotify',
          'social-stumbleupon',
          'social-youtube',
          'social-dropbox',
  );
}


function vc_iconpicker_type_iconsmind( $icons ){
$iconsmind_icons = array(
array( '' => 'empty' ), array( 'im im-icon-A-Z' => 'A-Z' ),array( 'im im-icon-Aa' => 'Aa' ),array( 'im im-icon-Add-Bag' => 'Add-Bag' ),array( 'im im-icon-Add-Basket' => 'Add-Basket' ),array( 'im im-icon-Add-Cart' => 'Add-Cart' ),array( 'im im-icon-Add-File' => 'Add-File' ),array( 'im im-icon-Add-SpaceAfterParagraph' => 'Add-SpaceAfterParagraph' ),array( 'im im-icon-Add-SpaceBeforeParagraph' => 'Add-SpaceBeforeParagraph' ),array( 'im im-icon-Add-User' => 'Add-User' ),array( 'im im-icon-Add-UserStar' => 'Add-UserStar' ),array( 'im im-icon-Add-Window' => 'Add-Window' ),array( 'im im-icon-Add' => 'Add' ),array( 'im im-icon-Address-Book' => 'Address-Book' ),array( 'im im-icon-Address-Book2' => 'Address-Book2' ),array( 'im im-icon-Administrator' => 'Administrator' ),array( 'im im-icon-Aerobics-2' => 'Aerobics-2' ),array( 'im im-icon-Aerobics-3' => 'Aerobics-3' ),array( 'im im-icon-Aerobics' => 'Aerobics' ),array( 'im im-icon-Affiliate' => 'Affiliate' ),array( 'im im-icon-Aim' => 'Aim' ),array( 'im im-icon-Air-Balloon' => 'Air-Balloon' ),array( 'im im-icon-Airbrush' => 'Airbrush' ),array( 'im im-icon-Airship' => 'Airship' ),array( 'im im-icon-Alarm-Clock' => 'Alarm-Clock' ),array( 'im im-icon-Alarm-Clock2' => 'Alarm-Clock2' ),array( 'im im-icon-Alarm' => 'Alarm' ),array( 'im im-icon-Alien-2' => 'Alien-2' ),array( 'im im-icon-Alien' => 'Alien' ),array( 'im im-icon-Aligator' => 'Aligator' ),array( 'im im-icon-Align-Center' => 'Align-Center' ),array( 'im im-icon-Align-JustifyAll' => 'Align-JustifyAll' ),array( 'im im-icon-Align-JustifyCenter' => 'Align-JustifyCenter' ),array( 'im im-icon-Align-JustifyLeft' => 'Align-JustifyLeft' ),array( 'im im-icon-Align-JustifyRight' => 'Align-JustifyRight' ),array( 'im im-icon-Align-Left' => 'Align-Left' ),array( 'im im-icon-Align-Right' => 'Align-Right' ),array( 'im im-icon-Alpha' => 'Alpha' ),array( 'im im-icon-Ambulance' => 'Ambulance' ),array( 'im im-icon-AMX' => 'AMX' ),array( 'im im-icon-Anchor-2' => 'Anchor-2' ),array( 'im im-icon-Anchor' => 'Anchor' ),array( 'im im-icon-Android-Store' => 'Android-Store' ),array( 'im im-icon-Android' => 'Android' ),array( 'im im-icon-Angel-Smiley' => 'Angel-Smiley' ),array( 'im im-icon-Angel' => 'Angel' ),array( 'im im-icon-Angry' => 'Angry' ),array( 'im im-icon-Apple-Bite' => 'Apple-Bite' ),array( 'im im-icon-Apple-Store' => 'Apple-Store' ),array( 'im im-icon-Apple' => 'Apple' ),array( 'im im-icon-Approved-Window' => 'Approved-Window' ),array( 'im im-icon-Aquarius-2' => 'Aquarius-2' ),array( 'im im-icon-Aquarius' => 'Aquarius' ),array( 'im im-icon-Archery-2' => 'Archery-2' ),array( 'im im-icon-Archery' => 'Archery' ),array( 'im im-icon-Argentina' => 'Argentina' ),array( 'im im-icon-Aries-2' => 'Aries-2' ),array( 'im im-icon-Aries' => 'Aries' ),array( 'im im-icon-Army-Key' => 'Army-Key' ),array( 'im im-icon-Arrow-Around' => 'Arrow-Around' ),array( 'im im-icon-Arrow-Back3' => 'Arrow-Back3' ),array( 'im im-icon-Arrow-Back' => 'Arrow-Back' ),array( 'im im-icon-Arrow-Back2' => 'Arrow-Back2' ),array( 'im im-icon-Arrow-Barrier' => 'Arrow-Barrier' ),array( 'im im-icon-Arrow-Circle' => 'Arrow-Circle' ),array( 'im im-icon-Arrow-Cross' => 'Arrow-Cross' ),array( 'im im-icon-Arrow-Down' => 'Arrow-Down' ),array( 'im im-icon-Arrow-Down2' => 'Arrow-Down2' ),array( 'im im-icon-Arrow-Down3' => 'Arrow-Down3' ),array( 'im im-icon-Arrow-DowninCircle' => 'Arrow-DowninCircle' ),array( 'im im-icon-Arrow-Fork' => 'Arrow-Fork' ),array( 'im im-icon-Arrow-Forward' => 'Arrow-Forward' ),array( 'im im-icon-Arrow-Forward2' => 'Arrow-Forward2' ),array( 'im im-icon-Arrow-From' => 'Arrow-From' ),array( 'im im-icon-Arrow-Inside' => 'Arrow-Inside' ),array( 'im im-icon-Arrow-Inside45' => 'Arrow-Inside45' ),array( 'im im-icon-Arrow-InsideGap' => 'Arrow-InsideGap' ),array( 'im im-icon-Arrow-InsideGap45' => 'Arrow-InsideGap45' ),array( 'im im-icon-Arrow-Into' => 'Arrow-Into' ),array( 'im im-icon-Arrow-Join' => 'Arrow-Join' ),array( 'im im-icon-Arrow-Junction' => 'Arrow-Junction' ),array( 'im im-icon-Arrow-Left' => 'Arrow-Left' ),array( 'im im-icon-Arrow-Left2' => 'Arrow-Left2' ),array( 'im im-icon-Arrow-LeftinCircle' => 'Arrow-LeftinCircle' ),array( 'im im-icon-Arrow-Loop' => 'Arrow-Loop' ),array( 'im im-icon-Arrow-Merge' => 'Arrow-Merge' ),array( 'im im-icon-Arrow-Mix' => 'Arrow-Mix' ),array( 'im im-icon-Arrow-Next' => 'Arrow-Next' ),array( 'im im-icon-Arrow-OutLeft' => 'Arrow-OutLeft' ),array( 'im im-icon-Arrow-OutRight' => 'Arrow-OutRight' ),array( 'im im-icon-Arrow-Outside' => 'Arrow-Outside' ),array( 'im im-icon-Arrow-Outside45' => 'Arrow-Outside45' ),array( 'im im-icon-Arrow-OutsideGap' => 'Arrow-OutsideGap' ),array( 'im im-icon-Arrow-OutsideGap45' => 'Arrow-OutsideGap45' ),array( 'im im-icon-Arrow-Over' => 'Arrow-Over' ),array( 'im im-icon-Arrow-Refresh' => 'Arrow-Refresh' ),array( 'im im-icon-Arrow-Refresh2' => 'Arrow-Refresh2' ),array( 'im im-icon-Arrow-Right' => 'Arrow-Right' ),array( 'im im-icon-Arrow-Right2' => 'Arrow-Right2' ),array( 'im im-icon-Arrow-RightinCircle' => 'Arrow-RightinCircle' ),array( 'im im-icon-Arrow-Shuffle' => 'Arrow-Shuffle' ),array( 'im im-icon-Arrow-Squiggly' => 'Arrow-Squiggly' ),array( 'im im-icon-Arrow-Through' => 'Arrow-Through' ),array( 'im im-icon-Arrow-To' => 'Arrow-To' ),array( 'im im-icon-Arrow-TurnLeft' => 'Arrow-TurnLeft' ),array( 'im im-icon-Arrow-TurnRight' => 'Arrow-TurnRight' ),array( 'im im-icon-Arrow-Up' => 'Arrow-Up' ),array( 'im im-icon-Arrow-Up2' => 'Arrow-Up2' ),array( 'im im-icon-Arrow-Up3' => 'Arrow-Up3' ),array( 'im im-icon-Arrow-UpinCircle' => 'Arrow-UpinCircle' ),array( 'im im-icon-Arrow-XLeft' => 'Arrow-XLeft' ),array( 'im im-icon-Arrow-XRight' => 'Arrow-XRight' ),array( 'im im-icon-Ask' => 'Ask' ),array( 'im im-icon-Assistant' => 'Assistant' ),array( 'im im-icon-Astronaut' => 'Astronaut' ),array( 'im im-icon-At-Sign' => 'At-Sign' ),array( 'im im-icon-ATM' => 'ATM' ),array( 'im im-icon-Atom' => 'Atom' ),array( 'im im-icon-Audio' => 'Audio' ),array( 'im im-icon-Auto-Flash' => 'Auto-Flash' ),array( 'im im-icon-Autumn' => 'Autumn' ),array( 'im im-icon-Baby-Clothes' => 'Baby-Clothes' ),array( 'im im-icon-Baby-Clothes2' => 'Baby-Clothes2' ),array( 'im im-icon-Baby-Cry' => 'Baby-Cry' ),array( 'im im-icon-Baby' => 'Baby' ),array( 'im im-icon-Back2' => 'Back2' ),array( 'im im-icon-Back-Media' => 'Back-Media' ),array( 'im im-icon-Back-Music' => 'Back-Music' ),array( 'im im-icon-Back' => 'Back' ),array( 'im im-icon-Background' => 'Background' ),array( 'im im-icon-Bacteria' => 'Bacteria' ),array( 'im im-icon-Bag-Coins' => 'Bag-Coins' ),array( 'im im-icon-Bag-Items' => 'Bag-Items' ),array( 'im im-icon-Bag-Quantity' => 'Bag-Quantity' ),array( 'im im-icon-Bag' => 'Bag' ),array( 'im im-icon-Bakelite' => 'Bakelite' ),array( 'im im-icon-Ballet-Shoes' => 'Ballet-Shoes' ),array( 'im im-icon-Balloon' => 'Balloon' ),array( 'im im-icon-Banana' => 'Banana' ),array( 'im im-icon-Band-Aid' => 'Band-Aid' ),array( 'im im-icon-Bank' => 'Bank' ),array( 'im im-icon-Bar-Chart' => 'Bar-Chart' ),array( 'im im-icon-Bar-Chart2' => 'Bar-Chart2' ),array( 'im im-icon-Bar-Chart3' => 'Bar-Chart3' ),array( 'im im-icon-Bar-Chart4' => 'Bar-Chart4' ),array( 'im im-icon-Bar-Chart5' => 'Bar-Chart5' ),array( 'im im-icon-Bar-Code' => 'Bar-Code' ),array( 'im im-icon-Barricade-2' => 'Barricade-2' ),array( 'im im-icon-Barricade' => 'Barricade' ),array( 'im im-icon-Baseball' => 'Baseball' ),array( 'im im-icon-Basket-Ball' => 'Basket-Ball' ),array( 'im im-icon-Basket-Coins' => 'Basket-Coins' ),array( 'im im-icon-Basket-Items' => 'Basket-Items' ),array( 'im im-icon-Basket-Quantity' => 'Basket-Quantity' ),array( 'im im-icon-Bat-2' => 'Bat-2' ),array( 'im im-icon-Bat' => 'Bat' ),array( 'im im-icon-Bathrobe' => 'Bathrobe' ),array( 'im im-icon-Batman-Mask' => 'Batman-Mask' ),array( 'im im-icon-Battery-0' => 'Battery-0' ),array( 'im im-icon-Battery-25' => 'Battery-25' ),array( 'im im-icon-Battery-50' => 'Battery-50' ),array( 'im im-icon-Battery-75' => 'Battery-75' ),array( 'im im-icon-Battery-100' => 'Battery-100' ),array( 'im im-icon-Battery-Charge' => 'Battery-Charge' ),array( 'im im-icon-Bear' => 'Bear' ),array( 'im im-icon-Beard-2' => 'Beard-2' ),array( 'im im-icon-Beard-3' => 'Beard-3' ),array( 'im im-icon-Beard' => 'Beard' ),array( 'im im-icon-Bebo' => 'Bebo' ),array( 'im im-icon-Bee' => 'Bee' ),array( 'im im-icon-Beer-Glass' => 'Beer-Glass' ),array( 'im im-icon-Beer' => 'Beer' ),array( 'im im-icon-Bell-2' => 'Bell-2' ),array( 'im im-icon-Bell' => 'Bell' ),array( 'im im-icon-Belt-2' => 'Belt-2' ),array( 'im im-icon-Belt-3' => 'Belt-3' ),array( 'im im-icon-Belt' => 'Belt' ),array( 'im im-icon-Berlin-Tower' => 'Berlin-Tower' ),array( 'im im-icon-Beta' => 'Beta' ),array( 'im im-icon-Betvibes' => 'Betvibes' ),array( 'im im-icon-Bicycle-2' => 'Bicycle-2' ),array( 'im im-icon-Bicycle-3' => 'Bicycle-3' ),array( 'im im-icon-Bicycle' => 'Bicycle' ),array( 'im im-icon-Big-Bang' => 'Big-Bang' ),array( 'im im-icon-Big-Data' => 'Big-Data' ),array( 'im im-icon-Bike-Helmet' => 'Bike-Helmet' ),array( 'im im-icon-Bikini' => 'Bikini' ),array( 'im im-icon-Bilk-Bottle2' => 'Bilk-Bottle2' ),array( 'im im-icon-Billing' => 'Billing' ),array( 'im im-icon-Bing' => 'Bing' ),array( 'im im-icon-Binocular' => 'Binocular' ),array( 'im im-icon-Bio-Hazard' => 'Bio-Hazard' ),array( 'im im-icon-Biotech' => 'Biotech' ),array( 'im im-icon-Bird-DeliveringLetter' => 'Bird-DeliveringLetter' ),array( 'im im-icon-Bird' => 'Bird' ),array( 'im im-icon-Birthday-Cake' => 'Birthday-Cake' ),array( 'im im-icon-Bisexual' => 'Bisexual' ),array( 'im im-icon-Bishop' => 'Bishop' ),array( 'im im-icon-Bitcoin' => 'Bitcoin' ),array( 'im im-icon-Black-Cat' => 'Black-Cat' ),array( 'im im-icon-Blackboard' => 'Blackboard' ),array( 'im im-icon-Blinklist' => 'Blinklist' ),array( 'im im-icon-Block-Cloud' => 'Block-Cloud' ),array( 'im im-icon-Block-Window' => 'Block-Window' ),array( 'im im-icon-Blogger' => 'Blogger' ),array( 'im im-icon-Blood' => 'Blood' ),array( 'im im-icon-Blouse' => 'Blouse' ),array( 'im im-icon-Blueprint' => 'Blueprint' ),array( 'im im-icon-Board' => 'Board' ),array( 'im im-icon-Bodybuilding' => 'Bodybuilding' ),array( 'im im-icon-Bold-Text' => 'Bold-Text' ),array( 'im im-icon-Bone' => 'Bone' ),array( 'im im-icon-Bones' => 'Bones' ),array( 'im im-icon-Book' => 'Book' ),array( 'im im-icon-Bookmark' => 'Bookmark' ),array( 'im im-icon-Books-2' => 'Books-2' ),array( 'im im-icon-Books' => 'Books' ),array( 'im im-icon-Boom' => 'Boom' ),array( 'im im-icon-Boot-2' => 'Boot-2' ),array( 'im im-icon-Boot' => 'Boot' ),array( 'im im-icon-Bottom-ToTop' => 'Bottom-ToTop' ),array( 'im im-icon-Bow-2' => 'Bow-2' ),array( 'im im-icon-Bow-3' => 'Bow-3' ),array( 'im im-icon-Bow-4' => 'Bow-4' ),array( 'im im-icon-Bow-5' => 'Bow-5' ),array( 'im im-icon-Bow-6' => 'Bow-6' ),array( 'im im-icon-Bow' => 'Bow' ),array( 'im im-icon-Bowling-2' => 'Bowling-2' ),array( 'im im-icon-Bowling' => 'Bowling' ),array( 'im im-icon-Box2' => 'Box2' ),array( 'im im-icon-Box-Close' => 'Box-Close' ),array( 'im im-icon-Box-Full' => 'Box-Full' ),array( 'im im-icon-Box-Open' => 'Box-Open' ),array( 'im im-icon-Box-withFolders' => 'Box-withFolders' ),array( 'im im-icon-Box' => 'Box' ),array( 'im im-icon-Boy' => 'Boy' ),array( 'im im-icon-Bra' => 'Bra' ),array( 'im im-icon-Brain-2' => 'Brain-2' ),array( 'im im-icon-Brain-3' => 'Brain-3' ),array( 'im im-icon-Brain' => 'Brain' ),array( 'im im-icon-Brazil' => 'Brazil' ),array( 'im im-icon-Bread-2' => 'Bread-2' ),array( 'im im-icon-Bread' => 'Bread' ),array( 'im im-icon-Bridge' => 'Bridge' ),array( 'im im-icon-Brightkite' => 'Brightkite' ),array( 'im im-icon-Broke-Link2' => 'Broke-Link2' ),array( 'im im-icon-Broken-Link' => 'Broken-Link' ),array( 'im im-icon-Broom' => 'Broom' ),array( 'im im-icon-Brush' => 'Brush' ),array( 'im im-icon-Bucket' => 'Bucket' ),array( 'im im-icon-Bug' => 'Bug' ),array( 'im im-icon-Building' => 'Building' ),array( 'im im-icon-Bulleted-List' => 'Bulleted-List' ),array( 'im im-icon-Bus-2' => 'Bus-2' ),array( 'im im-icon-Bus' => 'Bus' ),array( 'im im-icon-Business-Man' => 'Business-Man' ),array( 'im im-icon-Business-ManWoman' => 'Business-ManWoman' ),array( 'im im-icon-Business-Mens' => 'Business-Mens' ),array( 'im im-icon-Business-Woman' => 'Business-Woman' ),array( 'im im-icon-Butterfly' => 'Butterfly' ),array( 'im im-icon-Button' => 'Button' ),array( 'im im-icon-Cable-Car' => 'Cable-Car' ),array( 'im im-icon-Cake' => 'Cake' ),array( 'im im-icon-Calculator-2' => 'Calculator-2' ),array( 'im im-icon-Calculator-3' => 'Calculator-3' ),array( 'im im-icon-Calculator' => 'Calculator' ),array( 'im im-icon-Calendar-2' => 'Calendar-2' ),array( 'im im-icon-Calendar-3' => 'Calendar-3' ),array( 'im im-icon-Calendar-4' => 'Calendar-4' ),array( 'im im-icon-Calendar-Clock' => 'Calendar-Clock' ),array( 'im im-icon-Calendar' => 'Calendar' ),array( 'im im-icon-Camel' => 'Camel' ),array( 'im im-icon-Camera-2' => 'Camera-2' ),array( 'im im-icon-Camera-3' => 'Camera-3' ),array( 'im im-icon-Camera-4' => 'Camera-4' ),array( 'im im-icon-Camera-5' => 'Camera-5' ),array( 'im im-icon-Camera-Back' => 'Camera-Back' ),array( 'im im-icon-Camera' => 'Camera' ),array( 'im im-icon-Can-2' => 'Can-2' ),array( 'im im-icon-Can' => 'Can' ),array( 'im im-icon-Canada' => 'Canada' ),array( 'im im-icon-Cancer-2' => 'Cancer-2' ),array( 'im im-icon-Cancer-3' => 'Cancer-3' ),array( 'im im-icon-Cancer' => 'Cancer' ),array( 'im im-icon-Candle' => 'Candle' ),array( 'im im-icon-Candy-Cane' => 'Candy-Cane' ),array( 'im im-icon-Candy' => 'Candy' ),array( 'im im-icon-Cannon' => 'Cannon' ),array( 'im im-icon-Cap-2' => 'Cap-2' ),array( 'im im-icon-Cap-3' => 'Cap-3' ),array( 'im im-icon-Cap-Smiley' => 'Cap-Smiley' ),array( 'im im-icon-Cap' => 'Cap' ),array( 'im im-icon-Capricorn-2' => 'Capricorn-2' ),array( 'im im-icon-Capricorn' => 'Capricorn' ),array( 'im im-icon-Car-2' => 'Car-2' ),array( 'im im-icon-Car-3' => 'Car-3' ),array( 'im im-icon-Car-Coins' => 'Car-Coins' ),array( 'im im-icon-Car-Items' => 'Car-Items' ),array( 'im im-icon-Car-Wheel' => 'Car-Wheel' ),array( 'im im-icon-Car' => 'Car' ),array( 'im im-icon-Cardigan' => 'Cardigan' ),array( 'im im-icon-Cardiovascular' => 'Cardiovascular' ),array( 'im im-icon-Cart-Quantity' => 'Cart-Quantity' ),array( 'im im-icon-Casette-Tape' => 'Casette-Tape' ),array( 'im im-icon-Cash-Register' => 'Cash-Register' ),array( 'im im-icon-Cash-register2' => 'Cash-register2' ),array( 'im im-icon-Castle' => 'Castle' ),array( 'im im-icon-Cat' => 'Cat' ),array( 'im im-icon-Cathedral' => 'Cathedral' ),array( 'im im-icon-Cauldron' => 'Cauldron' ),array( 'im im-icon-CD-2' => 'CD-2' ),array( 'im im-icon-CD-Cover' => 'CD-Cover' ),array( 'im im-icon-CD' => 'CD' ),array( 'im im-icon-Cello' => 'Cello' ),array( 'im im-icon-Celsius' => 'Celsius' ),array( 'im im-icon-Chacked-Flag' => 'Chacked-Flag' ),array( 'im im-icon-Chair' => 'Chair' ),array( 'im im-icon-Charger' => 'Charger' ),array( 'im im-icon-Check-2' => 'Check-2' ),array( 'im im-icon-Check' => 'Check' ),array( 'im im-icon-Checked-User' => 'Checked-User' ),array( 'im im-icon-Checkmate' => 'Checkmate' ),array( 'im im-icon-Checkout-Bag' => 'Checkout-Bag' ),array( 'im im-icon-Checkout-Basket' => 'Checkout-Basket' ),array( 'im im-icon-Checkout' => 'Checkout' ),array( 'im im-icon-Cheese' => 'Cheese' ),array( 'im im-icon-Cheetah' => 'Cheetah' ),array( 'im im-icon-Chef-Hat' => 'Chef-Hat' ),array( 'im im-icon-Chef-Hat2' => 'Chef-Hat2' ),array( 'im im-icon-Chef' => 'Chef' ),array( 'im im-icon-Chemical-2' => 'Chemical-2' ),array( 'im im-icon-Chemical-3' => 'Chemical-3' ),array( 'im im-icon-Chemical-4' => 'Chemical-4' ),array( 'im im-icon-Chemical-5' => 'Chemical-5' ),array( 'im im-icon-Chemical' => 'Chemical' ),array( 'im im-icon-Chess-Board' => 'Chess-Board' ),array( 'im im-icon-Chess' => 'Chess' ),array( 'im im-icon-Chicken' => 'Chicken' ),array( 'im im-icon-Chile' => 'Chile' ),array( 'im im-icon-Chimney' => 'Chimney' ),array( 'im im-icon-China' => 'China' ),array( 'im im-icon-Chinese-Temple' => 'Chinese-Temple' ),array( 'im im-icon-Chip' => 'Chip' ),array( 'im im-icon-Chopsticks-2' => 'Chopsticks-2' ),array( 'im im-icon-Chopsticks' => 'Chopsticks' ),array( 'im im-icon-Christmas-Ball' => 'Christmas-Ball' ),array( 'im im-icon-Christmas-Bell' => 'Christmas-Bell' ),array( 'im im-icon-Christmas-Candle' => 'Christmas-Candle' ),array( 'im im-icon-Christmas-Hat' => 'Christmas-Hat' ),array( 'im im-icon-Christmas-Sleigh' => 'Christmas-Sleigh' ),array( 'im im-icon-Christmas-Snowman' => 'Christmas-Snowman' ),array( 'im im-icon-Christmas-Sock' => 'Christmas-Sock' ),array( 'im im-icon-Christmas-Tree' => 'Christmas-Tree' ),array( 'im im-icon-Christmas' => 'Christmas' ),array( 'im im-icon-Chrome' => 'Chrome' ),array( 'im im-icon-Chrysler-Building' => 'Chrysler-Building' ),array( 'im im-icon-Cinema' => 'Cinema' ),array( 'im im-icon-Circular-Point' => 'Circular-Point' ),array( 'im im-icon-City-Hall' => 'City-Hall' ),array( 'im im-icon-Clamp' => 'Clamp' ),array( 'im im-icon-Clapperboard-Close' => 'Clapperboard-Close' ),array( 'im im-icon-Clapperboard-Open' => 'Clapperboard-Open' ),array( 'im im-icon-Claps' => 'Claps' ),array( 'im im-icon-Clef' => 'Clef' ),array( 'im im-icon-Clinic' => 'Clinic' ),array( 'im im-icon-Clock-2' => 'Clock-2' ),array( 'im im-icon-Clock-3' => 'Clock-3' ),array( 'im im-icon-Clock-4' => 'Clock-4' ),array( 'im im-icon-Clock-Back' => 'Clock-Back' ),array( 'im im-icon-Clock-Forward' => 'Clock-Forward' ),array( 'im im-icon-Clock' => 'Clock' ),array( 'im im-icon-Close-Window' => 'Close-Window' ),array( 'im im-icon-Close' => 'Close' ),array( 'im im-icon-Clothing-Store' => 'Clothing-Store' ),array( 'im im-icon-Cloud--' => 'Cloud--' ),array( 'im im-icon-Cloud-' => 'Cloud-' ),array( 'im im-icon-Cloud-Camera' => 'Cloud-Camera' ),array( 'im im-icon-Cloud-Computer' => 'Cloud-Computer' ),array( 'im im-icon-Cloud-Email' => 'Cloud-Email' ),array( 'im im-icon-Cloud-Hail' => 'Cloud-Hail' ),array( 'im im-icon-Cloud-Laptop' => 'Cloud-Laptop' ),array( 'im im-icon-Cloud-Lock' => 'Cloud-Lock' ),array( 'im im-icon-Cloud-Moon' => 'Cloud-Moon' ),array( 'im im-icon-Cloud-Music' => 'Cloud-Music' ),array( 'im im-icon-Cloud-Picture' => 'Cloud-Picture' ),array( 'im im-icon-Cloud-Rain' => 'Cloud-Rain' ),array( 'im im-icon-Cloud-Remove' => 'Cloud-Remove' ),array( 'im im-icon-Cloud-Secure' => 'Cloud-Secure' ),array( 'im im-icon-Cloud-Settings' => 'Cloud-Settings' ),array( 'im im-icon-Cloud-Smartphone' => 'Cloud-Smartphone' ),array( 'im im-icon-Cloud-Snow' => 'Cloud-Snow' ),array( 'im im-icon-Cloud-Sun' => 'Cloud-Sun' ),array( 'im im-icon-Cloud-Tablet' => 'Cloud-Tablet' ),array( 'im im-icon-Cloud-Video' => 'Cloud-Video' ),array( 'im im-icon-Cloud-Weather' => 'Cloud-Weather' ),array( 'im im-icon-Cloud' => 'Cloud' ),array( 'im im-icon-Clouds-Weather' => 'Clouds-Weather' ),array( 'im im-icon-Clouds' => 'Clouds' ),array( 'im im-icon-Clown' => 'Clown' ),array( 'im im-icon-CMYK' => 'CMYK' ),array( 'im im-icon-Coat' => 'Coat' ),array( 'im im-icon-Cocktail' => 'Cocktail' ),array( 'im im-icon-Coconut' => 'Coconut' ),array( 'im im-icon-Code-Window' => 'Code-Window' ),array( 'im im-icon-Coding' => 'Coding' ),array( 'im im-icon-Coffee-2' => 'Coffee-2' ),array( 'im im-icon-Coffee-Bean' => 'Coffee-Bean' ),array( 'im im-icon-Coffee-Machine' => 'Coffee-Machine' ),array( 'im im-icon-Coffee-toGo' => 'Coffee-toGo' ),array( 'im im-icon-Coffee' => 'Coffee' ),array( 'im im-icon-Coffin' => 'Coffin' ),array( 'im im-icon-Coin' => 'Coin' ),array( 'im im-icon-Coins-2' => 'Coins-2' ),array( 'im im-icon-Coins-3' => 'Coins-3' ),array( 'im im-icon-Coins' => 'Coins' ),array( 'im im-icon-Colombia' => 'Colombia' ),array( 'im im-icon-Colosseum' => 'Colosseum' ),array( 'im im-icon-Column-2' => 'Column-2' ),array( 'im im-icon-Column-3' => 'Column-3' ),array( 'im im-icon-Column' => 'Column' ),array( 'im im-icon-Comb-2' => 'Comb-2' ),array( 'im im-icon-Comb' => 'Comb' ),array( 'im im-icon-Communication-Tower' => 'Communication-Tower' ),array( 'im im-icon-Communication-Tower2' => 'Communication-Tower2' ),array( 'im im-icon-Compass-2' => 'Compass-2' ),array( 'im im-icon-Compass-3' => 'Compass-3' ),array( 'im im-icon-Compass-4' => 'Compass-4' ),array( 'im im-icon-Compass-Rose' => 'Compass-Rose' ),array( 'im im-icon-Compass' => 'Compass' ),array( 'im im-icon-Computer-2' => 'Computer-2' ),array( 'im im-icon-Computer-3' => 'Computer-3' ),array( 'im im-icon-Computer-Secure' => 'Computer-Secure' ),array( 'im im-icon-Computer' => 'Computer' ),array( 'im im-icon-Conference' => 'Conference' ),array( 'im im-icon-Confused' => 'Confused' ),array( 'im im-icon-Conservation' => 'Conservation' ),array( 'im im-icon-Consulting' => 'Consulting' ),array( 'im im-icon-Contrast' => 'Contrast' ),array( 'im im-icon-Control-2' => 'Control-2' ),array( 'im im-icon-Control' => 'Control' ),array( 'im im-icon-Cookie-Man' => 'Cookie-Man' ),array( 'im im-icon-Cookies' => 'Cookies' ),array( 'im im-icon-Cool-Guy' => 'Cool-Guy' ),array( 'im im-icon-Cool' => 'Cool' ),array( 'im im-icon-Copyright' => 'Copyright' ),array( 'im im-icon-Costume' => 'Costume' ),array( 'im im-icon-Couple-Sign' => 'Couple-Sign' ),array( 'im im-icon-Cow' => 'Cow' ),array( 'im im-icon-CPU' => 'CPU' ),array( 'im im-icon-Crane' => 'Crane' ),array( 'im im-icon-Cranium' => 'Cranium' ),array( 'im im-icon-Credit-Card' => 'Credit-Card' ),array( 'im im-icon-Credit-Card2' => 'Credit-Card2' ),array( 'im im-icon-Credit-Card3' => 'Credit-Card3' ),array( 'im im-icon-Cricket' => 'Cricket' ),array( 'im im-icon-Criminal' => 'Criminal' ),array( 'im im-icon-Croissant' => 'Croissant' ),array( 'im im-icon-Crop-2' => 'Crop-2' ),array( 'im im-icon-Crop-3' => 'Crop-3' ),array( 'im im-icon-Crown-2' => 'Crown-2' ),array( 'im im-icon-Crown' => 'Crown' ),array( 'im im-icon-Crying' => 'Crying' ),array( 'im im-icon-Cube-Molecule' => 'Cube-Molecule' ),array( 'im im-icon-Cube-Molecule2' => 'Cube-Molecule2' ),array( 'im im-icon-Cupcake' => 'Cupcake' ),array( 'im im-icon-Cursor-Click' => 'Cursor-Click' ),array( 'im im-icon-Cursor-Click2' => 'Cursor-Click2' ),array( 'im im-icon-Cursor-Move' => 'Cursor-Move' ),array( 'im im-icon-Cursor-Move2' => 'Cursor-Move2' ),array( 'im im-icon-Cursor-Select' => 'Cursor-Select' ),array( 'im im-icon-Cursor' => 'Cursor' ),array( 'im im-icon-D-Eyeglasses' => 'D-Eyeglasses' ),array( 'im im-icon-D-Eyeglasses2' => 'D-Eyeglasses2' ),array( 'im im-icon-Dam' => 'Dam' ),array( 'im im-icon-Danemark' => 'Danemark' ),array( 'im im-icon-Danger-2' => 'Danger-2' ),array( 'im im-icon-Danger' => 'Danger' ),array( 'im im-icon-Dashboard' => 'Dashboard' ),array( 'im im-icon-Data-Backup' => 'Data-Backup' ),array( 'im im-icon-Data-Block' => 'Data-Block' ),array( 'im im-icon-Data-Center' => 'Data-Center' ),array( 'im im-icon-Data-Clock' => 'Data-Clock' ),array( 'im im-icon-Data-Cloud' => 'Data-Cloud' ),array( 'im im-icon-Data-Compress' => 'Data-Compress' ),array( 'im im-icon-Data-Copy' => 'Data-Copy' ),array( 'im im-icon-Data-Download' => 'Data-Download' ),array( 'im im-icon-Data-Financial' => 'Data-Financial' ),array( 'im im-icon-Data-Key' => 'Data-Key' ),array( 'im im-icon-Data-Lock' => 'Data-Lock' ),array( 'im im-icon-Data-Network' => 'Data-Network' ),array( 'im im-icon-Data-Password' => 'Data-Password' ),array( 'im im-icon-Data-Power' => 'Data-Power' ),array( 'im im-icon-Data-Refresh' => 'Data-Refresh' ),array( 'im im-icon-Data-Save' => 'Data-Save' ),array( 'im im-icon-Data-Search' => 'Data-Search' ),array( 'im im-icon-Data-Security' => 'Data-Security' ),array( 'im im-icon-Data-Settings' => 'Data-Settings' ),array( 'im im-icon-Data-Sharing' => 'Data-Sharing' ),array( 'im im-icon-Data-Shield' => 'Data-Shield' ),array( 'im im-icon-Data-Signal' => 'Data-Signal' ),array( 'im im-icon-Data-Storage' => 'Data-Storage' ),array( 'im im-icon-Data-Stream' => 'Data-Stream' ),array( 'im im-icon-Data-Transfer' => 'Data-Transfer' ),array( 'im im-icon-Data-Unlock' => 'Data-Unlock' ),array( 'im im-icon-Data-Upload' => 'Data-Upload' ),array( 'im im-icon-Data-Yes' => 'Data-Yes' ),array( 'im im-icon-Data' => 'Data' ),array( 'im im-icon-David-Star' => 'David-Star' ),array( 'im im-icon-Daylight' => 'Daylight' ),array( 'im im-icon-Death' => 'Death' ),array( 'im im-icon-Debian' => 'Debian' ),array( 'im im-icon-Dec' => 'Dec' ),array( 'im im-icon-Decrase-Inedit' => 'Decrase-Inedit' ),array( 'im im-icon-Deer-2' => 'Deer-2' ),array( 'im im-icon-Deer' => 'Deer' ),array( 'im im-icon-Delete-File' => 'Delete-File' ),array( 'im im-icon-Delete-Window' => 'Delete-Window' ),array( 'im im-icon-Delicious' => 'Delicious' ),array( 'im im-icon-Depression' => 'Depression' ),array( 'im im-icon-Deviantart' => 'Deviantart' ),array( 'im im-icon-Device-SyncwithCloud' => 'Device-SyncwithCloud' ),array( 'im im-icon-Diamond' => 'Diamond' ),array( 'im im-icon-Dice-2' => 'Dice-2' ),array( 'im im-icon-Dice' => 'Dice' ),array( 'im im-icon-Digg' => 'Digg' ),array( 'im im-icon-Digital-Drawing' => 'Digital-Drawing' ),array( 'im im-icon-Diigo' => 'Diigo' ),array( 'im im-icon-Dinosaur' => 'Dinosaur' ),array( 'im im-icon-Diploma-2' => 'Diploma-2' ),array( 'im im-icon-Diploma' => 'Diploma' ),array( 'im im-icon-Direction-East' => 'Direction-East' ),array( 'im im-icon-Direction-North' => 'Direction-North' ),array( 'im im-icon-Direction-South' => 'Direction-South' ),array( 'im im-icon-Direction-West' => 'Direction-West' ),array( 'im im-icon-Director' => 'Director' ),array( 'im im-icon-Disk' => 'Disk' ),array( 'im im-icon-Dj' => 'Dj' ),array( 'im im-icon-DNA-2' => 'DNA-2' ),array( 'im im-icon-DNA-Helix' => 'DNA-Helix' ),array( 'im im-icon-DNA' => 'DNA' ),array( 'im im-icon-Doctor' => 'Doctor' ),array( 'im im-icon-Dog' => 'Dog' ),array( 'im im-icon-Dollar-Sign' => 'Dollar-Sign' ),array( 'im im-icon-Dollar-Sign2' => 'Dollar-Sign2' ),array( 'im im-icon-Dollar' => 'Dollar' ),array( 'im im-icon-Dolphin' => 'Dolphin' ),array( 'im im-icon-Domino' => 'Domino' ),array( 'im im-icon-Door-Hanger' => 'Door-Hanger' ),array( 'im im-icon-Door' => 'Door' ),array( 'im im-icon-Doplr' => 'Doplr' ),array( 'im im-icon-Double-Circle' => 'Double-Circle' ),array( 'im im-icon-Double-Tap' => 'Double-Tap' ),array( 'im im-icon-Doughnut' => 'Doughnut' ),array( 'im im-icon-Dove' => 'Dove' ),array( 'im im-icon-Down-2' => 'Down-2' ),array( 'im im-icon-Down-3' => 'Down-3' ),array( 'im im-icon-Down-4' => 'Down-4' ),array( 'im im-icon-Down' => 'Down' ),array( 'im im-icon-Download-2' => 'Download-2' ),array( 'im im-icon-Download-fromCloud' => 'Download-fromCloud' ),array( 'im im-icon-Download-Window' => 'Download-Window' ),array( 'im im-icon-Download' => 'Download' ),array( 'im im-icon-Downward' => 'Downward' ),array( 'im im-icon-Drag-Down' => 'Drag-Down' ),array( 'im im-icon-Drag-Left' => 'Drag-Left' ),array( 'im im-icon-Drag-Right' => 'Drag-Right' ),array( 'im im-icon-Drag-Up' => 'Drag-Up' ),array( 'im im-icon-Drag' => 'Drag' ),array( 'im im-icon-Dress' => 'Dress' ),array( 'im im-icon-Drill-2' => 'Drill-2' ),array( 'im im-icon-Drill' => 'Drill' ),array( 'im im-icon-Drop' => 'Drop' ),array( 'im im-icon-Dropbox' => 'Dropbox' ),array( 'im im-icon-Drum' => 'Drum' ),array( 'im im-icon-Dry' => 'Dry' ),array( 'im im-icon-Duck' => 'Duck' ),array( 'im im-icon-Dumbbell' => 'Dumbbell' ),array( 'im im-icon-Duplicate-Layer' => 'Duplicate-Layer' ),array( 'im im-icon-Duplicate-Window' => 'Duplicate-Window' ),array( 'im im-icon-DVD' => 'DVD' ),array( 'im im-icon-Eagle' => 'Eagle' ),array( 'im im-icon-Ear' => 'Ear' ),array( 'im im-icon-Earphones-2' => 'Earphones-2' ),array( 'im im-icon-Earphones' => 'Earphones' ),array( 'im im-icon-Eci-Icon' => 'Eci-Icon' ),array( 'im im-icon-Edit-Map' => 'Edit-Map' ),array( 'im im-icon-Edit' => 'Edit' ),array( 'im im-icon-Eggs' => 'Eggs' ),array( 'im im-icon-Egypt' => 'Egypt' ),array( 'im im-icon-Eifel-Tower' => 'Eifel-Tower' ),array( 'im im-icon-eject-2' => 'eject-2' ),array( 'im im-icon-Eject' => 'Eject' ),array( 'im im-icon-El-Castillo' => 'El-Castillo' ),array( 'im im-icon-Elbow' => 'Elbow' ),array( 'im im-icon-Electric-Guitar' => 'Electric-Guitar' ),array( 'im im-icon-Electricity' => 'Electricity' ),array( 'im im-icon-Elephant' => 'Elephant' ),array( 'im im-icon-Email' => 'Email' ),array( 'im im-icon-Embassy' => 'Embassy' ),array( 'im im-icon-Empire-StateBuilding' => 'Empire-StateBuilding' ),array( 'im im-icon-Empty-Box' => 'Empty-Box' ),array( 'im im-icon-End2' => 'End2' ),array( 'im im-icon-End-2' => 'End-2' ),array( 'im im-icon-End' => 'End' ),array( 'im im-icon-Endways' => 'Endways' ),array( 'im im-icon-Engineering' => 'Engineering' ),array( 'im im-icon-Envelope-2' => 'Envelope-2' ),array( 'im im-icon-Envelope' => 'Envelope' ),array( 'im im-icon-Environmental-2' => 'Environmental-2' ),array( 'im im-icon-Environmental-3' => 'Environmental-3' ),array( 'im im-icon-Environmental' => 'Environmental' ),array( 'im im-icon-Equalizer' => 'Equalizer' ),array( 'im im-icon-Eraser-2' => 'Eraser-2' ),array( 'im im-icon-Eraser-3' => 'Eraser-3' ),array( 'im im-icon-Eraser' => 'Eraser' ),array( 'im im-icon-Error-404Window' => 'Error-404Window' ),array( 'im im-icon-Euro-Sign' => 'Euro-Sign' ),array( 'im im-icon-Euro-Sign2' => 'Euro-Sign2' ),array( 'im im-icon-Euro' => 'Euro' ),array( 'im im-icon-Evernote' => 'Evernote' ),array( 'im im-icon-Evil' => 'Evil' ),array( 'im im-icon-Explode' => 'Explode' ),array( 'im im-icon-Eye-2' => 'Eye-2' ),array( 'im im-icon-Eye-Blind' => 'Eye-Blind' ),array( 'im im-icon-Eye-Invisible' => 'Eye-Invisible' ),array( 'im im-icon-Eye-Scan' => 'Eye-Scan' ),array( 'im im-icon-Eye-Visible' => 'Eye-Visible' ),array( 'im im-icon-Eye' => 'Eye' ),array( 'im im-icon-Eyebrow-2' => 'Eyebrow-2' ),array( 'im im-icon-Eyebrow-3' => 'Eyebrow-3' ),array( 'im im-icon-Eyebrow' => 'Eyebrow' ),array( 'im im-icon-Eyeglasses-Smiley' => 'Eyeglasses-Smiley' ),array( 'im im-icon-Eyeglasses-Smiley2' => 'Eyeglasses-Smiley2' ),array( 'im im-icon-Face-Style' => 'Face-Style' ),array( 'im im-icon-Face-Style2' => 'Face-Style2' ),array( 'im im-icon-Face-Style3' => 'Face-Style3' ),array( 'im im-icon-Face-Style4' => 'Face-Style4' ),array( 'im im-icon-Face-Style5' => 'Face-Style5' ),array( 'im im-icon-Face-Style6' => 'Face-Style6' ),array( 'im im-icon-Facebook-2' => 'Facebook-2' ),array( 'im im-icon-Facebook' => 'Facebook' ),array( 'im im-icon-Factory-2' => 'Factory-2' ),array( 'im im-icon-Factory' => 'Factory' ),array( 'im im-icon-Fahrenheit' => 'Fahrenheit' ),array( 'im im-icon-Family-Sign' => 'Family-Sign' ),array( 'im im-icon-Fan' => 'Fan' ),array( 'im im-icon-Farmer' => 'Farmer' ),array( 'im im-icon-Fashion' => 'Fashion' ),array( 'im im-icon-Favorite-Window' => 'Favorite-Window' ),array( 'im im-icon-Fax' => 'Fax' ),array( 'im im-icon-Feather' => 'Feather' ),array( 'im im-icon-Feedburner' => 'Feedburner' ),array( 'im im-icon-Female-2' => 'Female-2' ),array( 'im im-icon-Female-Sign' => 'Female-Sign' ),array( 'im im-icon-Female' => 'Female' ),array( 'im im-icon-File-Block' => 'File-Block' ),array( 'im im-icon-File-Bookmark' => 'File-Bookmark' ),array( 'im im-icon-File-Chart' => 'File-Chart' ),array( 'im im-icon-File-Clipboard' => 'File-Clipboard' ),array( 'im im-icon-File-ClipboardFileText' => 'File-ClipboardFileText' ),array( 'im im-icon-File-ClipboardTextImage' => 'File-ClipboardTextImage' ),array( 'im im-icon-File-Cloud' => 'File-Cloud' ),array( 'im im-icon-File-Copy' => 'File-Copy' ),array( 'im im-icon-File-Copy2' => 'File-Copy2' ),array( 'im im-icon-File-CSV' => 'File-CSV' ),array( 'im im-icon-File-Download' => 'File-Download' ),array( 'im im-icon-File-Edit' => 'File-Edit' ),array( 'im im-icon-File-Excel' => 'File-Excel' ),array( 'im im-icon-File-Favorite' => 'File-Favorite' ),array( 'im im-icon-File-Fire' => 'File-Fire' ),array( 'im im-icon-File-Graph' => 'File-Graph' ),array( 'im im-icon-File-Hide' => 'File-Hide' ),array( 'im im-icon-File-Horizontal' => 'File-Horizontal' ),array( 'im im-icon-File-HorizontalText' => 'File-HorizontalText' ),array( 'im im-icon-File-HTML' => 'File-HTML' ),array( 'im im-icon-File-JPG' => 'File-JPG' ),array( 'im im-icon-File-Link' => 'File-Link' ),array( 'im im-icon-File-Loading' => 'File-Loading' ),array( 'im im-icon-File-Lock' => 'File-Lock' ),array( 'im im-icon-File-Love' => 'File-Love' ),array( 'im im-icon-File-Music' => 'File-Music' ),array( 'im im-icon-File-Network' => 'File-Network' ),array( 'im im-icon-File-Pictures' => 'File-Pictures' ),array( 'im im-icon-File-Pie' => 'File-Pie' ),array( 'im im-icon-File-Presentation' => 'File-Presentation' ),array( 'im im-icon-File-Refresh' => 'File-Refresh' ),array( 'im im-icon-File-Search' => 'File-Search' ),array( 'im im-icon-File-Settings' => 'File-Settings' ),array( 'im im-icon-File-Share' => 'File-Share' ),array( 'im im-icon-File-TextImage' => 'File-TextImage' ),array( 'im im-icon-File-Trash' => 'File-Trash' ),array( 'im im-icon-File-TXT' => 'File-TXT' ),array( 'im im-icon-File-Upload' => 'File-Upload' ),array( 'im im-icon-File-Video' => 'File-Video' ),array( 'im im-icon-File-Word' => 'File-Word' ),array( 'im im-icon-File-Zip' => 'File-Zip' ),array( 'im im-icon-File' => 'File' ),array( 'im im-icon-Files' => 'Files' ),array( 'im im-icon-Film-Board' => 'Film-Board' ),array( 'im im-icon-Film-Cartridge' => 'Film-Cartridge' ),array( 'im im-icon-Film-Strip' => 'Film-Strip' ),array( 'im im-icon-Film-Video' => 'Film-Video' ),array( 'im im-icon-Film' => 'Film' ),array( 'im im-icon-Filter-2' => 'Filter-2' ),array( 'im im-icon-Filter' => 'Filter' ),array( 'im im-icon-Financial' => 'Financial' ),array( 'im im-icon-Find-User' => 'Find-User' ),array( 'im im-icon-Finger-DragFourSides' => 'Finger-DragFourSides' ),array( 'im im-icon-Finger-DragTwoSides' => 'Finger-DragTwoSides' ),array( 'im im-icon-Finger-Print' => 'Finger-Print' ),array( 'im im-icon-Finger' => 'Finger' ),array( 'im im-icon-Fingerprint-2' => 'Fingerprint-2' ),array( 'im im-icon-Fingerprint' => 'Fingerprint' ),array( 'im im-icon-Fire-Flame' => 'Fire-Flame' ),array( 'im im-icon-Fire-Flame2' => 'Fire-Flame2' ),array( 'im im-icon-Fire-Hydrant' => 'Fire-Hydrant' ),array( 'im im-icon-Fire-Staion' => 'Fire-Staion' ),array( 'im im-icon-Firefox' => 'Firefox' ),array( 'im im-icon-Firewall' => 'Firewall' ),array( 'im im-icon-First-Aid' => 'First-Aid' ),array( 'im im-icon-First' => 'First' ),array( 'im im-icon-Fish-Food' => 'Fish-Food' ),array( 'im im-icon-Fish' => 'Fish' ),array( 'im im-icon-Fit-To' => 'Fit-To' ),array( 'im im-icon-Fit-To2' => 'Fit-To2' ),array( 'im im-icon-Five-Fingers' => 'Five-Fingers' ),array( 'im im-icon-Five-FingersDrag' => 'Five-FingersDrag' ),array( 'im im-icon-Five-FingersDrag2' => 'Five-FingersDrag2' ),array( 'im im-icon-Five-FingersTouch' => 'Five-FingersTouch' ),array( 'im im-icon-Flag-2' => 'Flag-2' ),array( 'im im-icon-Flag-3' => 'Flag-3' ),array( 'im im-icon-Flag-4' => 'Flag-4' ),array( 'im im-icon-Flag-5' => 'Flag-5' ),array( 'im im-icon-Flag-6' => 'Flag-6' ),array( 'im im-icon-Flag' => 'Flag' ),array( 'im im-icon-Flamingo' => 'Flamingo' ),array( 'im im-icon-Flash-2' => 'Flash-2' ),array( 'im im-icon-Flash-Video' => 'Flash-Video' ),array( 'im im-icon-Flash' => 'Flash' ),array( 'im im-icon-Flashlight' => 'Flashlight' ),array( 'im im-icon-Flask-2' => 'Flask-2' ),array( 'im im-icon-Flask' => 'Flask' ),array( 'im im-icon-Flick' => 'Flick' ),array( 'im im-icon-Flickr' => 'Flickr' ),array( 'im im-icon-Flowerpot' => 'Flowerpot' ),array( 'im im-icon-Fluorescent' => 'Fluorescent' ),array( 'im im-icon-Fog-Day' => 'Fog-Day' ),array( 'im im-icon-Fog-Night' => 'Fog-Night' ),array( 'im im-icon-Folder-Add' => 'Folder-Add' ),array( 'im im-icon-Folder-Archive' => 'Folder-Archive' ),array( 'im im-icon-Folder-Binder' => 'Folder-Binder' ),array( 'im im-icon-Folder-Binder2' => 'Folder-Binder2' ),array( 'im im-icon-Folder-Block' => 'Folder-Block' ),array( 'im im-icon-Folder-Bookmark' => 'Folder-Bookmark' ),array( 'im im-icon-Folder-Close' => 'Folder-Close' ),array( 'im im-icon-Folder-Cloud' => 'Folder-Cloud' ),array( 'im im-icon-Folder-Delete' => 'Folder-Delete' ),array( 'im im-icon-Folder-Download' => 'Folder-Download' ),array( 'im im-icon-Folder-Edit' => 'Folder-Edit' ),array( 'im im-icon-Folder-Favorite' => 'Folder-Favorite' ),array( 'im im-icon-Folder-Fire' => 'Folder-Fire' ),array( 'im im-icon-Folder-Hide' => 'Folder-Hide' ),array( 'im im-icon-Folder-Link' => 'Folder-Link' ),array( 'im im-icon-Folder-Loading' => 'Folder-Loading' ),array( 'im im-icon-Folder-Lock' => 'Folder-Lock' ),array( 'im im-icon-Folder-Love' => 'Folder-Love' ),array( 'im im-icon-Folder-Music' => 'Folder-Music' ),array( 'im im-icon-Folder-Network' => 'Folder-Network' ),array( 'im im-icon-Folder-Open' => 'Folder-Open' ),array( 'im im-icon-Folder-Open2' => 'Folder-Open2' ),array( 'im im-icon-Folder-Organizing' => 'Folder-Organizing' ),array( 'im im-icon-Folder-Pictures' => 'Folder-Pictures' ),array( 'im im-icon-Folder-Refresh' => 'Folder-Refresh' ),array( 'im im-icon-Folder-Remove-' => 'Folder-Remove-' ),array( 'im im-icon-Folder-Search' => 'Folder-Search' ),array( 'im im-icon-Folder-Settings' => 'Folder-Settings' ),array( 'im im-icon-Folder-Share' => 'Folder-Share' ),array( 'im im-icon-Folder-Trash' => 'Folder-Trash' ),array( 'im im-icon-Folder-Upload' => 'Folder-Upload' ),array( 'im im-icon-Folder-Video' => 'Folder-Video' ),array( 'im im-icon-Folder-WithDocument' => 'Folder-WithDocument' ),array( 'im im-icon-Folder-Zip' => 'Folder-Zip' ),array( 'im im-icon-Folder' => 'Folder' ),array( 'im im-icon-Folders' => 'Folders' ),array( 'im im-icon-Font-Color' => 'Font-Color' ),array( 'im im-icon-Font-Name' => 'Font-Name' ),array( 'im im-icon-Font-Size' => 'Font-Size' ),array( 'im im-icon-Font-Style' => 'Font-Style' ),array( 'im im-icon-Font-StyleSubscript' => 'Font-StyleSubscript' ),array( 'im im-icon-Font-StyleSuperscript' => 'Font-StyleSuperscript' ),array( 'im im-icon-Font-Window' => 'Font-Window' ),array( 'im im-icon-Foot-2' => 'Foot-2' ),array( 'im im-icon-Foot' => 'Foot' ),array( 'im im-icon-Football-2' => 'Football-2' ),array( 'im im-icon-Football' => 'Football' ),array( 'im im-icon-Footprint-2' => 'Footprint-2' ),array( 'im im-icon-Footprint-3' => 'Footprint-3' ),array( 'im im-icon-Footprint' => 'Footprint' ),array( 'im im-icon-Forest' => 'Forest' ),array( 'im im-icon-Fork' => 'Fork' ),array( 'im im-icon-Formspring' => 'Formspring' ),array( 'im im-icon-Formula' => 'Formula' ),array( 'im im-icon-Forsquare' => 'Forsquare' ),array( 'im im-icon-Forward' => 'Forward' ),array( 'im im-icon-Fountain-Pen' => 'Fountain-Pen' ),array( 'im im-icon-Four-Fingers' => 'Four-Fingers' ),array( 'im im-icon-Four-FingersDrag' => 'Four-FingersDrag' ),array( 'im im-icon-Four-FingersDrag2' => 'Four-FingersDrag2' ),array( 'im im-icon-Four-FingersTouch' => 'Four-FingersTouch' ),array( 'im im-icon-Fox' => 'Fox' ),array( 'im im-icon-Frankenstein' => 'Frankenstein' ),array( 'im im-icon-French-Fries' => 'French-Fries' ),array( 'im im-icon-Friendfeed' => 'Friendfeed' ),array( 'im im-icon-Friendster' => 'Friendster' ),array( 'im im-icon-Frog' => 'Frog' ),array( 'im im-icon-Fruits' => 'Fruits' ),array( 'im im-icon-Fuel' => 'Fuel' ),array( 'im im-icon-Full-Bag' => 'Full-Bag' ),array( 'im im-icon-Full-Basket' => 'Full-Basket' ),array( 'im im-icon-Full-Cart' => 'Full-Cart' ),array( 'im im-icon-Full-Moon' => 'Full-Moon' ),array( 'im im-icon-Full-Screen' => 'Full-Screen' ),array( 'im im-icon-Full-Screen2' => 'Full-Screen2' ),array( 'im im-icon-Full-View' => 'Full-View' ),array( 'im im-icon-Full-View2' => 'Full-View2' ),array( 'im im-icon-Full-ViewWindow' => 'Full-ViewWindow' ),array( 'im im-icon-Function' => 'Function' ),array( 'im im-icon-Funky' => 'Funky' ),array( 'im im-icon-Funny-Bicycle' => 'Funny-Bicycle' ),array( 'im im-icon-Furl' => 'Furl' ),array( 'im im-icon-Gamepad-2' => 'Gamepad-2' ),array( 'im im-icon-Gamepad' => 'Gamepad' ),array( 'im im-icon-Gas-Pump' => 'Gas-Pump' ),array( 'im im-icon-Gaugage-2' => 'Gaugage-2' ),array( 'im im-icon-Gaugage' => 'Gaugage' ),array( 'im im-icon-Gay' => 'Gay' ),array( 'im im-icon-Gear-2' => 'Gear-2' ),array( 'im im-icon-Gear' => 'Gear' ),array( 'im im-icon-Gears-2' => 'Gears-2' ),array( 'im im-icon-Gears' => 'Gears' ),array( 'im im-icon-Geek-2' => 'Geek-2' ),array( 'im im-icon-Geek' => 'Geek' ),array( 'im im-icon-Gemini-2' => 'Gemini-2' ),array( 'im im-icon-Gemini' => 'Gemini' ),array( 'im im-icon-Genius' => 'Genius' ),array( 'im im-icon-Gentleman' => 'Gentleman' ),array( 'im im-icon-Geo--' => 'Geo--' ),array( 'im im-icon-Geo-' => 'Geo-' ),array( 'im im-icon-Geo-Close' => 'Geo-Close' ),array( 'im im-icon-Geo-Love' => 'Geo-Love' ),array( 'im im-icon-Geo-Number' => 'Geo-Number' ),array( 'im im-icon-Geo-Star' => 'Geo-Star' ),array( 'im im-icon-Geo' => 'Geo' ),array( 'im im-icon-Geo2--' => 'Geo2--' ),array( 'im im-icon-Geo2-' => 'Geo2-' ),array( 'im im-icon-Geo2-Close' => 'Geo2-Close' ),array( 'im im-icon-Geo2-Love' => 'Geo2-Love' ),array( 'im im-icon-Geo2-Number' => 'Geo2-Number' ),array( 'im im-icon-Geo2-Star' => 'Geo2-Star' ),array( 'im im-icon-Geo2' => 'Geo2' ),array( 'im im-icon-Geo3--' => 'Geo3--' ),array( 'im im-icon-Geo3-' => 'Geo3-' ),array( 'im im-icon-Geo3-Close' => 'Geo3-Close' ),array( 'im im-icon-Geo3-Love' => 'Geo3-Love' ),array( 'im im-icon-Geo3-Number' => 'Geo3-Number' ),array( 'im im-icon-Geo3-Star' => 'Geo3-Star' ),array( 'im im-icon-Geo3' => 'Geo3' ),array( 'im im-icon-Gey' => 'Gey' ),array( 'im im-icon-Gift-Box' => 'Gift-Box' ),array( 'im im-icon-Giraffe' => 'Giraffe' ),array( 'im im-icon-Girl' => 'Girl' ),array( 'im im-icon-Glass-Water' => 'Glass-Water' ),array( 'im im-icon-Glasses-2' => 'Glasses-2' ),array( 'im im-icon-Glasses-3' => 'Glasses-3' ),array( 'im im-icon-Glasses' => 'Glasses' ),array( 'im im-icon-Global-Position' => 'Global-Position' ),array( 'im im-icon-Globe-2' => 'Globe-2' ),array( 'im im-icon-Globe' => 'Globe' ),array( 'im im-icon-Gloves' => 'Gloves' ),array( 'im im-icon-Go-Bottom' => 'Go-Bottom' ),array( 'im im-icon-Go-Top' => 'Go-Top' ),array( 'im im-icon-Goggles' => 'Goggles' ),array( 'im im-icon-Golf-2' => 'Golf-2' ),array( 'im im-icon-Golf' => 'Golf' ),array( 'im im-icon-Google-Buzz' => 'Google-Buzz' ),array( 'im im-icon-Google-Drive' => 'Google-Drive' ),array( 'im im-icon-Google-Play' => 'Google-Play' ),array( 'im im-icon-Google-Plus' => 'Google-Plus' ),array( 'im im-icon-Google' => 'Google' ),array( 'im im-icon-Gopro' => 'Gopro' ),array( 'im im-icon-Gorilla' => 'Gorilla' ),array( 'im im-icon-Gowalla' => 'Gowalla' ),array( 'im im-icon-Grave' => 'Grave' ),array( 'im im-icon-Graveyard' => 'Graveyard' ),array( 'im im-icon-Greece' => 'Greece' ),array( 'im im-icon-Green-Energy' => 'Green-Energy' ),array( 'im im-icon-Green-House' => 'Green-House' ),array( 'im im-icon-Guitar' => 'Guitar' ),array( 'im im-icon-Gun-2' => 'Gun-2' ),array( 'im im-icon-Gun-3' => 'Gun-3' ),array( 'im im-icon-Gun' => 'Gun' ),array( 'im im-icon-Gymnastics' => 'Gymnastics' ),array( 'im im-icon-Hair-2' => 'Hair-2' ),array( 'im im-icon-Hair-3' => 'Hair-3' ),array( 'im im-icon-Hair-4' => 'Hair-4' ),array( 'im im-icon-Hair' => 'Hair' ),array( 'im im-icon-Half-Moon' => 'Half-Moon' ),array( 'im im-icon-Halloween-HalfMoon' => 'Halloween-HalfMoon' ),array( 'im im-icon-Halloween-Moon' => 'Halloween-Moon' ),array( 'im im-icon-Hamburger' => 'Hamburger' ),array( 'im im-icon-Hammer' => 'Hammer' ),array( 'im im-icon-Hand-Touch' => 'Hand-Touch' ),array( 'im im-icon-Hand-Touch2' => 'Hand-Touch2' ),array( 'im im-icon-Hand-TouchSmartphone' => 'Hand-TouchSmartphone' ),array( 'im im-icon-Hand' => 'Hand' ),array( 'im im-icon-Hands' => 'Hands' ),array( 'im im-icon-Handshake' => 'Handshake' ),array( 'im im-icon-Hanger' => 'Hanger' ),array( 'im im-icon-Happy' => 'Happy' ),array( 'im im-icon-Hat-2' => 'Hat-2' ),array( 'im im-icon-Hat' => 'Hat' ),array( 'im im-icon-Haunted-House' => 'Haunted-House' ),array( 'im im-icon-HD-Video' => 'HD-Video' ),array( 'im im-icon-HD' => 'HD' ),array( 'im im-icon-HDD' => 'HDD' ),array( 'im im-icon-Headphone' => 'Headphone' ),array( 'im im-icon-Headphones' => 'Headphones' ),array( 'im im-icon-Headset' => 'Headset' ),array( 'im im-icon-Heart-2' => 'Heart-2' ),array( 'im im-icon-Heart' => 'Heart' ),array( 'im im-icon-Heels-2' => 'Heels-2' ),array( 'im im-icon-Heels' => 'Heels' ),array( 'im im-icon-Height-Window' => 'Height-Window' ),array( 'im im-icon-Helicopter-2' => 'Helicopter-2' ),array( 'im im-icon-Helicopter' => 'Helicopter' ),array( 'im im-icon-Helix-2' => 'Helix-2' ),array( 'im im-icon-Hello' => 'Hello' ),array( 'im im-icon-Helmet-2' => 'Helmet-2' ),array( 'im im-icon-Helmet-3' => 'Helmet-3' ),array( 'im im-icon-Helmet' => 'Helmet' ),array( 'im im-icon-Hipo' => 'Hipo' ),array( 'im im-icon-Hipster-Glasses' => 'Hipster-Glasses' ),array( 'im im-icon-Hipster-Glasses2' => 'Hipster-Glasses2' ),array( 'im im-icon-Hipster-Glasses3' => 'Hipster-Glasses3' ),array( 'im im-icon-Hipster-Headphones' => 'Hipster-Headphones' ),array( 'im im-icon-Hipster-Men' => 'Hipster-Men' ),array( 'im im-icon-Hipster-Men2' => 'Hipster-Men2' ),array( 'im im-icon-Hipster-Men3' => 'Hipster-Men3' ),array( 'im im-icon-Hipster-Sunglasses' => 'Hipster-Sunglasses' ),array( 'im im-icon-Hipster-Sunglasses2' => 'Hipster-Sunglasses2' ),array( 'im im-icon-Hipster-Sunglasses3' => 'Hipster-Sunglasses3' ),array( 'im im-icon-Hokey' => 'Hokey' ),array( 'im im-icon-Holly' => 'Holly' ),array( 'im im-icon-Home-2' => 'Home-2' ),array( 'im im-icon-Home-3' => 'Home-3' ),array( 'im im-icon-Home-4' => 'Home-4' ),array( 'im im-icon-Home-5' => 'Home-5' ),array( 'im im-icon-Home-Window' => 'Home-Window' ),array( 'im im-icon-Home' => 'Home' ),array( 'im im-icon-Homosexual' => 'Homosexual' ),array( 'im im-icon-Honey' => 'Honey' ),array( 'im im-icon-Hong-Kong' => 'Hong-Kong' ),array( 'im im-icon-Hoodie' => 'Hoodie' ),array( 'im im-icon-Horror' => 'Horror' ),array( 'im im-icon-Horse' => 'Horse' ),array( 'im im-icon-Hospital-2' => 'Hospital-2' ),array( 'im im-icon-Hospital' => 'Hospital' ),array( 'im im-icon-Host' => 'Host' ),array( 'im im-icon-Hot-Dog' => 'Hot-Dog' ),array( 'im im-icon-Hotel' => 'Hotel' ),array( 'im im-icon-Hour' => 'Hour' ),array( 'im im-icon-Hub' => 'Hub' ),array( 'im im-icon-Humor' => 'Humor' ),array( 'im im-icon-Hurt' => 'Hurt' ),array( 'im im-icon-Ice-Cream' => 'Ice-Cream' ),array( 'im im-icon-ICQ' => 'ICQ' ),array( 'im im-icon-ID-2' => 'ID-2' ),array( 'im im-icon-ID-3' => 'ID-3' ),array( 'im im-icon-ID-Card' => 'ID-Card' ),array( 'im im-icon-Idea-2' => 'Idea-2' ),array( 'im im-icon-Idea-3' => 'Idea-3' ),array( 'im im-icon-Idea-4' => 'Idea-4' ),array( 'im im-icon-Idea-5' => 'Idea-5' ),array( 'im im-icon-Idea' => 'Idea' ),array( 'im im-icon-Identification-Badge' => 'Identification-Badge' ),array( 'im im-icon-ImDB' => 'ImDB' ),array( 'im im-icon-Inbox-Empty' => 'Inbox-Empty' ),array( 'im im-icon-Inbox-Forward' => 'Inbox-Forward' ),array( 'im im-icon-Inbox-Full' => 'Inbox-Full' ),array( 'im im-icon-Inbox-Into' => 'Inbox-Into' ),array( 'im im-icon-Inbox-Out' => 'Inbox-Out' ),array( 'im im-icon-Inbox-Reply' => 'Inbox-Reply' ),array( 'im im-icon-Inbox' => 'Inbox' ),array( 'im im-icon-Increase-Inedit' => 'Increase-Inedit' ),array( 'im im-icon-Indent-FirstLine' => 'Indent-FirstLine' ),array( 'im im-icon-Indent-LeftMargin' => 'Indent-LeftMargin' ),array( 'im im-icon-Indent-RightMargin' => 'Indent-RightMargin' ),array( 'im im-icon-India' => 'India' ),array( 'im im-icon-Info-Window' => 'Info-Window' ),array( 'im im-icon-Information' => 'Information' ),array( 'im im-icon-Inifity' => 'Inifity' ),array( 'im im-icon-Instagram' => 'Instagram' ),array( 'im im-icon-Internet-2' => 'Internet-2' ),array( 'im im-icon-Internet-Explorer' => 'Internet-Explorer' ),array( 'im im-icon-Internet-Smiley' => 'Internet-Smiley' ),array( 'im im-icon-Internet' => 'Internet' ),array( 'im im-icon-iOS-Apple' => 'iOS-Apple' ),array( 'im im-icon-Israel' => 'Israel' ),array( 'im im-icon-Italic-Text' => 'Italic-Text' ),array( 'im im-icon-Jacket-2' => 'Jacket-2' ),array( 'im im-icon-Jacket' => 'Jacket' ),array( 'im im-icon-Jamaica' => 'Jamaica' ),array( 'im im-icon-Japan' => 'Japan' ),array( 'im im-icon-Japanese-Gate' => 'Japanese-Gate' ),array( 'im im-icon-Jeans' => 'Jeans' ),array( 'im im-icon-Jeep-2' => 'Jeep-2' ),array( 'im im-icon-Jeep' => 'Jeep' ),array( 'im im-icon-Jet' => 'Jet' ),array( 'im im-icon-Joystick' => 'Joystick' ),array( 'im im-icon-Juice' => 'Juice' ),array( 'im im-icon-Jump-Rope' => 'Jump-Rope' ),array( 'im im-icon-Kangoroo' => 'Kangoroo' ),array( 'im im-icon-Kenya' => 'Kenya' ),array( 'im im-icon-Key-2' => 'Key-2' ),array( 'im im-icon-Key-3' => 'Key-3' ),array( 'im im-icon-Key-Lock' => 'Key-Lock' ),array( 'im im-icon-Key' => 'Key' ),array( 'im im-icon-Keyboard' => 'Keyboard' ),array( 'im im-icon-Keyboard3' => 'Keyboard3' ),array( 'im im-icon-Keypad' => 'Keypad' ),array( 'im im-icon-King-2' => 'King-2' ),array( 'im im-icon-King' => 'King' ),array( 'im im-icon-Kiss' => 'Kiss' ),array( 'im im-icon-Knee' => 'Knee' ),array( 'im im-icon-Knife-2' => 'Knife-2' ),array( 'im im-icon-Knife' => 'Knife' ),array( 'im im-icon-Knight' => 'Knight' ),array( 'im im-icon-Koala' => 'Koala' ),array( 'im im-icon-Korea' => 'Korea' ),array( 'im im-icon-Lamp' => 'Lamp' ),array( 'im im-icon-Landscape-2' => 'Landscape-2' ),array( 'im im-icon-Landscape' => 'Landscape' ),array( 'im im-icon-Lantern' => 'Lantern' ),array( 'im im-icon-Laptop-2' => 'Laptop-2' ),array( 'im im-icon-Laptop-3' => 'Laptop-3' ),array( 'im im-icon-Laptop-Phone' => 'Laptop-Phone' ),array( 'im im-icon-Laptop-Secure' => 'Laptop-Secure' ),array( 'im im-icon-Laptop-Tablet' => 'Laptop-Tablet' ),array( 'im im-icon-Laptop' => 'Laptop' ),array( 'im im-icon-Laser' => 'Laser' ),array( 'im im-icon-Last-FM' => 'Last-FM' ),array( 'im im-icon-Last' => 'Last' ),array( 'im im-icon-Laughing' => 'Laughing' ),array( 'im im-icon-Layer-1635' => 'Layer-1635' ),array( 'im im-icon-Layer-1646' => 'Layer-1646' ),array( 'im im-icon-Layer-Backward' => 'Layer-Backward' ),array( 'im im-icon-Layer-Forward' => 'Layer-Forward' ),array( 'im im-icon-Leafs-2' => 'Leafs-2' ),array( 'im im-icon-Leafs' => 'Leafs' ),array( 'im im-icon-Leaning-Tower' => 'Leaning-Tower' ),array( 'im im-icon-Left--Right' => 'Left--Right' ),array( 'im im-icon-Left--Right3' => 'Left--Right3' ),array( 'im im-icon-Left-2' => 'Left-2' ),array( 'im im-icon-Left-3' => 'Left-3' ),array( 'im im-icon-Left-4' => 'Left-4' ),array( 'im im-icon-Left-ToRight' => 'Left-ToRight' ),array( 'im im-icon-Left' => 'Left' ),array( 'im im-icon-Leg-2' => 'Leg-2' ),array( 'im im-icon-Leg' => 'Leg' ),array( 'im im-icon-Lego' => 'Lego' ),array( 'im im-icon-Lemon' => 'Lemon' ),array( 'im im-icon-Len-2' => 'Len-2' ),array( 'im im-icon-Len-3' => 'Len-3' ),array( 'im im-icon-Len' => 'Len' ),array( 'im im-icon-Leo-2' => 'Leo-2' ),array( 'im im-icon-Leo' => 'Leo' ),array( 'im im-icon-Leopard' => 'Leopard' ),array( 'im im-icon-Lesbian' => 'Lesbian' ),array( 'im im-icon-Lesbians' => 'Lesbians' ),array( 'im im-icon-Letter-Close' => 'Letter-Close' ),array( 'im im-icon-Letter-Open' => 'Letter-Open' ),array( 'im im-icon-Letter-Sent' => 'Letter-Sent' ),array( 'im im-icon-Libra-2' => 'Libra-2' ),array( 'im im-icon-Libra' => 'Libra' ),array( 'im im-icon-Library-2' => 'Library-2' ),array( 'im im-icon-Library' => 'Library' ),array( 'im im-icon-Life-Jacket' => 'Life-Jacket' ),array( 'im im-icon-Life-Safer' => 'Life-Safer' ),array( 'im im-icon-Light-Bulb' => 'Light-Bulb' ),array( 'im im-icon-Light-Bulb2' => 'Light-Bulb2' ),array( 'im im-icon-Light-BulbLeaf' => 'Light-BulbLeaf' ),array( 'im im-icon-Lighthouse' => 'Lighthouse' ),array( 'im im-icon-Like-2' => 'Like-2' ),array( 'im im-icon-Like' => 'Like' ),array( 'im im-icon-Line-Chart' => 'Line-Chart' ),array( 'im im-icon-Line-Chart2' => 'Line-Chart2' ),array( 'im im-icon-Line-Chart3' => 'Line-Chart3' ),array( 'im im-icon-Line-Chart4' => 'Line-Chart4' ),array( 'im im-icon-Line-Spacing' => 'Line-Spacing' ),array( 'im im-icon-Line-SpacingText' => 'Line-SpacingText' ),array( 'im im-icon-Link-2' => 'Link-2' ),array( 'im im-icon-Link' => 'Link' ),array( 'im im-icon-Linkedin-2' => 'Linkedin-2' ),array( 'im im-icon-Linkedin' => 'Linkedin' ),array( 'im im-icon-Linux' => 'Linux' ),array( 'im im-icon-Lion' => 'Lion' ),array( 'im im-icon-Livejournal' => 'Livejournal' ),array( 'im im-icon-Loading-2' => 'Loading-2' ),array( 'im im-icon-Loading-3' => 'Loading-3' ),array( 'im im-icon-Loading-Window' => 'Loading-Window' ),array( 'im im-icon-Loading' => 'Loading' ),array( 'im im-icon-Location-2' => 'Location-2' ),array( 'im im-icon-Location' => 'Location' ),array( 'im im-icon-Lock-2' => 'Lock-2' ),array( 'im im-icon-Lock-3' => 'Lock-3' ),array( 'im im-icon-Lock-User' => 'Lock-User' ),array( 'im im-icon-Lock-Window' => 'Lock-Window' ),array( 'im im-icon-Lock' => 'Lock' ),array( 'im im-icon-Lollipop-2' => 'Lollipop-2' ),array( 'im im-icon-Lollipop-3' => 'Lollipop-3' ),array( 'im im-icon-Lollipop' => 'Lollipop' ),array( 'im im-icon-Loop' => 'Loop' ),array( 'im im-icon-Loud' => 'Loud' ),array( 'im im-icon-Loudspeaker' => 'Loudspeaker' ),array( 'im im-icon-Love-2' => 'Love-2' ),array( 'im im-icon-Love-User' => 'Love-User' ),array( 'im im-icon-Love-Window' => 'Love-Window' ),array( 'im im-icon-Love' => 'Love' ),array( 'im im-icon-Lowercase-Text' => 'Lowercase-Text' ),array( 'im im-icon-Luggafe-Front' => 'Luggafe-Front' ),array( 'im im-icon-Luggage-2' => 'Luggage-2' ),array( 'im im-icon-Macro' => 'Macro' ),array( 'im im-icon-Magic-Wand' => 'Magic-Wand' ),array( 'im im-icon-Magnet' => 'Magnet' ),array( 'im im-icon-Magnifi-Glass-' => 'Magnifi-Glass-' ),array( 'im im-icon-Magnifi-Glass' => 'Magnifi-Glass' ),array( 'im im-icon-Magnifi-Glass2' => 'Magnifi-Glass2' ),array( 'im im-icon-Mail-2' => 'Mail-2' ),array( 'im im-icon-Mail-3' => 'Mail-3' ),array( 'im im-icon-Mail-Add' => 'Mail-Add' ),array( 'im im-icon-Mail-Attachement' => 'Mail-Attachement' ),array( 'im im-icon-Mail-Block' => 'Mail-Block' ),array( 'im im-icon-Mail-Delete' => 'Mail-Delete' ),array( 'im im-icon-Mail-Favorite' => 'Mail-Favorite' ),array( 'im im-icon-Mail-Forward' => 'Mail-Forward' ),array( 'im im-icon-Mail-Gallery' => 'Mail-Gallery' ),array( 'im im-icon-Mail-Inbox' => 'Mail-Inbox' ),array( 'im im-icon-Mail-Link' => 'Mail-Link' ),array( 'im im-icon-Mail-Lock' => 'Mail-Lock' ),array( 'im im-icon-Mail-Love' => 'Mail-Love' ),array( 'im im-icon-Mail-Money' => 'Mail-Money' ),array( 'im im-icon-Mail-Open' => 'Mail-Open' ),array( 'im im-icon-Mail-Outbox' => 'Mail-Outbox' ),array( 'im im-icon-Mail-Password' => 'Mail-Password' ),array( 'im im-icon-Mail-Photo' => 'Mail-Photo' ),array( 'im im-icon-Mail-Read' => 'Mail-Read' ),array( 'im im-icon-Mail-Removex' => 'Mail-Removex' ),array( 'im im-icon-Mail-Reply' => 'Mail-Reply' ),array( 'im im-icon-Mail-ReplyAll' => 'Mail-ReplyAll' ),array( 'im im-icon-Mail-Search' => 'Mail-Search' ),array( 'im im-icon-Mail-Send' => 'Mail-Send' ),array( 'im im-icon-Mail-Settings' => 'Mail-Settings' ),array( 'im im-icon-Mail-Unread' => 'Mail-Unread' ),array( 'im im-icon-Mail-Video' => 'Mail-Video' ),array( 'im im-icon-Mail-withAtSign' => 'Mail-withAtSign' ),array( 'im im-icon-Mail-WithCursors' => 'Mail-WithCursors' ),array( 'im im-icon-Mail' => 'Mail' ),array( 'im im-icon-Mailbox-Empty' => 'Mailbox-Empty' ),array( 'im im-icon-Mailbox-Full' => 'Mailbox-Full' ),array( 'im im-icon-Male-2' => 'Male-2' ),array( 'im im-icon-Male-Sign' => 'Male-Sign' ),array( 'im im-icon-Male' => 'Male' ),array( 'im im-icon-MaleFemale' => 'MaleFemale' ),array( 'im im-icon-Man-Sign' => 'Man-Sign' ),array( 'im im-icon-Management' => 'Management' ),array( 'im im-icon-Mans-Underwear' => 'Mans-Underwear' ),array( 'im im-icon-Mans-Underwear2' => 'Mans-Underwear2' ),array( 'im im-icon-Map-Marker' => 'Map-Marker' ),array( 'im im-icon-Map-Marker2' => 'Map-Marker2' ),array( 'im im-icon-Map-Marker3' => 'Map-Marker3' ),array( 'im im-icon-Map' => 'Map' ),array( 'im im-icon-Map2' => 'Map2' ),array( 'im im-icon-Marker-2' => 'Marker-2' ),array( 'im im-icon-Marker-3' => 'Marker-3' ),array( 'im im-icon-Marker' => 'Marker' ),array( 'im im-icon-Martini-Glass' => 'Martini-Glass' ),array( 'im im-icon-Mask' => 'Mask' ),array( 'im im-icon-Master-Card' => 'Master-Card' ),array( 'im im-icon-Maximize-Window' => 'Maximize-Window' ),array( 'im im-icon-Maximize' => 'Maximize' ),array( 'im im-icon-Medal-2' => 'Medal-2' ),array( 'im im-icon-Medal-3' => 'Medal-3' ),array( 'im im-icon-Medal' => 'Medal' ),array( 'im im-icon-Medical-Sign' => 'Medical-Sign' ),array( 'im im-icon-Medicine-2' => 'Medicine-2' ),array( 'im im-icon-Medicine-3' => 'Medicine-3' ),array( 'im im-icon-Medicine' => 'Medicine' ),array( 'im im-icon-Megaphone' => 'Megaphone' ),array( 'im im-icon-Memory-Card' => 'Memory-Card' ),array( 'im im-icon-Memory-Card2' => 'Memory-Card2' ),array( 'im im-icon-Memory-Card3' => 'Memory-Card3' ),array( 'im im-icon-Men' => 'Men' ),array( 'im im-icon-Menorah' => 'Menorah' ),array( 'im im-icon-Mens' => 'Mens' ),array( 'im im-icon-Metacafe' => 'Metacafe' ),array( 'im im-icon-Mexico' => 'Mexico' ),array( 'im im-icon-Mic' => 'Mic' ),array( 'im im-icon-Microphone-2' => 'Microphone-2' ),array( 'im im-icon-Microphone-3' => 'Microphone-3' ),array( 'im im-icon-Microphone-4' => 'Microphone-4' ),array( 'im im-icon-Microphone-5' => 'Microphone-5' ),array( 'im im-icon-Microphone-6' => 'Microphone-6' ),array( 'im im-icon-Microphone-7' => 'Microphone-7' ),array( 'im im-icon-Microphone' => 'Microphone' ),array( 'im im-icon-Microscope' => 'Microscope' ),array( 'im im-icon-Milk-Bottle' => 'Milk-Bottle' ),array( 'im im-icon-Mine' => 'Mine' ),array( 'im im-icon-Minimize-Maximize-Close-Window' => 'Minimize-Maximize-Close-Window' ),array( 'im im-icon-Minimize-Window' => 'Minimize-Window' ),array( 'im im-icon-Minimize' => 'Minimize' ),array( 'im im-icon-Mirror' => 'Mirror' ),array( 'im im-icon-Mixer' => 'Mixer' ),array( 'im im-icon-Mixx' => 'Mixx' ),array( 'im im-icon-Money-2' => 'Money-2' ),array( 'im im-icon-Money-Bag' => 'Money-Bag' ),array( 'im im-icon-Money-Smiley' => 'Money-Smiley' ),array( 'im im-icon-Money' => 'Money' ),array( 'im im-icon-Monitor-2' => 'Monitor-2' ),array( 'im im-icon-Monitor-3' => 'Monitor-3' ),array( 'im im-icon-Monitor-4' => 'Monitor-4' ),array( 'im im-icon-Monitor-5' => 'Monitor-5' ),array( 'im im-icon-Monitor-Analytics' => 'Monitor-Analytics' ),array( 'im im-icon-Monitor-Laptop' => 'Monitor-Laptop' ),array( 'im im-icon-Monitor-phone' => 'Monitor-phone' ),array( 'im im-icon-Monitor-Tablet' => 'Monitor-Tablet' ),array( 'im im-icon-Monitor-Vertical' => 'Monitor-Vertical' ),array( 'im im-icon-Monitor' => 'Monitor' ),array( 'im im-icon-Monitoring' => 'Monitoring' ),array( 'im im-icon-Monkey' => 'Monkey' ),array( 'im im-icon-Monster' => 'Monster' ),array( 'im im-icon-Morocco' => 'Morocco' ),array( 'im im-icon-Motorcycle' => 'Motorcycle' ),array( 'im im-icon-Mouse-2' => 'Mouse-2' ),array( 'im im-icon-Mouse-3' => 'Mouse-3' ),array( 'im im-icon-Mouse-4' => 'Mouse-4' ),array( 'im im-icon-Mouse-Pointer' => 'Mouse-Pointer' ),array( 'im im-icon-Mouse' => 'Mouse' ),array( 'im im-icon-Moustache-Smiley' => 'Moustache-Smiley' ),array( 'im im-icon-Movie-Ticket' => 'Movie-Ticket' ),array( 'im im-icon-Movie' => 'Movie' ),array( 'im im-icon-Mp3-File' => 'Mp3-File' ),array( 'im im-icon-Museum' => 'Museum' ),array( 'im im-icon-Mushroom' => 'Mushroom' ),array( 'im im-icon-Music-Note' => 'Music-Note' ),array( 'im im-icon-Music-Note2' => 'Music-Note2' ),array( 'im im-icon-Music-Note3' => 'Music-Note3' ),array( 'im im-icon-Music-Note4' => 'Music-Note4' ),array( 'im im-icon-Music-Player' => 'Music-Player' ),array( 'im im-icon-Mustache-2' => 'Mustache-2' ),array( 'im im-icon-Mustache-3' => 'Mustache-3' ),array( 'im im-icon-Mustache-4' => 'Mustache-4' ),array( 'im im-icon-Mustache-5' => 'Mustache-5' ),array( 'im im-icon-Mustache-6' => 'Mustache-6' ),array( 'im im-icon-Mustache-7' => 'Mustache-7' ),array( 'im im-icon-Mustache-8' => 'Mustache-8' ),array( 'im im-icon-Mustache' => 'Mustache' ),array( 'im im-icon-Mute' => 'Mute' ),array( 'im im-icon-Myspace' => 'Myspace' ),array( 'im im-icon-Navigat-Start' => 'Navigat-Start' ),array( 'im im-icon-Navigate-End' => 'Navigate-End' ),array( 'im im-icon-Navigation-LeftWindow' => 'Navigation-LeftWindow' ),array( 'im im-icon-Navigation-RightWindow' => 'Navigation-RightWindow' ),array( 'im im-icon-Nepal' => 'Nepal' ),array( 'im im-icon-Netscape' => 'Netscape' ),array( 'im im-icon-Network-Window' => 'Network-Window' ),array( 'im im-icon-Network' => 'Network' ),array( 'im im-icon-Neutron' => 'Neutron' ),array( 'im im-icon-New-Mail' => 'New-Mail' ),array( 'im im-icon-New-Tab' => 'New-Tab' ),array( 'im im-icon-Newspaper-2' => 'Newspaper-2' ),array( 'im im-icon-Newspaper' => 'Newspaper' ),array( 'im im-icon-Newsvine' => 'Newsvine' ),array( 'im im-icon-Next2' => 'Next2' ),array( 'im im-icon-Next-3' => 'Next-3' ),array( 'im im-icon-Next-Music' => 'Next-Music' ),array( 'im im-icon-Next' => 'Next' ),array( 'im im-icon-No-Battery' => 'No-Battery' ),array( 'im im-icon-No-Drop' => 'No-Drop' ),array( 'im im-icon-No-Flash' => 'No-Flash' ),array( 'im im-icon-No-Smoking' => 'No-Smoking' ),array( 'im im-icon-Noose' => 'Noose' ),array( 'im im-icon-Normal-Text' => 'Normal-Text' ),array( 'im im-icon-Note' => 'Note' ),array( 'im im-icon-Notepad-2' => 'Notepad-2' ),array( 'im im-icon-Notepad' => 'Notepad' ),array( 'im im-icon-Nuclear' => 'Nuclear' ),array( 'im im-icon-Numbering-List' => 'Numbering-List' ),array( 'im im-icon-Nurse' => 'Nurse' ),array( 'im im-icon-Office-Lamp' => 'Office-Lamp' ),array( 'im im-icon-Office' => 'Office' ),array( 'im im-icon-Oil' => 'Oil' ),array( 'im im-icon-Old-Camera' => 'Old-Camera' ),array( 'im im-icon-Old-Cassette' => 'Old-Cassette' ),array( 'im im-icon-Old-Clock' => 'Old-Clock' ),array( 'im im-icon-Old-Radio' => 'Old-Radio' ),array( 'im im-icon-Old-Sticky' => 'Old-Sticky' ),array( 'im im-icon-Old-Sticky2' => 'Old-Sticky2' ),array( 'im im-icon-Old-Telephone' => 'Old-Telephone' ),array( 'im im-icon-Old-TV' => 'Old-TV' ),array( 'im im-icon-On-Air' => 'On-Air' ),array( 'im im-icon-On-Off-2' => 'On-Off-2' ),array( 'im im-icon-On-Off-3' => 'On-Off-3' ),array( 'im im-icon-On-off' => 'On-off' ),array( 'im im-icon-One-Finger' => 'One-Finger' ),array( 'im im-icon-One-FingerTouch' => 'One-FingerTouch' ),array( 'im im-icon-One-Window' => 'One-Window' ),array( 'im im-icon-Open-Banana' => 'Open-Banana' ),array( 'im im-icon-Open-Book' => 'Open-Book' ),array( 'im im-icon-Opera-House' => 'Opera-House' ),array( 'im im-icon-Opera' => 'Opera' ),array( 'im im-icon-Optimization' => 'Optimization' ),array( 'im im-icon-Orientation-2' => 'Orientation-2' ),array( 'im im-icon-Orientation-3' => 'Orientation-3' ),array( 'im im-icon-Orientation' => 'Orientation' ),array( 'im im-icon-Orkut' => 'Orkut' ),array( 'im im-icon-Ornament' => 'Ornament' ),array( 'im im-icon-Over-Time' => 'Over-Time' ),array( 'im im-icon-Over-Time2' => 'Over-Time2' ),array( 'im im-icon-Owl' => 'Owl' ),array( 'im im-icon-Pac-Man' => 'Pac-Man' ),array( 'im im-icon-Paint-Brush' => 'Paint-Brush' ),array( 'im im-icon-Paint-Bucket' => 'Paint-Bucket' ),array( 'im im-icon-Paintbrush' => 'Paintbrush' ),array( 'im im-icon-Palette' => 'Palette' ),array( 'im im-icon-Palm-Tree' => 'Palm-Tree' ),array( 'im im-icon-Panda' => 'Panda' ),array( 'im im-icon-Panorama' => 'Panorama' ),array( 'im im-icon-Pantheon' => 'Pantheon' ),array( 'im im-icon-Pantone' => 'Pantone' ),array( 'im im-icon-Pants' => 'Pants' ),array( 'im im-icon-Paper-Plane' => 'Paper-Plane' ),array( 'im im-icon-Paper' => 'Paper' ),array( 'im im-icon-Parasailing' => 'Parasailing' ),array( 'im im-icon-Parrot' => 'Parrot' ),array( 'im im-icon-Password-2shopping' => 'Password-2shopping' ),array( 'im im-icon-Password-Field' => 'Password-Field' ),array( 'im im-icon-Password-shopping' => 'Password-shopping' ),array( 'im im-icon-Password' => 'Password' ),array( 'im im-icon-pause-2' => 'pause-2' ),array( 'im im-icon-Pause' => 'Pause' ),array( 'im im-icon-Paw' => 'Paw' ),array( 'im im-icon-Pawn' => 'Pawn' ),array( 'im im-icon-Paypal' => 'Paypal' ),array( 'im im-icon-Pen-2' => 'Pen-2' ),array( 'im im-icon-Pen-3' => 'Pen-3' ),array( 'im im-icon-Pen-4' => 'Pen-4' ),array( 'im im-icon-Pen-5' => 'Pen-5' ),array( 'im im-icon-Pen-6' => 'Pen-6' ),array( 'im im-icon-Pen' => 'Pen' ),array( 'im im-icon-Pencil-Ruler' => 'Pencil-Ruler' ),array( 'im im-icon-Pencil' => 'Pencil' ),array( 'im im-icon-Penguin' => 'Penguin' ),array( 'im im-icon-Pentagon' => 'Pentagon' ),array( 'im im-icon-People-onCloud' => 'People-onCloud' ),array( 'im im-icon-Pepper-withFire' => 'Pepper-withFire' ),array( 'im im-icon-Pepper' => 'Pepper' ),array( 'im im-icon-Petrol' => 'Petrol' ),array( 'im im-icon-Petronas-Tower' => 'Petronas-Tower' ),array( 'im im-icon-Philipines' => 'Philipines' ),array( 'im im-icon-Phone-2' => 'Phone-2' ),array( 'im im-icon-Phone-3' => 'Phone-3' ),array( 'im im-icon-Phone-3G' => 'Phone-3G' ),array( 'im im-icon-Phone-4G' => 'Phone-4G' ),array( 'im im-icon-Phone-Simcard' => 'Phone-Simcard' ),array( 'im im-icon-Phone-SMS' => 'Phone-SMS' ),array( 'im im-icon-Phone-Wifi' => 'Phone-Wifi' ),array( 'im im-icon-Phone' => 'Phone' ),array( 'im im-icon-Photo-2' => 'Photo-2' ),array( 'im im-icon-Photo-3' => 'Photo-3' ),array( 'im im-icon-Photo-Album' => 'Photo-Album' ),array( 'im im-icon-Photo-Album2' => 'Photo-Album2' ),array( 'im im-icon-Photo-Album3' => 'Photo-Album3' ),array( 'im im-icon-Photo' => 'Photo' ),array( 'im im-icon-Photos' => 'Photos' ),array( 'im im-icon-Physics' => 'Physics' ),array( 'im im-icon-Pi' => 'Pi' ),array( 'im im-icon-Piano' => 'Piano' ),array( 'im im-icon-Picasa' => 'Picasa' ),array( 'im im-icon-Pie-Chart' => 'Pie-Chart' ),array( 'im im-icon-Pie-Chart2' => 'Pie-Chart2' ),array( 'im im-icon-Pie-Chart3' => 'Pie-Chart3' ),array( 'im im-icon-Pilates-2' => 'Pilates-2' ),array( 'im im-icon-Pilates-3' => 'Pilates-3' ),array( 'im im-icon-Pilates' => 'Pilates' ),array( 'im im-icon-Pilot' => 'Pilot' ),array( 'im im-icon-Pinch' => 'Pinch' ),array( 'im im-icon-Ping-Pong' => 'Ping-Pong' ),array( 'im im-icon-Pinterest' => 'Pinterest' ),array( 'im im-icon-Pipe' => 'Pipe' ),array( 'im im-icon-Pipette' => 'Pipette' ),array( 'im im-icon-Piramids' => 'Piramids' ),array( 'im im-icon-Pisces-2' => 'Pisces-2' ),array( 'im im-icon-Pisces' => 'Pisces' ),array( 'im im-icon-Pizza-Slice' => 'Pizza-Slice' ),array( 'im im-icon-Pizza' => 'Pizza' ),array( 'im im-icon-Plane-2' => 'Plane-2' ),array( 'im im-icon-Plane' => 'Plane' ),array( 'im im-icon-Plant' => 'Plant' ),array( 'im im-icon-Plasmid' => 'Plasmid' ),array( 'im im-icon-Plaster' => 'Plaster' ),array( 'im im-icon-Plastic-CupPhone' => 'Plastic-CupPhone' ),array( 'im im-icon-Plastic-CupPhone2' => 'Plastic-CupPhone2' ),array( 'im im-icon-Plate' => 'Plate' ),array( 'im im-icon-Plates' => 'Plates' ),array( 'im im-icon-Plaxo' => 'Plaxo' ),array( 'im im-icon-Play-Music' => 'Play-Music' ),array( 'im im-icon-Plug-In' => 'Plug-In' ),array( 'im im-icon-Plug-In2' => 'Plug-In2' ),array( 'im im-icon-Plurk' => 'Plurk' ),array( 'im im-icon-Pointer' => 'Pointer' ),array( 'im im-icon-Poland' => 'Poland' ),array( 'im im-icon-Police-Man' => 'Police-Man' ),array( 'im im-icon-Police-Station' => 'Police-Station' ),array( 'im im-icon-Police-Woman' => 'Police-Woman' ),array( 'im im-icon-Police' => 'Police' ),array( 'im im-icon-Polo-Shirt' => 'Polo-Shirt' ),array( 'im im-icon-Portrait' => 'Portrait' ),array( 'im im-icon-Portugal' => 'Portugal' ),array( 'im im-icon-Post-Mail' => 'Post-Mail' ),array( 'im im-icon-Post-Mail2' => 'Post-Mail2' ),array( 'im im-icon-Post-Office' => 'Post-Office' ),array( 'im im-icon-Post-Sign' => 'Post-Sign' ),array( 'im im-icon-Post-Sign2ways' => 'Post-Sign2ways' ),array( 'im im-icon-Posterous' => 'Posterous' ),array( 'im im-icon-Pound-Sign' => 'Pound-Sign' ),array( 'im im-icon-Pound-Sign2' => 'Pound-Sign2' ),array( 'im im-icon-Pound' => 'Pound' ),array( 'im im-icon-Power-2' => 'Power-2' ),array( 'im im-icon-Power-3' => 'Power-3' ),array( 'im im-icon-Power-Cable' => 'Power-Cable' ),array( 'im im-icon-Power-Station' => 'Power-Station' ),array( 'im im-icon-Power' => 'Power' ),array( 'im im-icon-Prater' => 'Prater' ),array( 'im im-icon-Present' => 'Present' ),array( 'im im-icon-Presents' => 'Presents' ),array( 'im im-icon-Press' => 'Press' ),array( 'im im-icon-Preview' => 'Preview' ),array( 'im im-icon-Previous' => 'Previous' ),array( 'im im-icon-Pricing' => 'Pricing' ),array( 'im im-icon-Printer' => 'Printer' ),array( 'im im-icon-Professor' => 'Professor' ),array( 'im im-icon-Profile' => 'Profile' ),array( 'im im-icon-Project' => 'Project' ),array( 'im im-icon-Projector-2' => 'Projector-2' ),array( 'im im-icon-Projector' => 'Projector' ),array( 'im im-icon-Pulse' => 'Pulse' ),array( 'im im-icon-Pumpkin' => 'Pumpkin' ),array( 'im im-icon-Punk' => 'Punk' ),array( 'im im-icon-Punker' => 'Punker' ),array( 'im im-icon-Puzzle' => 'Puzzle' ),array( 'im im-icon-QIK' => 'QIK' ),array( 'im im-icon-QR-Code' => 'QR-Code' ),array( 'im im-icon-Queen-2' => 'Queen-2' ),array( 'im im-icon-Queen' => 'Queen' ),array( 'im im-icon-Quill-2' => 'Quill-2' ),array( 'im im-icon-Quill-3' => 'Quill-3' ),array( 'im im-icon-Quill' => 'Quill' ),array( 'im im-icon-Quotes-2' => 'Quotes-2' ),array( 'im im-icon-Quotes' => 'Quotes' ),array( 'im im-icon-Radio' => 'Radio' ),array( 'im im-icon-Radioactive' => 'Radioactive' ),array( 'im im-icon-Rafting' => 'Rafting' ),array( 'im im-icon-Rain-Drop' => 'Rain-Drop' ),array( 'im im-icon-Rainbow-2' => 'Rainbow-2' ),array( 'im im-icon-Rainbow' => 'Rainbow' ),array( 'im im-icon-Ram' => 'Ram' ),array( 'im im-icon-Razzor-Blade' => 'Razzor-Blade' ),array( 'im im-icon-Receipt-2' => 'Receipt-2' ),array( 'im im-icon-Receipt-3' => 'Receipt-3' ),array( 'im im-icon-Receipt-4' => 'Receipt-4' ),array( 'im im-icon-Receipt' => 'Receipt' ),array( 'im im-icon-Record2' => 'Record2' ),array( 'im im-icon-Record-3' => 'Record-3' ),array( 'im im-icon-Record-Music' => 'Record-Music' ),array( 'im im-icon-Record' => 'Record' ),array( 'im im-icon-Recycling-2' => 'Recycling-2' ),array( 'im im-icon-Recycling' => 'Recycling' ),array( 'im im-icon-Reddit' => 'Reddit' ),array( 'im im-icon-Redhat' => 'Redhat' ),array( 'im im-icon-Redirect' => 'Redirect' ),array( 'im im-icon-Redo' => 'Redo' ),array( 'im im-icon-Reel' => 'Reel' ),array( 'im im-icon-Refinery' => 'Refinery' ),array( 'im im-icon-Refresh-Window' => 'Refresh-Window' ),array( 'im im-icon-Refresh' => 'Refresh' ),array( 'im im-icon-Reload-2' => 'Reload-2' ),array( 'im im-icon-Reload-3' => 'Reload-3' ),array( 'im im-icon-Reload' => 'Reload' ),array( 'im im-icon-Remote-Controll' => 'Remote-Controll' ),array( 'im im-icon-Remote-Controll2' => 'Remote-Controll2' ),array( 'im im-icon-Remove-Bag' => 'Remove-Bag' ),array( 'im im-icon-Remove-Basket' => 'Remove-Basket' ),array( 'im im-icon-Remove-Cart' => 'Remove-Cart' ),array( 'im im-icon-Remove-File' => 'Remove-File' ),array( 'im im-icon-Remove-User' => 'Remove-User' ),array( 'im im-icon-Remove-Window' => 'Remove-Window' ),array( 'im im-icon-Remove' => 'Remove' ),array( 'im im-icon-Rename' => 'Rename' ),array( 'im im-icon-Repair' => 'Repair' ),array( 'im im-icon-Repeat-2' => 'Repeat-2' ),array( 'im im-icon-Repeat-3' => 'Repeat-3' ),array( 'im im-icon-Repeat-4' => 'Repeat-4' ),array( 'im im-icon-Repeat-5' => 'Repeat-5' ),array( 'im im-icon-Repeat-6' => 'Repeat-6' ),array( 'im im-icon-Repeat-7' => 'Repeat-7' ),array( 'im im-icon-Repeat' => 'Repeat' ),array( 'im im-icon-Reset' => 'Reset' ),array( 'im im-icon-Resize' => 'Resize' ),array( 'im im-icon-Restore-Window' => 'Restore-Window' ),array( 'im im-icon-Retouching' => 'Retouching' ),array( 'im im-icon-Retro-Camera' => 'Retro-Camera' ),array( 'im im-icon-Retro' => 'Retro' ),array( 'im im-icon-Retweet' => 'Retweet' ),array( 'im im-icon-Reverbnation' => 'Reverbnation' ),array( 'im im-icon-Rewind' => 'Rewind' ),array( 'im im-icon-RGB' => 'RGB' ),array( 'im im-icon-Ribbon-2' => 'Ribbon-2' ),array( 'im im-icon-Ribbon-3' => 'Ribbon-3' ),array( 'im im-icon-Ribbon' => 'Ribbon' ),array( 'im im-icon-Right-2' => 'Right-2' ),array( 'im im-icon-Right-3' => 'Right-3' ),array( 'im im-icon-Right-4' => 'Right-4' ),array( 'im im-icon-Right-ToLeft' => 'Right-ToLeft' ),array( 'im im-icon-Right' => 'Right' ),array( 'im im-icon-Road-2' => 'Road-2' ),array( 'im im-icon-Road-3' => 'Road-3' ),array( 'im im-icon-Road' => 'Road' ),array( 'im im-icon-Robot-2' => 'Robot-2' ),array( 'im im-icon-Robot' => 'Robot' ),array( 'im im-icon-Rock-andRoll' => 'Rock-andRoll' ),array( 'im im-icon-Rocket' => 'Rocket' ),array( 'im im-icon-Roller' => 'Roller' ),array( 'im im-icon-Roof' => 'Roof' ),array( 'im im-icon-Rook' => 'Rook' ),array( 'im im-icon-Rotate-Gesture' => 'Rotate-Gesture' ),array( 'im im-icon-Rotate-Gesture2' => 'Rotate-Gesture2' ),array( 'im im-icon-Rotate-Gesture3' => 'Rotate-Gesture3' ),array( 'im im-icon-Rotation-390' => 'Rotation-390' ),array( 'im im-icon-Rotation' => 'Rotation' ),array( 'im im-icon-Router-2' => 'Router-2' ),array( 'im im-icon-Router' => 'Router' ),array( 'im im-icon-RSS' => 'RSS' ),array( 'im im-icon-Ruler-2' => 'Ruler-2' ),array( 'im im-icon-Ruler' => 'Ruler' ),array( 'im im-icon-Running-Shoes' => 'Running-Shoes' ),array( 'im im-icon-Running' => 'Running' ),array( 'im im-icon-Safari' => 'Safari' ),array( 'im im-icon-Safe-Box' => 'Safe-Box' ),array( 'im im-icon-Safe-Box2' => 'Safe-Box2' ),array( 'im im-icon-Safety-PinClose' => 'Safety-PinClose' ),array( 'im im-icon-Safety-PinOpen' => 'Safety-PinOpen' ),array( 'im im-icon-Sagittarus-2' => 'Sagittarus-2' ),array( 'im im-icon-Sagittarus' => 'Sagittarus' ),array( 'im im-icon-Sailing-Ship' => 'Sailing-Ship' ),array( 'im im-icon-Sand-watch' => 'Sand-watch' ),array( 'im im-icon-Sand-watch2' => 'Sand-watch2' ),array( 'im im-icon-Santa-Claus' => 'Santa-Claus' ),array( 'im im-icon-Santa-Claus2' => 'Santa-Claus2' ),array( 'im im-icon-Santa-onSled' => 'Santa-onSled' ),array( 'im im-icon-Satelite-2' => 'Satelite-2' ),array( 'im im-icon-Satelite' => 'Satelite' ),array( 'im im-icon-Save-Window' => 'Save-Window' ),array( 'im im-icon-Save' => 'Save' ),array( 'im im-icon-Saw' => 'Saw' ),array( 'im im-icon-Saxophone' => 'Saxophone' ),array( 'im im-icon-Scale' => 'Scale' ),array( 'im im-icon-Scarf' => 'Scarf' ),array( 'im im-icon-Scissor' => 'Scissor' ),array( 'im im-icon-Scooter-Front' => 'Scooter-Front' ),array( 'im im-icon-Scooter' => 'Scooter' ),array( 'im im-icon-Scorpio-2' => 'Scorpio-2' ),array( 'im im-icon-Scorpio' => 'Scorpio' ),array( 'im im-icon-Scotland' => 'Scotland' ),array( 'im im-icon-Screwdriver' => 'Screwdriver' ),array( 'im im-icon-Scroll-Fast' => 'Scroll-Fast' ),array( 'im im-icon-Scroll' => 'Scroll' ),array( 'im im-icon-Scroller-2' => 'Scroller-2' ),array( 'im im-icon-Scroller' => 'Scroller' ),array( 'im im-icon-Sea-Dog' => 'Sea-Dog' ),array( 'im im-icon-Search-onCloud' => 'Search-onCloud' ),array( 'im im-icon-Search-People' => 'Search-People' ),array( 'im im-icon-secound' => 'secound' ),array( 'im im-icon-secound2' => 'secound2' ),array( 'im im-icon-Security-Block' => 'Security-Block' ),array( 'im im-icon-Security-Bug' => 'Security-Bug' ),array( 'im im-icon-Security-Camera' => 'Security-Camera' ),array( 'im im-icon-Security-Check' => 'Security-Check' ),array( 'im im-icon-Security-Settings' => 'Security-Settings' ),array( 'im im-icon-Security-Smiley' => 'Security-Smiley' ),array( 'im im-icon-Securiy-Remove' => 'Securiy-Remove' ),array( 'im im-icon-Seed' => 'Seed' ),array( 'im im-icon-Selfie' => 'Selfie' ),array( 'im im-icon-Serbia' => 'Serbia' ),array( 'im im-icon-Server-2' => 'Server-2' ),array( 'im im-icon-Server' => 'Server' ),array( 'im im-icon-Servers' => 'Servers' ),array( 'im im-icon-Settings-Window' => 'Settings-Window' ),array( 'im im-icon-Sewing-Machine' => 'Sewing-Machine' ),array( 'im im-icon-Sexual' => 'Sexual' ),array( 'im im-icon-Share-onCloud' => 'Share-onCloud' ),array( 'im im-icon-Share-Window' => 'Share-Window' ),array( 'im im-icon-Share' => 'Share' ),array( 'im im-icon-Sharethis' => 'Sharethis' ),array( 'im im-icon-Shark' => 'Shark' ),array( 'im im-icon-Sheep' => 'Sheep' ),array( 'im im-icon-Sheriff-Badge' => 'Sheriff-Badge' ),array( 'im im-icon-Shield' => 'Shield' ),array( 'im im-icon-Ship-2' => 'Ship-2' ),array( 'im im-icon-Ship' => 'Ship' ),array( 'im im-icon-Shirt' => 'Shirt' ),array( 'im im-icon-Shoes-2' => 'Shoes-2' ),array( 'im im-icon-Shoes-3' => 'Shoes-3' ),array( 'im im-icon-Shoes' => 'Shoes' ),array( 'im im-icon-Shop-2' => 'Shop-2' ),array( 'im im-icon-Shop-3' => 'Shop-3' ),array( 'im im-icon-Shop-4' => 'Shop-4' ),array( 'im im-icon-Shop' => 'Shop' ),array( 'im im-icon-Shopping-Bag' => 'Shopping-Bag' ),array( 'im im-icon-Shopping-Basket' => 'Shopping-Basket' ),array( 'im im-icon-Shopping-Cart' => 'Shopping-Cart' ),array( 'im im-icon-Short-Pants' => 'Short-Pants' ),array( 'im im-icon-Shoutwire' => 'Shoutwire' ),array( 'im im-icon-Shovel' => 'Shovel' ),array( 'im im-icon-Shuffle-2' => 'Shuffle-2' ),array( 'im im-icon-Shuffle-3' => 'Shuffle-3' ),array( 'im im-icon-Shuffle-4' => 'Shuffle-4' ),array( 'im im-icon-Shuffle' => 'Shuffle' ),array( 'im im-icon-Shutter' => 'Shutter' ),array( 'im im-icon-Sidebar-Window' => 'Sidebar-Window' ),array( 'im im-icon-Signal' => 'Signal' ),array( 'im im-icon-Singapore' => 'Singapore' ),array( 'im im-icon-Skate-Shoes' => 'Skate-Shoes' ),array( 'im im-icon-Skateboard-2' => 'Skateboard-2' ),array( 'im im-icon-Skateboard' => 'Skateboard' ),array( 'im im-icon-Skeleton' => 'Skeleton' ),array( 'im im-icon-Ski' => 'Ski' ),array( 'im im-icon-Skirt' => 'Skirt' ),array( 'im im-icon-Skrill' => 'Skrill' ),array( 'im im-icon-Skull' => 'Skull' ),array( 'im im-icon-Skydiving' => 'Skydiving' ),array( 'im im-icon-Skype' => 'Skype' ),array( 'im im-icon-Sled-withGifts' => 'Sled-withGifts' ),array( 'im im-icon-Sled' => 'Sled' ),array( 'im im-icon-Sleeping' => 'Sleeping' ),array( 'im im-icon-Sleet' => 'Sleet' ),array( 'im im-icon-Slippers' => 'Slippers' ),array( 'im im-icon-Smart' => 'Smart' ),array( 'im im-icon-Smartphone-2' => 'Smartphone-2' ),array( 'im im-icon-Smartphone-3' => 'Smartphone-3' ),array( 'im im-icon-Smartphone-4' => 'Smartphone-4' ),array( 'im im-icon-Smartphone-Secure' => 'Smartphone-Secure' ),array( 'im im-icon-Smartphone' => 'Smartphone' ),array( 'im im-icon-Smile' => 'Smile' ),array( 'im im-icon-Smoking-Area' => 'Smoking-Area' ),array( 'im im-icon-Smoking-Pipe' => 'Smoking-Pipe' ),array( 'im im-icon-Snake' => 'Snake' ),array( 'im im-icon-Snorkel' => 'Snorkel' ),array( 'im im-icon-Snow-2' => 'Snow-2' ),array( 'im im-icon-Snow-Dome' => 'Snow-Dome' ),array( 'im im-icon-Snow-Storm' => 'Snow-Storm' ),array( 'im im-icon-Snow' => 'Snow' ),array( 'im im-icon-Snowflake-2' => 'Snowflake-2' ),array( 'im im-icon-Snowflake-3' => 'Snowflake-3' ),array( 'im im-icon-Snowflake-4' => 'Snowflake-4' ),array( 'im im-icon-Snowflake' => 'Snowflake' ),array( 'im im-icon-Snowman' => 'Snowman' ),array( 'im im-icon-Soccer-Ball' => 'Soccer-Ball' ),array( 'im im-icon-Soccer-Shoes' => 'Soccer-Shoes' ),array( 'im im-icon-Socks' => 'Socks' ),array( 'im im-icon-Solar' => 'Solar' ),array( 'im im-icon-Sound-Wave' => 'Sound-Wave' ),array( 'im im-icon-Sound' => 'Sound' ),array( 'im im-icon-Soundcloud' => 'Soundcloud' ),array( 'im im-icon-Soup' => 'Soup' ),array( 'im im-icon-South-Africa' => 'South-Africa' ),array( 'im im-icon-Space-Needle' => 'Space-Needle' ),array( 'im im-icon-Spain' => 'Spain' ),array( 'im im-icon-Spam-Mail' => 'Spam-Mail' ),array( 'im im-icon-Speach-Bubble' => 'Speach-Bubble' ),array( 'im im-icon-Speach-Bubble2' => 'Speach-Bubble2' ),array( 'im im-icon-Speach-Bubble3' => 'Speach-Bubble3' ),array( 'im im-icon-Speach-Bubble4' => 'Speach-Bubble4' ),array( 'im im-icon-Speach-Bubble5' => 'Speach-Bubble5' ),array( 'im im-icon-Speach-Bubble6' => 'Speach-Bubble6' ),array( 'im im-icon-Speach-Bubble7' => 'Speach-Bubble7' ),array( 'im im-icon-Speach-Bubble8' => 'Speach-Bubble8' ),array( 'im im-icon-Speach-Bubble9' => 'Speach-Bubble9' ),array( 'im im-icon-Speach-Bubble10' => 'Speach-Bubble10' ),array( 'im im-icon-Speach-Bubble11' => 'Speach-Bubble11' ),array( 'im im-icon-Speach-Bubble12' => 'Speach-Bubble12' ),array( 'im im-icon-Speach-Bubble13' => 'Speach-Bubble13' ),array( 'im im-icon-Speach-BubbleAsking' => 'Speach-BubbleAsking' ),array( 'im im-icon-Speach-BubbleComic' => 'Speach-BubbleComic' ),array( 'im im-icon-Speach-BubbleComic2' => 'Speach-BubbleComic2' ),array( 'im im-icon-Speach-BubbleComic3' => 'Speach-BubbleComic3' ),array( 'im im-icon-Speach-BubbleComic4' => 'Speach-BubbleComic4' ),array( 'im im-icon-Speach-BubbleDialog' => 'Speach-BubbleDialog' ),array( 'im im-icon-Speach-Bubbles' => 'Speach-Bubbles' ),array( 'im im-icon-Speak-2' => 'Speak-2' ),array( 'im im-icon-Speak' => 'Speak' ),array( 'im im-icon-Speaker-2' => 'Speaker-2' ),array( 'im im-icon-Speaker' => 'Speaker' ),array( 'im im-icon-Spell-Check' => 'Spell-Check' ),array( 'im im-icon-Spell-CheckABC' => 'Spell-CheckABC' ),array( 'im im-icon-Spermium' => 'Spermium' ),array( 'im im-icon-Spider' => 'Spider' ),array( 'im im-icon-Spiderweb' => 'Spiderweb' ),array( 'im im-icon-Split-FourSquareWindow' => 'Split-FourSquareWindow' ),array( 'im im-icon-Split-Horizontal' => 'Split-Horizontal' ),array( 'im im-icon-Split-Horizontal2Window' => 'Split-Horizontal2Window' ),array( 'im im-icon-Split-Vertical' => 'Split-Vertical' ),array( 'im im-icon-Split-Vertical2' => 'Split-Vertical2' ),array( 'im im-icon-Split-Window' => 'Split-Window' ),array( 'im im-icon-Spoder' => 'Spoder' ),array( 'im im-icon-Spoon' => 'Spoon' ),array( 'im im-icon-Sport-Mode' => 'Sport-Mode' ),array( 'im im-icon-Sports-Clothings1' => 'Sports-Clothings1' ),array( 'im im-icon-Sports-Clothings2' => 'Sports-Clothings2' ),array( 'im im-icon-Sports-Shirt' => 'Sports-Shirt' ),array( 'im im-icon-Spot' => 'Spot' ),array( 'im im-icon-Spray' => 'Spray' ),array( 'im im-icon-Spread' => 'Spread' ),array( 'im im-icon-Spring' => 'Spring' ),array( 'im im-icon-Spurl' => 'Spurl' ),array( 'im im-icon-Spy' => 'Spy' ),array( 'im im-icon-Squirrel' => 'Squirrel' ),array( 'im im-icon-SSL' => 'SSL' ),array( 'im im-icon-St-BasilsCathedral' => 'St-BasilsCathedral' ),array( 'im im-icon-St-PaulsCathedral' => 'St-PaulsCathedral' ),array( 'im im-icon-Stamp-2' => 'Stamp-2' ),array( 'im im-icon-Stamp' => 'Stamp' ),array( 'im im-icon-Stapler' => 'Stapler' ),array( 'im im-icon-Star-Track' => 'Star-Track' ),array( 'im im-icon-Star' => 'Star' ),array( 'im im-icon-Starfish' => 'Starfish' ),array( 'im im-icon-Start2' => 'Start2' ),array( 'im im-icon-Start-3' => 'Start-3' ),array( 'im im-icon-Start-ways' => 'Start-ways' ),array( 'im im-icon-Start' => 'Start' ),array( 'im im-icon-Statistic' => 'Statistic' ),array( 'im im-icon-Stethoscope' => 'Stethoscope' ),array( 'im im-icon-stop--2' => 'stop--2' ),array( 'im im-icon-Stop-Music' => 'Stop-Music' ),array( 'im im-icon-Stop' => 'Stop' ),array( 'im im-icon-Stopwatch-2' => 'Stopwatch-2' ),array( 'im im-icon-Stopwatch' => 'Stopwatch' ),array( 'im im-icon-Storm' => 'Storm' ),array( 'im im-icon-Street-View' => 'Street-View' ),array( 'im im-icon-Street-View2' => 'Street-View2' ),array( 'im im-icon-Strikethrough-Text' => 'Strikethrough-Text' ),array( 'im im-icon-Stroller' => 'Stroller' ),array( 'im im-icon-Structure' => 'Structure' ),array( 'im im-icon-Student-Female' => 'Student-Female' ),array( 'im im-icon-Student-Hat' => 'Student-Hat' ),array( 'im im-icon-Student-Hat2' => 'Student-Hat2' ),array( 'im im-icon-Student-Male' => 'Student-Male' ),array( 'im im-icon-Student-MaleFemale' => 'Student-MaleFemale' ),array( 'im im-icon-Students' => 'Students' ),array( 'im im-icon-Studio-Flash' => 'Studio-Flash' ),array( 'im im-icon-Studio-Lightbox' => 'Studio-Lightbox' ),array( 'im im-icon-Stumbleupon' => 'Stumbleupon' ),array( 'im im-icon-Suit' => 'Suit' ),array( 'im im-icon-Suitcase' => 'Suitcase' ),array( 'im im-icon-Sum-2' => 'Sum-2' ),array( 'im im-icon-Sum' => 'Sum' ),array( 'im im-icon-Summer' => 'Summer' ),array( 'im im-icon-Sun-CloudyRain' => 'Sun-CloudyRain' ),array( 'im im-icon-Sun' => 'Sun' ),array( 'im im-icon-Sunglasses-2' => 'Sunglasses-2' ),array( 'im im-icon-Sunglasses-3' => 'Sunglasses-3' ),array( 'im im-icon-Sunglasses-Smiley' => 'Sunglasses-Smiley' ),array( 'im im-icon-Sunglasses-Smiley2' => 'Sunglasses-Smiley2' ),array( 'im im-icon-Sunglasses-W' => 'Sunglasses-W' ),array( 'im im-icon-Sunglasses-W2' => 'Sunglasses-W2' ),array( 'im im-icon-Sunglasses-W3' => 'Sunglasses-W3' ),array( 'im im-icon-Sunglasses' => 'Sunglasses' ),array( 'im im-icon-Sunrise' => 'Sunrise' ),array( 'im im-icon-Sunset' => 'Sunset' ),array( 'im im-icon-Superman' => 'Superman' ),array( 'im im-icon-Support' => 'Support' ),array( 'im im-icon-Surprise' => 'Surprise' ),array( 'im im-icon-Sushi' => 'Sushi' ),array( 'im im-icon-Sweden' => 'Sweden' ),array( 'im im-icon-Swimming-Short' => 'Swimming-Short' ),array( 'im im-icon-Swimming' => 'Swimming' ),array( 'im im-icon-Swimmwear' => 'Swimmwear' ),array( 'im im-icon-Switch' => 'Switch' ),array( 'im im-icon-Switzerland' => 'Switzerland' ),array( 'im im-icon-Sync-Cloud' => 'Sync-Cloud' ),array( 'im im-icon-Sync' => 'Sync' ),array( 'im im-icon-Synchronize-2' => 'Synchronize-2' ),array( 'im im-icon-Synchronize' => 'Synchronize' ),array( 'im im-icon-T-Shirt' => 'T-Shirt' ),array( 'im im-icon-Tablet-2' => 'Tablet-2' ),array( 'im im-icon-Tablet-3' => 'Tablet-3' ),array( 'im im-icon-Tablet-Orientation' => 'Tablet-Orientation' ),array( 'im im-icon-Tablet-Phone' => 'Tablet-Phone' ),array( 'im im-icon-Tablet-Secure' => 'Tablet-Secure' ),array( 'im im-icon-Tablet-Vertical' => 'Tablet-Vertical' ),array( 'im im-icon-Tablet' => 'Tablet' ),array( 'im im-icon-Tactic' => 'Tactic' ),array( 'im im-icon-Tag-2' => 'Tag-2' ),array( 'im im-icon-Tag-3' => 'Tag-3' ),array( 'im im-icon-Tag-4' => 'Tag-4' ),array( 'im im-icon-Tag-5' => 'Tag-5' ),array( 'im im-icon-Tag' => 'Tag' ),array( 'im im-icon-Taj-Mahal' => 'Taj-Mahal' ),array( 'im im-icon-Talk-Man' => 'Talk-Man' ),array( 'im im-icon-Tap' => 'Tap' ),array( 'im im-icon-Target-Market' => 'Target-Market' ),array( 'im im-icon-Target' => 'Target' ),array( 'im im-icon-Taurus-2' => 'Taurus-2' ),array( 'im im-icon-Taurus' => 'Taurus' ),array( 'im im-icon-Taxi-2' => 'Taxi-2' ),array( 'im im-icon-Taxi-Sign' => 'Taxi-Sign' ),array( 'im im-icon-Taxi' => 'Taxi' ),array( 'im im-icon-Teacher' => 'Teacher' ),array( 'im im-icon-Teapot' => 'Teapot' ),array( 'im im-icon-Technorati' => 'Technorati' ),array( 'im im-icon-Teddy-Bear' => 'Teddy-Bear' ),array( 'im im-icon-Tee-Mug' => 'Tee-Mug' ),array( 'im im-icon-Telephone-2' => 'Telephone-2' ),array( 'im im-icon-Telephone' => 'Telephone' ),array( 'im im-icon-Telescope' => 'Telescope' ),array( 'im im-icon-Temperature-2' => 'Temperature-2' ),array( 'im im-icon-Temperature-3' => 'Temperature-3' ),array( 'im im-icon-Temperature' => 'Temperature' ),array( 'im im-icon-Temple' => 'Temple' ),array( 'im im-icon-Tennis-Ball' => 'Tennis-Ball' ),array( 'im im-icon-Tennis' => 'Tennis' ),array( 'im im-icon-Tent' => 'Tent' ),array( 'im im-icon-Test-Tube' => 'Test-Tube' ),array( 'im im-icon-Test-Tube2' => 'Test-Tube2' ),array( 'im im-icon-Testimonal' => 'Testimonal' ),array( 'im im-icon-Text-Box' => 'Text-Box' ),array( 'im im-icon-Text-Effect' => 'Text-Effect' ),array( 'im im-icon-Text-HighlightColor' => 'Text-HighlightColor' ),array( 'im im-icon-Text-Paragraph' => 'Text-Paragraph' ),array( 'im im-icon-Thailand' => 'Thailand' ),array( 'im im-icon-The-WhiteHouse' => 'The-WhiteHouse' ),array( 'im im-icon-This-SideUp' => 'This-SideUp' ),array( 'im im-icon-Thread' => 'Thread' ),array( 'im im-icon-Three-ArrowFork' => 'Three-ArrowFork' ),array( 'im im-icon-Three-Fingers' => 'Three-Fingers' ),array( 'im im-icon-Three-FingersDrag' => 'Three-FingersDrag' ),array( 'im im-icon-Three-FingersDrag2' => 'Three-FingersDrag2' ),array( 'im im-icon-Three-FingersTouch' => 'Three-FingersTouch' ),array( 'im im-icon-Thumb' => 'Thumb' ),array( 'im im-icon-Thumbs-DownSmiley' => 'Thumbs-DownSmiley' ),array( 'im im-icon-Thumbs-UpSmiley' => 'Thumbs-UpSmiley' ),array( 'im im-icon-Thunder' => 'Thunder' ),array( 'im im-icon-Thunderstorm' => 'Thunderstorm' ),array( 'im im-icon-Ticket' => 'Ticket' ),array( 'im im-icon-Tie-2' => 'Tie-2' ),array( 'im im-icon-Tie-3' => 'Tie-3' ),array( 'im im-icon-Tie-4' => 'Tie-4' ),array( 'im im-icon-Tie' => 'Tie' ),array( 'im im-icon-Tiger' => 'Tiger' ),array( 'im im-icon-Time-Backup' => 'Time-Backup' ),array( 'im im-icon-Time-Bomb' => 'Time-Bomb' ),array( 'im im-icon-Time-Clock' => 'Time-Clock' ),array( 'im im-icon-Time-Fire' => 'Time-Fire' ),array( 'im im-icon-Time-Machine' => 'Time-Machine' ),array( 'im im-icon-Time-Window' => 'Time-Window' ),array( 'im im-icon-Timer-2' => 'Timer-2' ),array( 'im im-icon-Timer' => 'Timer' ),array( 'im im-icon-To-Bottom' => 'To-Bottom' ),array( 'im im-icon-To-Bottom2' => 'To-Bottom2' ),array( 'im im-icon-To-Left' => 'To-Left' ),array( 'im im-icon-To-Right' => 'To-Right' ),array( 'im im-icon-To-Top' => 'To-Top' ),array( 'im im-icon-To-Top2' => 'To-Top2' ),array( 'im im-icon-Token-' => 'Token-' ),array( 'im im-icon-Tomato' => 'Tomato' ),array( 'im im-icon-Tongue' => 'Tongue' ),array( 'im im-icon-Tooth-2' => 'Tooth-2' ),array( 'im im-icon-Tooth' => 'Tooth' ),array( 'im im-icon-Top-ToBottom' => 'Top-ToBottom' ),array( 'im im-icon-Touch-Window' => 'Touch-Window' ),array( 'im im-icon-Tourch' => 'Tourch' ),array( 'im im-icon-Tower-2' => 'Tower-2' ),array( 'im im-icon-Tower-Bridge' => 'Tower-Bridge' ),array( 'im im-icon-Tower' => 'Tower' ),array( 'im im-icon-Trace' => 'Trace' ),array( 'im im-icon-Tractor' => 'Tractor' ),array( 'im im-icon-traffic-Light' => 'traffic-Light' ),array( 'im im-icon-Traffic-Light2' => 'Traffic-Light2' ),array( 'im im-icon-Train-2' => 'Train-2' ),array( 'im im-icon-Train' => 'Train' ),array( 'im im-icon-Tram' => 'Tram' ),array( 'im im-icon-Transform-2' => 'Transform-2' ),array( 'im im-icon-Transform-3' => 'Transform-3' ),array( 'im im-icon-Transform-4' => 'Transform-4' ),array( 'im im-icon-Transform' => 'Transform' ),array( 'im im-icon-Trash-withMen' => 'Trash-withMen' ),array( 'im im-icon-Tree-2' => 'Tree-2' ),array( 'im im-icon-Tree-3' => 'Tree-3' ),array( 'im im-icon-Tree-4' => 'Tree-4' ),array( 'im im-icon-Tree-5' => 'Tree-5' ),array( 'im im-icon-Tree' => 'Tree' ),array( 'im im-icon-Trekking' => 'Trekking' ),array( 'im im-icon-Triangle-ArrowDown' => 'Triangle-ArrowDown' ),array( 'im im-icon-Triangle-ArrowLeft' => 'Triangle-ArrowLeft' ),array( 'im im-icon-Triangle-ArrowRight' => 'Triangle-ArrowRight' ),array( 'im im-icon-Triangle-ArrowUp' => 'Triangle-ArrowUp' ),array( 'im im-icon-Tripod-2' => 'Tripod-2' ),array( 'im im-icon-Tripod-andVideo' => 'Tripod-andVideo' ),array( 'im im-icon-Tripod-withCamera' => 'Tripod-withCamera' ),array( 'im im-icon-Tripod-withGopro' => 'Tripod-withGopro' ),array( 'im im-icon-Trophy-2' => 'Trophy-2' ),array( 'im im-icon-Trophy' => 'Trophy' ),array( 'im im-icon-Truck' => 'Truck' ),array( 'im im-icon-Trumpet' => 'Trumpet' ),array( 'im im-icon-Tumblr' => 'Tumblr' ),array( 'im im-icon-Turkey' => 'Turkey' ),array( 'im im-icon-Turn-Down' => 'Turn-Down' ),array( 'im im-icon-Turn-Down2' => 'Turn-Down2' ),array( 'im im-icon-Turn-DownFromLeft' => 'Turn-DownFromLeft' ),array( 'im im-icon-Turn-DownFromRight' => 'Turn-DownFromRight' ),array( 'im im-icon-Turn-Left' => 'Turn-Left' ),array( 'im im-icon-Turn-Left3' => 'Turn-Left3' ),array( 'im im-icon-Turn-Right' => 'Turn-Right' ),array( 'im im-icon-Turn-Right3' => 'Turn-Right3' ),array( 'im im-icon-Turn-Up' => 'Turn-Up' ),array( 'im im-icon-Turn-Up2' => 'Turn-Up2' ),array( 'im im-icon-Turtle' => 'Turtle' ),array( 'im im-icon-Tuxedo' => 'Tuxedo' ),array( 'im im-icon-TV' => 'TV' ),array( 'im im-icon-Twister' => 'Twister' ),array( 'im im-icon-Twitter-2' => 'Twitter-2' ),array( 'im im-icon-Twitter' => 'Twitter' ),array( 'im im-icon-Two-Fingers' => 'Two-Fingers' ),array( 'im im-icon-Two-FingersDrag' => 'Two-FingersDrag' ),array( 'im im-icon-Two-FingersDrag2' => 'Two-FingersDrag2' ),array( 'im im-icon-Two-FingersScroll' => 'Two-FingersScroll' ),array( 'im im-icon-Two-FingersTouch' => 'Two-FingersTouch' ),array( 'im im-icon-Two-Windows' => 'Two-Windows' ),array( 'im im-icon-Type-Pass' => 'Type-Pass' ),array( 'im im-icon-Ukraine' => 'Ukraine' ),array( 'im im-icon-Umbrela' => 'Umbrela' ),array( 'im im-icon-Umbrella-2' => 'Umbrella-2' ),array( 'im im-icon-Umbrella-3' => 'Umbrella-3' ),array( 'im im-icon-Under-LineText' => 'Under-LineText' ),array( 'im im-icon-Undo' => 'Undo' ),array( 'im im-icon-United-Kingdom' => 'United-Kingdom' ),array( 'im im-icon-United-States' => 'United-States' ),array( 'im im-icon-University-2' => 'University-2' ),array( 'im im-icon-University' => 'University' ),array( 'im im-icon-Unlike-2' => 'Unlike-2' ),array( 'im im-icon-Unlike' => 'Unlike' ),array( 'im im-icon-Unlock-2' => 'Unlock-2' ),array( 'im im-icon-Unlock-3' => 'Unlock-3' ),array( 'im im-icon-Unlock' => 'Unlock' ),array( 'im im-icon-Up--Down' => 'Up--Down' ),array( 'im im-icon-Up--Down3' => 'Up--Down3' ),array( 'im im-icon-Up-2' => 'Up-2' ),array( 'im im-icon-Up-3' => 'Up-3' ),array( 'im im-icon-Up-4' => 'Up-4' ),array( 'im im-icon-Up' => 'Up' ),array( 'im im-icon-Upgrade' => 'Upgrade' ),array( 'im im-icon-Upload-2' => 'Upload-2' ),array( 'im im-icon-Upload-toCloud' => 'Upload-toCloud' ),array( 'im im-icon-Upload-Window' => 'Upload-Window' ),array( 'im im-icon-Upload' => 'Upload' ),array( 'im im-icon-Uppercase-Text' => 'Uppercase-Text' ),array( 'im im-icon-Upward' => 'Upward' ),array( 'im im-icon-URL-Window' => 'URL-Window' ),array( 'im im-icon-Usb-2' => 'Usb-2' ),array( 'im im-icon-Usb-Cable' => 'Usb-Cable' ),array( 'im im-icon-Usb' => 'Usb' ),array( 'im im-icon-User' => 'User' ),array( 'im im-icon-Ustream' => 'Ustream' ),array( 'im im-icon-Vase' => 'Vase' ),array( 'im im-icon-Vector-2' => 'Vector-2' ),array( 'im im-icon-Vector-3' => 'Vector-3' ),array( 'im im-icon-Vector-4' => 'Vector-4' ),array( 'im im-icon-Vector-5' => 'Vector-5' ),array( 'im im-icon-Vector' => 'Vector' ),array( 'im im-icon-Venn-Diagram' => 'Venn-Diagram' ),array( 'im im-icon-Vest-2' => 'Vest-2' ),array( 'im im-icon-Vest' => 'Vest' ),array( 'im im-icon-Viddler' => 'Viddler' ),array( 'im im-icon-Video-2' => 'Video-2' ),array( 'im im-icon-Video-3' => 'Video-3' ),array( 'im im-icon-Video-4' => 'Video-4' ),array( 'im im-icon-Video-5' => 'Video-5' ),array( 'im im-icon-Video-6' => 'Video-6' ),array( 'im im-icon-Video-GameController' => 'Video-GameController' ),array( 'im im-icon-Video-Len' => 'Video-Len' ),array( 'im im-icon-Video-Len2' => 'Video-Len2' ),array( 'im im-icon-Video-Photographer' => 'Video-Photographer' ),array( 'im im-icon-Video-Tripod' => 'Video-Tripod' ),array( 'im im-icon-Video' => 'Video' ),array( 'im im-icon-Vietnam' => 'Vietnam' ),array( 'im im-icon-View-Height' => 'View-Height' ),array( 'im im-icon-View-Width' => 'View-Width' ),array( 'im im-icon-Vimeo' => 'Vimeo' ),array( 'im im-icon-Virgo-2' => 'Virgo-2' ),array( 'im im-icon-Virgo' => 'Virgo' ),array( 'im im-icon-Virus-2' => 'Virus-2' ),array( 'im im-icon-Virus-3' => 'Virus-3' ),array( 'im im-icon-Virus' => 'Virus' ),array( 'im im-icon-Visa' => 'Visa' ),array( 'im im-icon-Voice' => 'Voice' ),array( 'im im-icon-Voicemail' => 'Voicemail' ),array( 'im im-icon-Volleyball' => 'Volleyball' ),array( 'im im-icon-Volume-Down' => 'Volume-Down' ),array( 'im im-icon-Volume-Up' => 'Volume-Up' ),array( 'im im-icon-VPN' => 'VPN' ),array( 'im im-icon-Wacom-Tablet' => 'Wacom-Tablet' ),array( 'im im-icon-Waiter' => 'Waiter' ),array( 'im im-icon-Walkie-Talkie' => 'Walkie-Talkie' ),array( 'im im-icon-Wallet-2' => 'Wallet-2' ),array( 'im im-icon-Wallet-3' => 'Wallet-3' ),array( 'im im-icon-Wallet' => 'Wallet' ),array( 'im im-icon-Warehouse' => 'Warehouse' ),array( 'im im-icon-Warning-Window' => 'Warning-Window' ),array( 'im im-icon-Watch-2' => 'Watch-2' ),array( 'im im-icon-Watch-3' => 'Watch-3' ),array( 'im im-icon-Watch' => 'Watch' ),array( 'im im-icon-Wave-2' => 'Wave-2' ),array( 'im im-icon-Wave' => 'Wave' ),array( 'im im-icon-Webcam' => 'Webcam' ),array( 'im im-icon-weight-Lift' => 'weight-Lift' ),array( 'im im-icon-Wheelbarrow' => 'Wheelbarrow' ),array( 'im im-icon-Wheelchair' => 'Wheelchair' ),array( 'im im-icon-Width-Window' => 'Width-Window' ),array( 'im im-icon-Wifi-2' => 'Wifi-2' ),array( 'im im-icon-Wifi-Keyboard' => 'Wifi-Keyboard' ),array( 'im im-icon-Wifi' => 'Wifi' ),array( 'im im-icon-Wind-Turbine' => 'Wind-Turbine' ),array( 'im im-icon-Windmill' => 'Windmill' ),array( 'im im-icon-Window-2' => 'Window-2' ),array( 'im im-icon-Window' => 'Window' ),array( 'im im-icon-Windows-2' => 'Windows-2' ),array( 'im im-icon-Windows-Microsoft' => 'Windows-Microsoft' ),array( 'im im-icon-Windows' => 'Windows' ),array( 'im im-icon-Windsock' => 'Windsock' ),array( 'im im-icon-Windy' => 'Windy' ),array( 'im im-icon-Wine-Bottle' => 'Wine-Bottle' ),array( 'im im-icon-Wine-Glass' => 'Wine-Glass' ),array( 'im im-icon-Wink' => 'Wink' ),array( 'im im-icon-Winter-2' => 'Winter-2' ),array( 'im im-icon-Winter' => 'Winter' ),array( 'im im-icon-Wireless' => 'Wireless' ),array( 'im im-icon-Witch-Hat' => 'Witch-Hat' ),array( 'im im-icon-Witch' => 'Witch' ),array( 'im im-icon-Wizard' => 'Wizard' ),array( 'im im-icon-Wolf' => 'Wolf' ),array( 'im im-icon-Woman-Sign' => 'Woman-Sign' ),array( 'im im-icon-WomanMan' => 'WomanMan' ),array( 'im im-icon-Womans-Underwear' => 'Womans-Underwear' ),array( 'im im-icon-Womans-Underwear2' => 'Womans-Underwear2' ),array( 'im im-icon-Women' => 'Women' ),array( 'im im-icon-Wonder-Woman' => 'Wonder-Woman' ),array( 'im im-icon-Wordpress' => 'Wordpress' ),array( 'im im-icon-Worker-Clothes' => 'Worker-Clothes' ),array( 'im im-icon-Worker' => 'Worker' ),array( 'im im-icon-Wrap-Text' => 'Wrap-Text' ),array( 'im im-icon-Wreath' => 'Wreath' ),array( 'im im-icon-Wrench' => 'Wrench' ),array( 'im im-icon-X-Box' => 'X-Box' ),array( 'im im-icon-X-ray' => 'X-ray' ),array( 'im im-icon-Xanga' => 'Xanga' ),array( 'im im-icon-Xing' => 'Xing' ),array( 'im im-im im-icon-Yacht' => 'Yacht' ),array( 'im im-icon-Yahoo-Buzz' => 'Yahoo-Buzz' ),array( 'im im-icon-Yahoo' => 'Yahoo' ),array( 'im im-icon-Yelp' => 'Yelp' ),array( 'im im-icon-Yes' => 'Yes' ),array( 'im im-icon-Ying-Yang' => 'Ying-Yang' ),array( 'im im-icon-Youtube' => 'Youtube' ),array( 'im im-icon-Z-A' => 'Z-A' ),array( 'im im-icon-Zebra' => 'Zebra' ),array( 'im im-icon-Zombie' => 'Zombie' ),array( 'im im-icon-Zoom-Gesture' => 'Zoom-Gesture' ),array( 'im im-icon-Zootool' => 'Zootool' ),
  );

  return array_merge( $icons, $iconsmind_icons );
}